@@ -1,7 +1,7 @@
 #! /bin/bash -e
-# $Id: check_doxygen.sh 1757 2010-12-30 14:51:38Z bradbell $
+# $Id: check_doxygen.sh 2082 2011-08-31 17:50:58Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
 # the terms of the
@@ -10,7 +10,7 @@
 # A copy of this license is included in the COPYING file of this distribution.
 # Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # -----------------------------------------------------------------------------
-if [ $0 != "bin/check_doxygen.sh" ]
+if [ ! -e "bin/check_doxygen.sh" ]
 then
 	echo "bin/check_doxygen.sh: must be executed from its parent directory"
 	exit 1
@@ -21,7 +21,8 @@ then
 	echo "bin/check_doxygen.sh: cannot find doxygen.err"
 	exit 1
 fi
-doxygen_version=`doxygen --version  | sed -e 's|\.|*100+|' -e's|\.|*10+|'`
+doxygen_version=`doxygen --version  | 
+	sed -e 's|\.|*100+|' -e 's|\.|*10+|' -e 's|\..*||'`
 let doxygen_version=$doxygen_version
 if (( $doxygen_version <= 155 ))
 then
