@@ -1,7 +1,7 @@
 #! /bin/bash -e
-# $Id: svn_merge.sh 1766 2010-12-31 17:47:57Z bradbell $
+# $Id: svn_merge.sh 2178 2011-10-30 06:52:58Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
 # the terms of the
@@ -10,7 +10,7 @@
 # A copy of this license is included in the COPYING file of this distribution.
 # Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # -----------------------------------------------------------------------------
-if [ $0 != "bin/svn_merge.sh" ]
+if [ ! -e "bin/svn_merge.sh" ]
 then
 	echo "bin/svn_merge.sh: must be executed from its parent directory"
 	exit 1
@@ -29,13 +29,13 @@ echo "DryRun = $DryRun"
 # script to help in execution of svn merge command
 #
 # Name of the directory where the changes have been committed
-from_branch=branches/multiple_result
+from_branch=branches/thread
 #
 # Version of the repository corresponding to from_branch just before changes
-Start=1583
+Start=2124
 # 
 # Version of the repository corresponding to from_branch after the changes
-End=1587
+End=2177
 #
 # the svn merge command
 cmd="svn merge $DryRun -r $Start:$End"
