@@ -1,5 +1,5 @@
 #! /bin/bash -e
-# $Id: build.sh 1816 2011-01-17 02:50:30Z bradbell $
+# $Id: build.sh 2245 2012-01-01 17:32:13Z bradbell $
 # -----------------------------------------------------------------------------
 # CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 #
@@ -17,8 +17,6 @@ ADOLC_DIR=$HOME/prefix/adolc
 FADBAD_DIR=$HOME/prefix/fadbad
 SACADO_DIR=$HOME/prefix/sacado
 IPOPT_DIR=$HOME/prefix/ipopt
-# library path for the ipopt and adolc
-export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$ADOLC_DIR/lib:$IPOPT_DIR/lib"
 # version type is one of "trunk" or "stable"
 version_type="stable"
 # -----------------------------------------------------------------------------
@@ -71,9 +69,7 @@ else
 fi
 #
 # Files are created by the configure command and copied to the source tree
-# (This list is also in the gpl_license.sh file.)
 configure_file_list="
-	cppad/config.h
 	cppad/configure.hpp
 	doc.omh
 	doxyfile
@@ -97,7 +93,6 @@ then
 	#
 	list="
 		configure
-		cppad/config.h
 	"
 	for name in $list
 	do
@@ -121,15 +116,10 @@ then
 		-e "s/\$as_me [0-9]\{8\}[.0-9]*/\$as_me $version/g" \
         	-e "s/Generated by GNU Autoconf.*$version/&./"
 	#
-	echo "sed -i.old cppad/config.h ..."
-	sed -i.old cppad/config.h \
-		-e "s/CppAD [0-9]\{8\}[.0-9]*/CppAD $version/g" \
-		-e "s/VERSION \"[0-9]\{8\}[.0-9]*\"/VERSION \"$version\"/g"
 	list="
 		AUTHORS
 		configure.ac
 		configure
-		cppad/config.h
 	"
 	for name in $list
 	do
@@ -164,8 +154,6 @@ then
 		install-sh 
 		missing 
 		configure 
-		cppad/config.h 
-		cppad/config.h.in 
 		$makefile_in
 	"
 	missing=""
@@ -192,9 +180,6 @@ then
 	echo "aclocal"
 	aclocal
 	#
-	echo "autoheader"
-	autoheader
-	#
 	echo "skipping libtoolize"
 	# echo "libtoolize -c -f -i"
 	# if ! libtoolize -c -f -i
@@ -238,8 +223,10 @@ then
 	"
 	if [ -e $BOOST_DIR/boost ]
 	then
-		dir_list="$dir_list 
-			BOOST_DIR=$BOOST_DIR"
+		dir_list="$dir_list
+			--with-boostvector BOOST_DIR=$BOOST_DIR"
+#_build_test_only:		dir_list="$dir_list 
+#_build_test_only:			--with-boostvector"
 	fi
 	if [ -e $ADOLC_DIR/include/adolc ]
 	then
@@ -261,20 +248,36 @@ then
 		dir_list="$dir_list 
 		IPOPT_DIR=$IPOPT_DIR"
 	fi
+	# Use TAPE_ADDR_TYPE=int (a signed type) to do more checking for 
+	# slicing from size_t to addr_t.
+	tape_addr_type=""
+#_build_test_only:	tape_addr_type="TAPE_ADDR_TYPE=int"
+	#
 	dir_list=`echo $dir_list | sed -e 's|\t\t*| |g'`
-	echo "../configure \\"
-	echo "$dir_list" | sed -e 's| | \\\n\t|g' -e 's|$| \\|' -e 's|^|\t|'
-	echo "CXX_FLAGS=\"-Wall -ansi -pedantic-errors -std=c++98 -Wshadow\"\\"
-	echo "--with-Documentation"
+	cxx_flags="-Wall -ansi -pedantic-errors -std=c++98 -Wshadow"
+cat << EOF
+../configure \\
+$dir_list \\
+CXX_FLAGS=\"$cxx_flags\" \\
+$tape_addr_type --with-Documentation OPENMP_FLAGS=-fopenmp
+EOF
 	#
 	../configure $dir_list \
-		CXX_FLAGS="-Wall -ansi -pedantic-errors -std=c++98 -Wshadow" \
-		--with-Documentation
+		CXX_FLAGS="$cxx_flags" \
+		$tape_addr_type --with-Documentation OPENMP_FLAGS=-fopenmp
 	#
 	for file in $configure_file_list
 	do
 		echo "cp $file ../$file"
 		cp $file ../$file
+		#
+		# change shell scripts to be executable
+		ext=`echo $file | sed -e 's/.*\.\([^.]*\)$/\1/'`
+		if [ "$ext" == "sh" ]
+		then
+			echo "chmod +x ../$file"
+			chmod +x ../$file
+		fi
 	done
 	#
 	echo "OK: ./build.sh configure"
@@ -284,7 +287,7 @@ fi
 if [ "$1" = "dist" ] 
 then
 	# ----------------------------------------------------------------------
-	# Things to do in the distribution directory
+	# Things to do in the original source directory
 	# ----------------------------------------------------------------------
 	echo "Only include the *.xml version of the documentation in distribution"
 	if ! grep < doc.omh > /dev/null \
@@ -301,24 +304,42 @@ then
 	if [ -e doc ]
 	then
 		echo "rm -r doc"
-		rm -r doc
+		      rm -r doc
 	fi
 	#
-	echo "bin/run_omhelp.sh doc xml"
-	      bin/run_omhelp.sh doc xml
+	echo "bin/run_omhelp.sh xml"
+	      bin/run_omhelp.sh xml
 	#
 	echo "mv doc.omh.save doc.omh"
-	mv doc.omh.save doc.omh
+	      mv doc.omh.save doc.omh
+	#
+	# Run automated checking of file names in original source directory
+	list="
+		check_example.sh
+		check_if_0.sh
+		check_include_def.sh
+		check_include_file.sh
+		check_include_omh.sh
+		check_makefile.sh
+		check_op_code.sh
+		check_svn_id.sh
+		check_verbatim.sh
+	"
+	for check in $list 
+	do
+		echo "bin/$check"
+		      bin/$check
+	done
 	# ----------------------------------------------------------------------
 	# Things to do in the work directory
 	# ----------------------------------------------------------------------
 	echo "cd work"
-	cd work
+	      cd work
 	#
 	if [ -e cppad-$version ]
 	then
 		echo "rm -rf cppad-$version"
-		rm -rf cppad-$version
+		      rm -rf cppad-$version
 	fi
 	for file in cppad-*.tgz 
 	do
@@ -330,7 +351,7 @@ then
 	done
 	#
 	echo "make dist"
-	make dist
+	      make dist
 	#
 	if [ ! -e cppad-$version.tar.gz ]
 	then
@@ -341,13 +362,13 @@ then
 	fi
 	# change *.tgz to *.cpl.tgz
 	echo "mv cppad-$version.tar.gz cppad-$version.cpl.tgz"
-	mv cppad-$version.tar.gz cppad-$version.cpl.tgz
+	      mv cppad-$version.tar.gz cppad-$version.cpl.tgz
 	#
 	echo "OK: ./build.sh dist"
 	exit 0
 fi
 # -----------------------------------------------------------------------------
-# omhelp comes after dist becasue dist only includes one help output
+# omhelp comes after dist because dist only includes one help output
 if [ "$1" = "omhelp" ] 
 then
 	if ! grep < doc.omh > /dev/null \
@@ -360,9 +381,9 @@ then
 	do
 		for ext in htm xml
 		do
-			echo "begin: bin/run_omhelp.sh doc $ext $flag"
-			             bin/run_omhelp.sh doc $ext $flag
-			echo="end:   bin/run_omhelp.sh doc $ext $flag"
+			echo "begin: bin/run_omhelp.sh $ext $flag"
+			             bin/run_omhelp.sh $ext $flag
+			echo="end:   bin/run_omhelp.sh $ext $flag"
 		done
 	done
 	#
@@ -456,24 +477,6 @@ then
 	# start log for this test
 	echo "date > $log_file"
 	      date > $log_dir/$log_file
-	#
-	# Run automated checking of file names in original source directory
-	#
-	list="
-		check_example.sh
-		check_if_0.sh
-		check_include_def.sh
-		check_include_file.sh
-		check_include_omh.sh
-		check_makefile.sh
-	"
-	for check in $list 
-	do
-		echo "bin/$check >> $log_file"
-		      bin/$check >> $log_dir/$log_file
-	done
-	# add a new line after last file check
-	echo ""             >> $log_dir/$log_file
 	# ----------------------------------------------------------------------
 	# Things to do in the work directory
 	# ----------------------------------------------------------------------
@@ -501,20 +504,21 @@ then
 	echo "cd cppad-$version" >> $log_dir/$log_file
 	      cd cppad-$version
 	#
+	# build_test_only configuration
+	echo "sed -i -e 's|^#_build_test_only:||' build.sh"
+	sed -i -e 's|^#_build_test_only:||' build.sh
+	#
 	echo "./build.sh configure >> $log_file" 
 	      ./build.sh configure >> $log_dir/$log_file
 	#
 	# test user documentation
-	echo "bin/run_omhelp.sh doc xml  >> $log_file"
-	      bin/run_omhelp.sh doc xml  >> $log_dir/$log_file
+	echo "bin/run_omhelp.sh xml  >> $log_file"
+	      bin/run_omhelp.sh xml  >> $log_dir/$log_file
 	# 
 	# test developer documentation
 	echo "./build.sh doxygen   >> $log_file"
 	      ./build.sh doxygen   >> $log_dir/$log_file
 	#
-	# openmp test script
-	echo "openmp/run.sh       >> $log_file"
-	      openmp/run.sh       >> $log_dir/$log_file
 	# ----------------------------------------------------------------------
 	# Things to do in the work/disribution/work directory
 	# ----------------------------------------------------------------------
@@ -523,19 +527,58 @@ then
 	      cd work
 	#
 	dir=`pwd` 
-	echo "Use: tail -f $dir/make_test.log"
-	echo "to follow the progress of the following command:"
+	echo "To see progress in the 'make test' log file use"
+	echo "	../temp.sh ( OK | All | tail | follow | file )"
+	cat << EOF > $log_dir/../temp.sh
+#! /bin/bash -e
+case "\$1" in
+
+	OK)
+	grep OK $dir/make_test.log
+	exit 0
+	;;
+
+	All)
+	grep All $dir/make_test.log
+	exit 0
+	;;
+
+	tail)
+	tail $dir/make_test.log
+	exit 0
+	;;
+
+	follow)
+	tail -f $dir/make_test.log
+	exit 0
+	;;
+
+	file)
+	echo "$dir/make_test.log"
+	exit 0
+	;;
+
+	*)
+	echo "usage: ../temp.sh option"
+	echo "where option is one of following: OK, All, tail, follow, file."
+	exit 1
+esac
+EOF
+	chmod +x $log_dir/../temp.sh
 	#
 	# build and run all the tests
 	echo "make test                >& make_test.log"
 	      make test                >& make_test.log
 	#
+	echo "rm ../temp.sh"
+	rm $log_dir/../temp.sh
+	#
 	echo "cat make_test.log        >> $log_file"
 	      cat make_test.log        >> $log_dir/$log_file
 	#
-	if grep 'warning:' make_test.log
-	then
-		echo "There are warnings in $dir/make.log"
+	if grep ': *warning:' make_test.log
+	then 
+		echo "There are warnings in $dir/make_test.log"
 		exit 1
 	fi
 	# --------------------------------------------------------------------
@@ -568,7 +611,7 @@ usage: ./build.sh option_1 option_2 ...
 
 options                                                               requires
 -------                                                               --------
-version:   set version in AUTHORS, configure.ac, configure, config.h.
+version:   set version in AUTHORS, configure.ac, configure, ...
 automake:  run the tools required by autoconf and automake.
 configure: run the configure script in the work directory.            automake
 dist:      create the distribution file work/cppad-version.cpl.tgz.   configure
