@@ -1,9 +1,9 @@
-/* $Id: check_simple_vector.hpp 1698 2010-06-02 16:34:43Z bradbell $ */
+/* $Id: check_simple_vector.hpp 2085 2011-09-01 14:54:04Z bradbell $ */
 # ifndef CPPAD_CHECK_SIMPLE_VECTOR_INCLUDED
 # define CPPAD_CHECK_SIMPLE_VECTOR_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -15,6 +15,7 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 /*
 $begin CheckSimpleVector$$
 $spell
+	alloc
 	const
 	cppad.hpp
 	CppAD
@@ -81,6 +82,13 @@ The file $code cppad/check_simple_vector.hpp$$ is included by $code cppad/cppad.
 but it can also be included separately with out the rest
 if the CppAD include files.
 
+$head Parallel Mode$$
+$index parallel, CheckSimpleVector$$
+$index CheckSimpleVector, parallel$$
+The routine $cref/thread_alloc::parallel_setup/ta_parallel_setup/$$
+must be called before it
+can be used in $cref/parallel/ta_in_parallel/$$ mode.
+
 $head Example$$
 $children%
 	example/check_simple_vector.cpp
@@ -96,7 +104,10 @@ $end
 ---------------------------------------------------------------------------
 */
 
+# include <cstddef>
 # include <cppad/local/cppad_assert.hpp>
+# include <cppad/local/define.hpp>
+# include <cppad/thread_alloc.hpp>
 
 namespace CppAD {
 
@@ -116,11 +127,14 @@ namespace CppAD {
 
 	template <class Scalar, class Vector>
 	void CheckSimpleVector(const Scalar& x, const Scalar& y)
-	{	// only need execute once per value Scalar, Vector pair
-		static bool runOnce = false;
-		if( runOnce )
+	{	// Section 3.6.2 of ISO/IEC 14882:1998(E) states: "The storage for 
+		// objects with static storage duration (3.7.1) shall be zero-
+		// initialized (8.5) before any other initialization takes place."
+		static size_t count[CPPAD_MAX_NUM_THREADS];
+		size_t thread = thread_alloc::thread_num();
+		if( count[thread] > 0  )
 			return;
-		runOnce = true;
+		count[thread]++;
 
 		// value_type must be type of elements of Vector
 		typedef typename Vector::value_type value_type;
