@@ -1,8 +1,8 @@
-/* $Id: cppad.hpp 1643 2010-02-04 05:45:21Z bradbell $ */
+/* $Id: cppad.hpp 2238 2011-12-28 15:09:38Z bradbell $ */
 # ifndef CPPAD_CPPAD_INCLUDED
 # define CPPAD_CPPAD_INCLUDED
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -19,9 +19,7 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 \brief contains all the variables and functions defined by the CppAD package.
 */
 
-# include <cppad/declare.hpp>            // forward declarations need by user
-// ---------------------------------------------------------------------------
-# include <cppad/local/base_complex.hpp> // allow form complex Base types
+# include <cppad/base_require.hpp> // all base type requirements
 // ---------------------------------------------------------------------------
 // CppAD general purpose library routines (can be included separately)
 
@@ -29,10 +27,12 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <cppad/check_simple_vector.hpp>
 # include <cppad/local/cppad_assert.hpp>
 # include <cppad/lu_solve.hpp>
+# include <cppad/memory_leak.hpp>
 # include <cppad/near_equal.hpp>
 # include <cppad/ode_err_control.hpp>
 # include <cppad/ode_gear.hpp>
 # include <cppad/ode_gear_control.hpp>
+# include <cppad/omp_alloc.hpp>
 # include <cppad/poly.hpp>
 # include <cppad/pow_int.hpp>
 # include <cppad/romberg_mul.hpp>
@@ -40,7 +40,9 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <cppad/rosen_34.hpp>
 # include <cppad/runge_45.hpp>
 # include <cppad/speed_test.hpp>
+# include <cppad/time_test.hpp>
 # include <cppad/track_new_del.hpp>
+# include <cppad/thread_alloc.hpp>
 # include <cppad/vector.hpp>
 
 // --------------------------------------------------------------------------
