@@ -1,9 +1,9 @@
-/* $Id: ad_fun.hpp 1641 2010-02-01 16:39:45Z bradbell $ */
+/* $Id: ad_fun.hpp 2178 2011-10-30 06:52:58Z bradbell $ */
 # ifndef CPPAD_AD_FUN_INCLUDED
 # define CPPAD_AD_FUN_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -50,9 +50,7 @@ $childtable%
 	cppad/local/fun_eval.hpp%
 	cppad/local/drivers.hpp%
 	cppad/local/fun_check.hpp%
-	cppad/local/omp_max_thread.hpp%
-	cppad/local/optimize.hpp%
-	omh/fun_deprecated.omh
+	cppad/local/optimize.hpp
 %$$
 
 $end
@@ -68,13 +66,12 @@ File used to define the ADFun<Base> class.
 Class used to hold function objects
 
 \tparam Base
-This function object case recorded using AD< \a Base > operations.
-It does it calculations using \a Base operations.
+A function object has a recording of <tt>AD<Base></tt> operations.
+It does it calculations using \c Base operations.
 */
 
 template <class Base>
 class ADFun {
-public:
 // ------------------------------------------------------------
 // Private member variables
 private:
@@ -103,7 +100,7 @@ private:
 	player<Base> play_;
 
 	/// results of the forward mode calculations
-	Base *taylor_;
+	pod_vector<Base> taylor_;
 
 	/// packed results of the forward mode Jacobian sparsity calculations
 	/// (\c for_jac_sparse_pack_.n_set() != 0  implies
@@ -223,7 +220,7 @@ private:
 public:
 	/// copy constructor
 	ADFun(const ADFun& g) 
-	: total_num_var_(0), taylor_(CPPAD_NULL)
+	: total_num_var_(0)
 	{	CppAD::ErrorHandler::Call(
 		true,
 		__LINE__,
@@ -248,9 +245,7 @@ public:
 
 	/// destructor
 	~ADFun(void)
-	{	if( taylor_ != CPPAD_NULL )
-			CPPAD_TRACK_DEL_VEC(taylor_);
-	}
+	{ }
 
 	/// deprecated: assign a new operation sequence
 	template <typename ADvector>
@@ -262,7 +257,8 @@ public:
 
 	/// forward mode sweep
 	template <typename VectorBase>
-	VectorBase Forward(size_t p, const VectorBase &u);
+	VectorBase Forward(
+		size_t p, const VectorBase& x, std::ostream& s = std::cout);
 
 	/// reverse mode sweep
 	template <typename VectorBase>
@@ -470,6 +466,7 @@ CPPAD_END_NAMESPACE
 # include <cppad/local/rev_hes_sweep.hpp>
 
 // user interfaces
+# include <cppad/local/parallel_ad.hpp>
 # include <cppad/local/independent.hpp>
 # include <cppad/local/dependent.hpp>
 # include <cppad/local/fun_construct.hpp>
