@@ -1,9 +1,9 @@
-/* $Id: ad_valued.hpp 1369 2009-05-31 01:31:48Z bradbell $ */
+/* $Id: ad_valued.hpp 1865 2011-02-06 22:17:22Z bradbell $ */
 # ifndef CPPAD_AD_VALUED_INCLUDED
 # define CPPAD_AD_VALUED_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-07 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -28,7 +28,8 @@ $childtable%
 	cppad/local/std_math_ad.hpp%
 	cppad/local/math_other.hpp%
 	cppad/local/cond_exp.hpp%
-	cppad/local/discrete.hpp
+	cppad/local/discrete.hpp%
+	cppad/local/user_atomic.hpp
 %$$
 
 $end
@@ -42,5 +43,6 @@ $end
 # include <cppad/local/cond_exp.hpp>
 # include <cppad/local/math_other.hpp>
 # include <cppad/local/discrete.hpp>
+# include <cppad/local/user_atomic.hpp>
 
 # endif
