@@ -1,9 +1,9 @@
-/* $Id: add.hpp 1742 2010-12-27 17:38:20Z bradbell $ */
+/* $Id: add.hpp 1986 2011-06-18 20:33:17Z bradbell $ */
 # ifndef CPPAD_ADD_INCLUDED
 # define CPPAD_ADD_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -23,7 +23,7 @@ AD<Base> operator + (const AD<Base> &left , const AD<Base> &right)
 	if( tape != CPPAD_NULL )
 		tape_id = tape->id_;
 
-	// id_ == 1 is initial setting for parameters so cannot match 0
+	// id_ setting for parameters cannot match 0
 	bool var_left  = left.id_  == tape_id;
 	bool var_right = right.id_ == tape_id;
 	CPPAD_ASSERT_KNOWN(
@@ -63,7 +63,7 @@ AD<Base> operator + (const AD<Base> &left , const AD<Base> &right)
 			CPPAD_ASSERT_UNKNOWN( NumArg(AddpvOp) == 2 );
 
 			// put operand addresses in tape
-			size_t p = tape->Rec_.PutPar(right.value_);
+			addr_t p = tape->Rec_.PutPar(right.value_);
 			tape->Rec_.PutArg(p, left.taddr_);
 			// put operator in the tape
 			result.taddr_ = tape->Rec_.PutOp(AddpvOp);
@@ -82,7 +82,7 @@ AD<Base> operator + (const AD<Base> &left , const AD<Base> &right)
 			CPPAD_ASSERT_UNKNOWN( NumArg(AddpvOp) == 2 );
 
 			// put operand addresses in tape
-			size_t p = tape->Rec_.PutPar(left.value_);
+			addr_t p = tape->Rec_.PutPar(left.value_);
 			tape->Rec_.PutArg(p, right.taddr_);
 			// put operator in the tape
 			result.taddr_ = tape->Rec_.PutOp(AddpvOp);
