@@ -1,9 +1,9 @@
-/* $Id: define.hpp 1588 2009-11-24 20:26:48Z bradbell $ */
+/* $Id: define.hpp 2234 2011-12-21 13:44:54Z bradbell $ */
 # ifndef CPPAD_DEFINE_INCLUDED
 # define CPPAD_DEFINE_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-09 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -16,9 +16,32 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 /*!
 \file define.hpp
 Define processor symbols and macros that are used by CppAD.
-
 */
 
+/*!
+\def CPPAD_OP_CODE_TYPE
+Is the type used to store enum OpCode values. If not the same as OpCode, then 
+<code>sizeof(CPPAD_OP_CODE_TYPE) <= sizeof( enum OpCode )</code>
+to conserve memory.
+This type must support \c std::numeric_limits,
+the \c <= operator,
+and conversion to \c size_t.
+Make sure that the type chosen returns true for is_pod<CPPAD_OP_CODE_TYPE>
+in pod_vector.hpp.
+*/
+# define CPPAD_OP_CODE_TYPE unsigned char
+
+/*!
+\def CPPAD_TAPE_ID_TYPE
+Is the type used to store tape identifies on the tape. If not size_t, then 
+<code>sizeof(CPPAD_TAPE_ID_TYPE) <= sizeof( size_t )</code>
+to conserve memory.
+This type must support \c std::numeric_limits,
+the \c <= operator,
+and conversion to \c size_t.
+*/
+# define CPPAD_TAPE_ID_TYPE unsigned int
+
 /*!
 \def CPPAD_USE_FORWARD0SWEEP
 If ture, use compute zero order sweeps using a specialized routine.
@@ -38,15 +61,14 @@ This preprocessor symbol makes it easier to compare these two options.
 Declares beginning of the CppAD namespace is a way not reconized by doxygen.
 
 \def CPPAD_END_NAMESPACE
-Used for end that matches the beginning of a CppAD namespace section
+Used for end that matches the beginning of a CppAD namespace section.
 */
-
 # define CPPAD_BEGIN_NAMESPACE namespace CppAD {
 # define CPPAD_END_NAMESPACE   }
 
 
 /*!
-\def CPPAD_INLINE
+\def CPPAD_INLINE_FRIEND_TEMPLATE_FUNCTION
 A version of the inline command that works with MC compiler.
 
 Microsoft Visual C++ version 9.0 generates a warning if a template
@@ -62,12 +84,12 @@ and it contains the text
 	to a specialization of a function template
 \endverbatim
 This happens even if the function is not a specialization.
-The macro CPPAD_INLINE is defined as empty for Microsoft compilers.
+This macro is defined as empty for Microsoft compilers.
 */
 # ifdef _MSC_VER
-# define CPPAD_INLINE
+# define CPPAD_INLINE_FRIEND_TEMPLATE_FUNCTION
 # else
-# define CPPAD_INLINE inline
+# define CPPAD_INLINE_FRIEND_TEMPLATE_FUNCTION inline
 # endif
 
 /*!
@@ -83,19 +105,14 @@ it is defined when cppad/local/define.hpp is included.
  
 /*!
 \def CPPAD_MAX_NUM_THREADS
-Specifies the maximum number of OpenMp threads that can be used with CppAD.
+Specifies the maximum number of threads that CppAD can support.
 
-If it is not yet defined,
+The user may define CPPAD_MAX_NUM_THREADS before including any of the CppAD
+header files.  If it is not yet defined,
 it is defined when cppad/local/define.hpp is included.
-If the preprocessor symbol _OPENMP is not defined, 
-CPPAD_MAX_NUM_THREADS one. Otheriwse it is 32.
 */
 # ifndef CPPAD_MAX_NUM_THREADS
-# ifdef _OPENMP
-# define CPPAD_MAX_NUM_THREADS 32
-# else
-# define CPPAD_MAX_NUM_THREADS 1
-# endif
+# define CPPAD_MAX_NUM_THREADS 48
 # endif
 
 /*!
@@ -122,16 +139,16 @@ uses the definition of the same operation for that case.
 template <class Base>                                                   \
 inline AD<Base>& operator Op                                            \
 (AD<Base> &left, double right)                                          \
-{	return left Op AD<Base>(right); }                               \
+{	return left Op AD<Base>(right); }                                  \
                                                                         \
 template <class Base>                                                   \
 inline AD<Base>& operator Op                                            \
 (AD<Base> &left, const Base &right)                                     \
-{	return left Op AD<Base>(right); }                               \
+{	return left Op AD<Base>(right); }                                  \
                                                                         \
 inline AD<double>& operator Op                                          \
 (AD<double> &left, const double &right)                                 \
-{	return left Op AD<double>(right); }                             \
+{	return left Op AD<double>(right); }                                \
                                                                         \
 template <class Base>                                                   \
 inline AD<Base>& operator Op                                            \
@@ -165,79 +182,79 @@ uses the definition of the same operation for that case.
 template <class Base>                                                  \
 inline AD<Base> operator Op                                            \
 (const AD<Base> &left, const VecAD_reference<Base> &right)             \
-{	return left Op right.ADBase(); }                               \
+{	return left Op right.ADBase(); }                                  \
                                                                        \
 template <class Base>                                                  \
 inline AD<Base> operator Op                                            \
 (const VecAD_reference<Base> &left, const VecAD_reference<Base> &right)\
-{	return left.ADBase() Op right.ADBase(); }                      \
+{	return left.ADBase() Op right.ADBase(); }                         \
                                                                        \
 template <class Base>                                                  \
 inline AD<Base> operator Op                                            \
-	(const VecAD_reference<Base> &left, const AD<Base> &right)     \
-{	return left.ADBase() Op right; }                               \
+	(const VecAD_reference<Base> &left, const AD<Base> &right)        \
+{	return left.ADBase() Op right; }                                  \
 /* ----------------------------------------------------------------*/  \
 /* Operations Base */                                                  \
                                                                        \
 template <class Base>                                                  \
 inline AD<Base> operator Op                                            \
-	(const Base &left, const AD<Base> &right)                      \
-{	return AD<Base>(left) Op right; }                              \
+	(const Base &left, const AD<Base> &right)                         \
+{	return AD<Base>(left) Op right; }                                 \
                                                                        \
 template <class Base>                                                  \
 inline AD<Base> operator Op                                            \
-	(const Base &left, const VecAD_reference<Base> &right)         \
-{	return AD<Base>(left) Op right.ADBase(); }                     \
+	(const Base &left, const VecAD_reference<Base> &right)            \
+{	return AD<Base>(left) Op right.ADBase(); }                        \
                                                                        \
 template <class Base>                                                  \
 inline AD<Base> operator Op                                            \
-	(const AD<Base> &left, const Base &right)                      \
-{	return left Op AD<Base>(right); }                              \
+	(const AD<Base> &left, const Base &right)                         \
+{	return left Op AD<Base>(right); }                                 \
                                                                        \
 template <class Base>                                                  \
 inline AD<Base> operator Op                                            \
-	(const VecAD_reference<Base> &left, const Base &right)         \
-{	return left.ADBase() Op AD<Base>(right); }                     \
+	(const VecAD_reference<Base> &left, const Base &right)            \
+{	return left.ADBase() Op AD<Base>(right); }                        \
                                                                        \
 /* ----------------------------------------------------------------*/  \
 /* Operations double */                                                \
                                                                        \
 template <class Base>                                                  \
 inline AD<Base> operator Op                                            \
-	(const double &left, const AD<Base> &right)                    \
-{	return AD<Base>(left) Op right; }                              \
+	(const double &left, const AD<Base> &right)                       \
+{	return AD<Base>(left) Op right; }                                 \
                                                                        \
 template <class Base>                                                  \
 inline AD<Base> operator Op                                            \
-	(const double &left, const VecAD_reference<Base> &right)       \
-{	return AD<Base>(left) Op right.ADBase(); }                     \
+	(const double &left, const VecAD_reference<Base> &right)          \
+{	return AD<Base>(left) Op right.ADBase(); }                        \
                                                                        \
 template <class Base>                                                  \
 inline AD<Base> operator Op                                            \
-	(const AD<Base> &left, const double &right)                    \
-{	return left Op AD<Base>(right); }                              \
+	(const AD<Base> &left, const double &right)                       \
+{	return left Op AD<Base>(right); }                                 \
                                                                        \
 template <class Base>                                                  \
 inline AD<Base> operator Op                                            \
-	(const VecAD_reference<Base> &left, const double &right)       \
-{	return left.ADBase() Op AD<Base>(right); }                     \
+	(const VecAD_reference<Base> &left, const double &right)          \
+{	return left.ADBase() Op AD<Base>(right); }                        \
 /* ----------------------------------------------------------------*/  \
 /* Special case to avoid ambuigity when Base is double */              \
                                                                        \
 inline AD<double> operator Op                                          \
-	(const double &left, const AD<double> &right)                  \
-{	return AD<double>(left) Op right; }                            \
+	(const double &left, const AD<double> &right)                     \
+{	return AD<double>(left) Op right; }                               \
                                                                        \
 inline AD<double> operator Op                                          \
-	(const double &left, const VecAD_reference<double> &right)     \
-{	return AD<double>(left) Op right.ADBase(); }                   \
+	(const double &left, const VecAD_reference<double> &right)        \
+{	return AD<double>(left) Op right.ADBase(); }                      \
                                                                        \
 inline AD<double> operator Op                                          \
-	(const AD<double> &left, const double &right)                  \
-{	return left Op AD<double>(right); }                            \
+	(const AD<double> &left, const double &right)                     \
+{	return left Op AD<double>(right); }                               \
                                                                        \
 inline AD<double> operator Op                                          \
-	(const VecAD_reference<double> &left, const double &right)     \
+	(const VecAD_reference<double> &left, const double &right)        \
 {	return left.ADBase() Op AD<double>(right); }
 
 // =======================================================================
@@ -268,79 +285,79 @@ uses the definition of the same operation for that case.
 template <class Base>                                                  \
 inline bool operator Op                                                \
 (const AD<Base> &left, const VecAD_reference<Base> &right)             \
-{	return left Op right.ADBase(); }                               \
+{	return left Op right.ADBase(); }                                  \
                                                                        \
 template <class Base>                                                  \
 inline bool operator Op                                                \
 (const VecAD_reference<Base> &left, const VecAD_reference<Base> &right)\
-{	return left.ADBase() Op right.ADBase(); }                      \
+{	return left.ADBase() Op right.ADBase(); }                         \
                                                                        \
 template <class Base>                                                  \
 inline bool operator Op                                                \
-	(const VecAD_reference<Base> &left, const AD<Base> &right)     \
-{	return left.ADBase() Op right; }                               \
+	(const VecAD_reference<Base> &left, const AD<Base> &right)        \
+{	return left.ADBase() Op right; }                                  \
 /* ----------------------------------------------------------------*/  \
 /* Operations Base */                                                  \
                                                                        \
 template <class Base>                                                  \
 inline bool operator Op                                                \
-	(const Base &left, const AD<Base> &right)                      \
-{	return AD<Base>(left) Op right; }                              \
+	(const Base &left, const AD<Base> &right)                         \
+{	return AD<Base>(left) Op right; }                                 \
                                                                        \
 template <class Base>                                                  \
 inline bool operator Op                                                \
-	(const Base &left, const VecAD_reference<Base> &right)         \
-{	return AD<Base>(left) Op right.ADBase(); }                     \
+	(const Base &left, const VecAD_reference<Base> &right)            \
+{	return AD<Base>(left) Op right.ADBase(); }                        \
                                                                        \
 template <class Base>                                                  \
 inline bool operator Op                                                \
-	(const AD<Base> &left, const Base &right)                      \
-{	return left Op AD<Base>(right); }                              \
+	(const AD<Base> &left, const Base &right)                         \
+{	return left Op AD<Base>(right); }                                 \
                                                                        \
 template <class Base>                                                  \
 inline bool operator Op                                                \
-	(const VecAD_reference<Base> &left, const Base &right)         \
-{	return left.ADBase() Op AD<Base>(right); }                     \
+	(const VecAD_reference<Base> &left, const Base &right)            \
+{	return left.ADBase() Op AD<Base>(right); }                        \
                                                                        \
 /* ----------------------------------------------------------------*/  \
 /* Operations double */                                                \
                                                                        \
 template <class Base>                                                  \
 inline bool operator Op                                                \
-	(const double &left, const AD<Base> &right)                    \
-{	return AD<Base>(left) Op right; }                              \
+	(const double &left, const AD<Base> &right)                       \
+{	return AD<Base>(left) Op right; }                                 \
                                                                        \
 template <class Base>                                                  \
 inline bool operator Op                                                \
-	(const double &left, const VecAD_reference<Base> &right)       \
-{	return AD<Base>(left) Op right.ADBase(); }                     \
+	(const double &left, const VecAD_reference<Base> &right)          \
+{	return AD<Base>(left) Op right.ADBase(); }                        \
                                                                        \
 template <class Base>                                                  \
 inline bool operator Op                                                \
-	(const AD<Base> &left, const double &right)                    \
-{	return left Op AD<Base>(right); }                              \
+	(const AD<Base> &left, const double &right)                       \
+{	return left Op AD<Base>(right); }                                 \
                                                                        \
 template <class Base>                                                  \
 inline bool operator Op                                                \
-	(const VecAD_reference<Base> &left, const double &right)       \
-{	return left.ADBase() Op AD<Base>(right); }                     \
+	(const VecAD_reference<Base> &left, const double &right)          \
+{	return left.ADBase() Op AD<Base>(right); }                        \
 /* ----------------------------------------------------------------*/  \
 /* Special case to avoid ambuigity when Base is double */              \
                                                                        \
 inline bool operator Op                                                \
-	(const double &left, const AD<double> &right)                  \
-{	return AD<double>(left) Op right; }                            \
+	(const double &left, const AD<double> &right)                     \
+{	return AD<double>(left) Op right; }                               \
                                                                        \
 inline bool operator Op                                                \
-	(const double &left, const VecAD_reference<double> &right)     \
-{	return AD<double>(left) Op right.ADBase(); }                   \
+	(const double &left, const VecAD_reference<double> &right)        \
+{	return AD<double>(left) Op right.ADBase(); }                      \
                                                                        \
 inline bool operator Op                                                \
-	(const AD<double> &left, const double &right)                  \
-{	return left Op AD<double>(right); }                            \
+	(const AD<double> &left, const double &right)                     \
+{	return left Op AD<double>(right); }                               \
                                                                        \
 inline bool operator Op                                                \
-	(const VecAD_reference<double> &left, const double &right)     \
+	(const VecAD_reference<double> &left, const double &right)        \
 {	return left.ADBase() Op AD<double>(right); }
 
 # endif
