@@ -1,9 +1,9 @@
-/* $Id: discrete_op.hpp 1641 2010-02-01 16:39:45Z bradbell $ */
+/* $Id: discrete_op.hpp 1986 2011-06-18 20:33:17Z bradbell $ */
 # ifndef CPPAD_DISCRETE_OP_INCLUDED
 # define CPPAD_DISCRETE_OP_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -43,19 +43,19 @@ i.e. the row index in \a taylor corresponding to z.
 \param arg
 \a arg[0]
 \n
-variable index corresponding to the argument for this operator;
-i.e. the row index in \a taylor corresponding to x.
+is the index, in the order of the discrete functions defined by the user, 
+for this discrete function.
 \n
 \n
 \a arg[1]
-is the index, in the order of the discrete functions defined by the user, 
-for this discrete function.
+variable index corresponding to the argument for this operator;
+i.e. the row index in \a taylor corresponding to x.
 
 \param nc_taylor
 number of colums in the matrix containing all the Taylor coefficients.
 
 \param taylor
-\b Input: \a taylor [ \a arg[0] * \a nc_taylor + 0 ] 
+\b Input: \a taylor [ \a arg[1] * \a nc_taylor + 0 ] 
 is the zero order Taylor coefficient corresponding to x. 
 \n
 \b Output: \a taylor [ \a i_z * \a nc_taylor + 0 ] 
@@ -64,27 +64,27 @@ is the zero order Taylor coefficient corresponding to z.
 \par Checked Assertions where op is the unary operator with one result:
 \li NumArg(op) == 2
 \li NumRes(op) == 1
-\li \a arg[0] < \a i_z 
+\li \a arg[1] < \a i_z 
 \li \a 0 < \a nc_taylor
 */
 template <class Base>
 inline void forward_dis_op_0(
 	size_t        i_z         ,
-	const size_t* arg         ,
+	const addr_t* arg         ,
 	size_t        nc_taylor   , 
 	Base*         taylor      )
 {	
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(DisOp) == 2 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(DisOp) == 1 );
-	CPPAD_ASSERT_UNKNOWN( arg[0] < i_z );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < i_z );
 	CPPAD_ASSERT_UNKNOWN( 0 < nc_taylor );
 
 	// Taylor coefficients corresponding to argument and result
-	Base* x = taylor + arg[0] * nc_taylor;
+	Base* x = taylor + arg[1] * nc_taylor;
 	Base* z = taylor + i_z * nc_taylor;
 
-	z[0]  = ADDiscrete<Base>::Eval(arg[1], x[0]);
+	z[0]  = discrete<Base>::eval(arg[0], x[0]);
 }
 
 
