@@ -1,8 +1,8 @@
-/* $Id: for_jac_sweep.hpp 1659 2010-03-11 03:48:31Z bradbell $ */
+/* $Id: for_jac_sweep.hpp 2240 2011-12-31 05:33:55Z bradbell $ */
 # ifndef CPPAD_FOR_JAC_SWEEP_INCLUDED
 # define CPPAD_FOR_JAC_SWEEP_INCLUDED
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -11,6 +11,8 @@ the terms of the
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
+# include <set>
+# include <cppad/local/pod_vector.hpp>
 
 CPPAD_BEGIN_NAMESPACE
 /*!
@@ -74,7 +76,6 @@ corresponds to the set with index i in \a var_sparsity.
 \li numvar == play->num_rec_var()
 */
 
-
 template <class Base, class Vector_set>
 void ForJacSweep(
 	size_t                n            ,
@@ -86,8 +87,7 @@ void ForJacSweep(
 	size_t         i_op;
 	size_t        i_var;
 
-	const size_t   *arg = 0;
-	const size_t *arg_0 = 0;
+	const addr_t*   arg = 0;
 
 	size_t            i, j, k;
 
@@ -95,8 +95,8 @@ void ForJacSweep(
 	CPPAD_ASSERT_UNKNOWN( play->num_rec_var()  == numvar );
 	CPPAD_ASSERT_UNKNOWN( var_sparsity.n_set() == numvar );
 
-        // length of the parameter vector (used by CppAD assert macros)
-        const size_t num_par = play->num_rec_par();
+	// length of the parameter vector (used by CppAD assert macros)
+	const size_t num_par = play->num_rec_par();
 
 	// cum_sparsity accumulates sparsity pattern a cummulative sum
 	size_t limit = var_sparsity.end();
@@ -109,10 +109,10 @@ void ForJacSweep(
 	size_t num_vecad_vec   = play->num_rec_vecad_vec();
 	Vector_set  vecad_sparsity;
 	vecad_sparsity.resize(num_vecad_vec, limit);
-	size_t* vecad_ind      = CPPAD_NULL;
+	pod_vector<size_t> vecad_ind;
 	if( num_vecad_vec > 0 )
 	{	size_t length;
-		vecad_ind     = CPPAD_TRACK_NEW_VEC(num_vecad_ind, vecad_ind);
+		vecad_ind.extend(num_vecad_ind);
 		j             = 0;
 		for(i = 0; i < num_vecad_vec; i++)
 		{	// length of this VecAD
@@ -127,15 +127,30 @@ void ForJacSweep(
 		CPPAD_ASSERT_UNKNOWN( j == play->num_rec_vecad_ind() );
 	}
 
+	// work space used by UserOp.
+	typedef std::set<size_t> size_set;
+	const size_t user_q = limit; // maximum element plus one
+	size_set::iterator set_itr;  // iterator for a standard set
+	size_set::iterator set_end;  // end of iterator sequence
+	vector< size_set > user_r;   // sparsity pattern for the argument x
+	vector< size_set > user_s;   // sparisty pattern for the result y
+	size_t user_index = 0;       // indentifier for this user_atomic operation
+	size_t user_id    = 0;       // user identifier for this call to operator
+	size_t user_i     = 0;       // index in result vector
+	size_t user_j     = 0;       // index in argument vector
+	size_t user_m     = 0;       // size of result vector
+	size_t user_n     = 0;       // size of arugment vector
+	// next expected operator in a UserOp sequence
+	enum { user_start, user_arg, user_ret, user_end } user_state = user_start;
+
 # if CPPAD_FOR_JAC_SWEEP_TRACE
 	std::cout << std::endl;
 	CppAD::vector<bool> z_value(limit);
 # endif
 
 	// skip the BeginOp at the beginning of the recording
-        play->start_forward(op, arg, i_op, i_var);
+	play->start_forward(op, arg, i_op, i_var);
 	CPPAD_ASSERT_UNKNOWN( op == BeginOp );
-        arg_0 = arg;
 	while(op != EndOp)
 	{
 		// this op
@@ -171,8 +186,7 @@ void ForJacSweep(
 			// -------------------------------------------------
 
 			case AcosOp:
-			// acos(x) and sqrt(1 - x * x) are computed in pairs
-			// but ivar + 1 should only be used here
+			// sqrt(1 - x * x), acos(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
 			forward_sparse_jacobian_unary_op(
 				i_var, arg[0], var_sparsity
@@ -181,8 +195,7 @@ void ForJacSweep(
 			// -------------------------------------------------
 
 			case AsinOp:
-			// asin(x) and sqrt(1 - x * x) are computed in pairs
-			// but ivar + 1 should only be used here
+			// sqrt(1 - x * x), asin(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
 			forward_sparse_jacobian_unary_op(
 				i_var, arg[0], var_sparsity
@@ -191,8 +204,7 @@ void ForJacSweep(
 			// -------------------------------------------------
 
 			case AtanOp:
-			// atan(x) and 1 + x * x must be computed in pairs
-			// but ivar + 1 should only be used here
+			// 1 + x * x, atan(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
 			forward_sparse_jacobian_unary_op(
 				i_var, arg[0], var_sparsity
@@ -225,8 +237,7 @@ void ForJacSweep(
 			// --------------------------------------------------
 
 			case CosOp:
-			// cosine and sine must come in pairs
-			// but ivar should only be used here
+			// sin(x), cos(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
 			forward_sparse_jacobian_unary_op(
 				i_var, arg[0], var_sparsity
@@ -235,8 +246,7 @@ void ForJacSweep(
 			// ---------------------------------------------------
 
 			case CoshOp:
-			// hyperbolic cosine and sine must come in pairs
-			// but ivar should only be used here
+			// sinh(x), cosh(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
 			forward_sparse_jacobian_unary_op(
 				i_var, arg[0], var_sparsity
@@ -299,7 +309,7 @@ void ForJacSweep(
 				i_var,
 				arg,
 				num_vecad_ind,
-				vecad_ind,
+				vecad_ind.data(),
 				var_sparsity,
 				vecad_sparsity
 			);
@@ -312,7 +322,7 @@ void ForJacSweep(
 				i_var,
 				arg,
 				num_vecad_ind,
-				vecad_ind,
+				vecad_ind.data(),
 				var_sparsity,
 				vecad_sparsity
 			);
@@ -373,20 +383,21 @@ void ForJacSweep(
 			break;
 			// -------------------------------------------------
 
-			case PripOp:
-			CPPAD_ASSERT_NARG_NRES(op, 2, 0);
-			var_sparsity.clear(i_var);
+			case PriOp:
+			CPPAD_ASSERT_NARG_NRES(op, 5, 0);
 			break;
 			// -------------------------------------------------
 
-			case PrivOp:
-			CPPAD_ASSERT_NARG_NRES(op, 2, 0);
+			case SignOp:
+			CPPAD_ASSERT_NARG_NRES(op, 1, 1);
+			forward_sparse_jacobian_unary_op(
+				i_var, arg[0], var_sparsity
+			);
 			break;
 			// -------------------------------------------------
 
 			case SinOp:
-			// sine and cosine must come in pairs
-			// but ivar should only be used here
+			// cos(x), sin(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
 			forward_sparse_jacobian_unary_op(
 				i_var, arg[0], var_sparsity
@@ -395,8 +406,7 @@ void ForJacSweep(
 			// -------------------------------------------------
 
 			case SinhOp:
-			// hyperbolic sine and cosine must come in pairs
-			// but ivar should only be used here
+			// cosh(x), sinh(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
 			forward_sparse_jacobian_unary_op(
 				i_var, arg[0], var_sparsity
@@ -423,7 +433,7 @@ void ForJacSweep(
 				op,
 				arg,
 				num_vecad_ind,
-				vecad_ind,
+				vecad_ind.data(),
 				var_sparsity,
 				vecad_sparsity
 			);
@@ -441,7 +451,7 @@ void ForJacSweep(
 				op,
 				arg,
 				num_vecad_ind,
-				vecad_ind,
+				vecad_ind.data(),
 				var_sparsity,
 				vecad_sparsity
 			);
@@ -472,6 +482,116 @@ void ForJacSweep(
 			break;
 			// -------------------------------------------------
 
+			case TanOp:
+			// tan(x)^2, tan(x)
+			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
+			forward_sparse_jacobian_unary_op(
+				i_var, arg[0], var_sparsity
+			);
+			break;
+			// -------------------------------------------------
+
+			case TanhOp:
+			// tanh(x)^2, tanh(x)
+			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
+			forward_sparse_jacobian_unary_op(
+				i_var, arg[0], var_sparsity
+			);
+			break;
+			// -------------------------------------------------
+
+			case UserOp:
+			// start or end an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( NumRes( UserOp ) == 0 );
+			CPPAD_ASSERT_UNKNOWN( NumArg( UserOp ) == 4 );
+			if( user_state == user_start )
+			{	user_index = arg[0];
+				user_id    = arg[1];
+				user_n     = arg[2];
+				user_m     = arg[3];
+				if(user_r.size() < user_n )
+					user_r.resize(user_n);
+				if(user_s.size() < user_m )
+					user_s.resize(user_m);
+				user_j     = 0;
+				user_i     = 0;
+				user_state = user_arg;
+			}
+			else
+			{	CPPAD_ASSERT_UNKNOWN( user_state == user_end );
+				CPPAD_ASSERT_UNKNOWN( user_index == size_t(arg[0]) );
+				CPPAD_ASSERT_UNKNOWN( user_id    == size_t(arg[1]) );
+				CPPAD_ASSERT_UNKNOWN( user_n     == size_t(arg[2]) );
+				CPPAD_ASSERT_UNKNOWN( user_m     == size_t(arg[3]) );
+				user_state = user_start;
+			}
+			break;
+
+			case UsrapOp:
+			// parameter argument in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_arg );
+			CPPAD_ASSERT_UNKNOWN( user_j < user_n );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
+			// parameters have an empty sparsity pattern
+			user_r[user_j].clear();
+			++user_j;
+			if( user_j == user_n )
+			{	// call users function for this operation
+				user_atomic<Base>::for_jac_sparse(user_index, user_id,
+					user_n, user_m, user_q, user_r, user_s
+				);
+				user_state = user_ret;
+			}
+			break;
+
+			case UsravOp:
+			// variable argument in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_arg );
+			CPPAD_ASSERT_UNKNOWN( user_j < user_n );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) <= i_var );
+			// set user_r[user_j] to sparsity pattern for variable arg[0]
+			user_r[user_j].clear();
+			var_sparsity.begin(arg[0]);
+			i = var_sparsity.next_element();
+			while( i < user_q )
+			{	user_r[user_j].insert(i);
+				i = var_sparsity.next_element();
+			}
+			++user_j;
+			if( user_j == user_n )
+			{	// call users function for this operation
+				user_atomic<Base>::for_jac_sparse(user_index, user_id,
+					user_n, user_m, user_q, user_r, user_s
+				);
+				user_state = user_ret;
+			}
+			break;
+
+			case UsrrpOp:
+			// parameter result in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_ret );
+			CPPAD_ASSERT_UNKNOWN( user_i < user_m );
+			user_i++;
+			if( user_i == user_m )
+				user_state = user_end;
+			break;
+
+			case UsrrvOp:
+			// variable result in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_ret );
+			CPPAD_ASSERT_UNKNOWN( user_i < user_m );
+			// It might be faster if we add set union to var_sparsity
+			// where one of the sets is not in var_sparsity
+			set_itr = user_s[user_i].begin();
+			set_end = user_s[user_i].end();
+			while( set_itr != set_end )
+				var_sparsity.add_element(i_var, *set_itr++);
+			user_i++;
+			if( user_i == user_m )
+				user_state = user_end;
+			break;
+			// -------------------------------------------------
+
 			default:
 			CPPAD_ASSERT_UNKNOWN(0);
 		}
@@ -503,13 +623,12 @@ void ForJacSweep(
 # endif
 	CPPAD_ASSERT_UNKNOWN( i_var + 1 == play->num_rec_var() );
 
-	if( vecad_ind != CPPAD_NULL )
-		CPPAD_TRACK_DEL_VEC(vecad_ind);
-
 	return;
 }
 
+CPPAD_END_NAMESPACE
+
+// preprocessor symbols that are local to this file
 # undef CPPAD_FOR_JAC_SWEEP_TRACE
 
-CPPAD_END_NAMESPACE
 # endif
