@@ -1,9 +1,9 @@
-/* $Id: fun_construct.hpp 1641 2010-02-01 16:39:45Z bradbell $ */
+/* $Id: fun_construct.hpp 2085 2011-09-01 14:54:04Z bradbell $ */
 # ifndef CPPAD_FUN_CONSTRUCT_INCLUDED
 # define CPPAD_FUN_CONSTRUCT_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -15,6 +15,8 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 /*
 $begin FunConstruct$$
 $spell 
+	alloc
+	num
 	Jac
 	bool
 	taylor_
@@ -189,13 +191,10 @@ $codei%
 	%g%.size_forward_set()  == %f%.size_forward_set()
 %$$
 
-$head OpenMP$$
-$index OpenMP, Dependent$$
-$index Dependent, OpenMP$$
-$index OpenMP, ADFun$$
-$index ADFun, OpenMP$$
-In the case of multi-threading with OpenMP,
-the call to $code Independent$$
+$head Parallel Mode$$
+$index parallel, ADFun$$
+$index ADFun, parallel$$
+The call to $code Independent$$,
 and the corresponding call to
 $codei%
 	ADFun<%Base%> %f%( %x%, %y%)
@@ -204,8 +203,9 @@ or
 $codei%
 	%f%.Dependent( %x%, %y%)
 %$$
-must be preformed by the same thread.
-
+or $cref abort_recording$$,
+must be preformed by the same thread; i.e.,
+$cref/thread_alloc::thread_num/ta_thread_num/$$ must be the same.
 
 $head Example$$
 
@@ -261,7 +261,7 @@ i.e., operation sequences that were recorded using the type \c AD<Base>.
 */
 template <typename Base>
 ADFun<Base>::ADFun(void)
-: total_num_var_(0), taylor_(CPPAD_NULL)
+: total_num_var_(0)
 { }
 
 /*!
@@ -291,8 +291,11 @@ void ADFun<Base>::operator=(const ADFun<Base>& f)
 	// go through member variables in order
 	// (see ad_fun.hpp for meaning of each variable)
 	compare_change_            = 0;
+
+	taylor_.erase();
 	taylor_per_var_            = 0;
 	taylor_col_dim_            = 0;
+
 	total_num_var_             = f.total_num_var_;
 	ind_taddr_.resize(n);
 	ind_taddr_                 = f.ind_taddr_;
@@ -301,9 +304,6 @@ void ADFun<Base>::operator=(const ADFun<Base>& f)
 	dep_parameter_.resize(m);
 	dep_parameter_             = f.dep_parameter_;
 	play_                      = f.play_;
-	if( taylor_ != CPPAD_NULL )
-		CPPAD_TRACK_DEL_VEC(taylor_);
-	taylor_                    = CPPAD_NULL;
 	for_jac_sparse_pack_.resize(0, 0);
 	for_jac_sparse_set_.resize(0, 0);
 
@@ -311,7 +311,8 @@ void ADFun<Base>::operator=(const ADFun<Base>& f)
 	taylor_per_var_     = f.taylor_per_var_;
 	taylor_col_dim_     = f.taylor_col_dim_;
 	size_t length       = total_num_var_ * taylor_col_dim_;
-	if( length > 0 ) taylor_   = CPPAD_TRACK_NEW_VEC(length, taylor_);
+	if( length > 0 )
+		taylor_.extend(length);
 	size_t i, j;
 	for(i = 0; i < total_num_var_; i++)
 	{	for(j = 0; j < taylor_per_var_; j++)
@@ -389,7 +390,7 @@ are stored in this ADFun object.
 template <typename Base>
 template <typename VectorAD>
 ADFun<Base>::ADFun(const VectorAD &x, const VectorAD &y)
-: total_num_var_(0), taylor_(CPPAD_NULL)
+: total_num_var_(0)
 {
 	CPPAD_ASSERT_KNOWN(
 		x.size() > 0,
@@ -409,7 +410,7 @@ ADFun<Base>::ADFun(const VectorAD &x, const VectorAD &y)
 	size_t i, m = y.size();
 	for(j = 0; j < n; j++)
 	{	CPPAD_ASSERT_KNOWN(
-		x[j].taddr_ == (j+1),
+		size_t(x[j].taddr_) == (j+1),
 		"ADFun<Base>: independent variable vector has been changed."
 		);
 		CPPAD_ASSERT_KNOWN(
@@ -432,31 +433,32 @@ ADFun<Base>::ADFun(const VectorAD &x, const VectorAD &y)
 	// allocate memory for one zero order taylor_ coefficient
 	taylor_per_var_  = 1;
 	taylor_col_dim_  = 1;
-	taylor_          = CPPAD_TRACK_NEW_VEC(total_num_var_, taylor_);
+	taylor_.extend(total_num_var_);
 
 	// set zero order coefficients corresponding to indpendent variables
 	CPPAD_ASSERT_UNKNOWN( n == ind_taddr_.size() );
 	for(j = 0; j < n; j++)
 	{	CPPAD_ASSERT_UNKNOWN( ind_taddr_[j] == (j+1) );
-		CPPAD_ASSERT_UNKNOWN( x[j].taddr_  == (j+1) );
+		CPPAD_ASSERT_UNKNOWN( size_t(x[j].taddr_) == (j+1) );
 		taylor_[ ind_taddr_[j] ]  = x[j].value_;
 	}
 
 	// use independent variable values to fill in values for others
 # if CPPAD_USE_FORWARD0SWEEP
-	compare_change_ = forward0sweep(
-		false, n, total_num_var_, &play_, taylor_col_dim_, taylor_
+	compare_change_ = forward0sweep(std::cout, false,
+		n, total_num_var_, &play_, taylor_col_dim_, taylor_.data()
 	);
 # else
 	size_t p = 0;
-	compare_change_ = forward_sweep(
-		false, p, n, total_num_var_, &play_, taylor_col_dim_, taylor_
+	compare_change_ = forward_sweep(std::cout, false,
+		p, n, total_num_var_, &play_, taylor_col_dim_, taylor_.data()
 	);
 # endif
 	CPPAD_ASSERT_UNKNOWN( compare_change_ == 0 );
 
 # ifndef NDEBUG
-	for(i = 0; i < m; i++) if( taylor_[dep_taddr_[i]] != y[i].value_ )
+	for(i = 0; i < m; i++) 
+	if( taylor_[dep_taddr_[i]] != y[i].value_ || isnan( y[i].value_ ) )
 	{	using std::endl;
 		std::ostringstream buf;
 		buf << "A dependent variable value is not equal to "
