@@ -1,9 +1,9 @@
-/* $Id: hash_code.hpp 1641 2010-02-01 16:39:45Z bradbell $ */
+/* $Id: hash_code.hpp 2111 2011-09-27 13:42:06Z bradbell $ */
 # ifndef CPPAD_HASH_CODE_INCLUDED
 # define CPPAD_HASH_CODE_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -24,7 +24,7 @@ CppAD hashing utility.
 the codes retruned by hash_code are between zero and CPPAD_HASH_TABLE_SIZE 
 minus one. 
 */
-# define CPPAD_HASH_TABLE_SIZE 65536
+# define CPPAD_HASH_TABLE_SIZE 10000
 
 /*!
 General purpose hash code for an arbitrary value.
@@ -42,7 +42,7 @@ the value that we are generating a hash code for.
 is a hash code that is between zero and CPPAD_HASH_TABLE_SIZE - 1.
 
 \par Checked Assertions
-\li \c std::numeric_limits<unsigned short>::max() == CPPAD_HASH_TABLE_SIZE - 1
+\li \c std::numeric_limits<unsigned short>::max() >= CPPAD_HASH_TABLE_SIZE
 \li \c sizeof(value) is even 
 \li \c sizeof(unsigned short)  == 2
 */
@@ -51,24 +51,23 @@ template <class Value>
 unsigned short hash_code(const Value& value)
 {	CPPAD_ASSERT_UNKNOWN( 
 		std::numeric_limits<unsigned short>::max()
-		==
-		(CPPAD_HASH_TABLE_SIZE-1)
+		>=
+		CPPAD_HASH_TABLE_SIZE
 	);
 	CPPAD_ASSERT_UNKNOWN( sizeof(unsigned short) == 2 );
 	CPPAD_ASSERT_UNKNOWN( sizeof(value) % 2  == 0 );
-	static unsigned short n   = sizeof(value) / 2;
-
-	const unsigned short* v;
-	size_t                i;
-	unsigned short        code;
-
-	v    = reinterpret_cast<const unsigned short*>(& value);
-	i    = n - 1;
-	code = v[i];
+	#
+	const unsigned short* v
+	         = reinterpret_cast<const unsigned short*>(& value);
+	#
+	size_t i = sizeof(value) / 2 - 1;
+	#
+	unsigned short code = v[i];
+	#
 	while(i--)
 		code += v[i];
 
-	return code;
+	return code % CPPAD_HASH_TABLE_SIZE;
 }
 
 /*!
@@ -81,7 +80,7 @@ hash coded and zero is returned:
 
 \li unary operators:
 AbsOp, AcosOp, AsinOp, AtanOp, CosOp, CoshOp, DisOp,
-ExpOp, LogOp, SinOp, SinhOp, SqrtOp
+ExpOp, LogOp, SinOp, SinhOp, SqrtOp, TanOp, TanhOp
 
 \li binary operators where first argument is a parameter:
 AddpvOp, DivpvOp, MulpvOp, PowpvOp, SubpvOp, 
@@ -111,7 +110,7 @@ is a hash code that is between zero and CPPAD_HASH_TABLE_SIZE - 1.
 
 \par Checked Assertions
 \c op must be one of the operators specified above. In addition,
-\li \c std::numeric_limits<unsigned short>::max() == CPPAD_HASH_TABLE_SIZE - 1
+\li \c std::numeric_limits<unsigned short>::max() >= CPPAD_HASH_TABLE_SIZE 
 \li \c sizeof(size_t) is even 
 \li \c sizeof(Base) is even 
 \li \c sizeof(unsigned short)  == 2
@@ -122,25 +121,25 @@ is a hash code that is between zero and CPPAD_HASH_TABLE_SIZE - 1.
 template <class Base>
 unsigned short hash_code(
 	OpCode        op      , 
-	const size_t* arg     , 
+	const addr_t* arg     , 
 	size_t npar           , 
 	const Base* par       )
 {	CPPAD_ASSERT_UNKNOWN( 
 		std::numeric_limits<unsigned short>::max()
-		==
-		(CPPAD_HASH_TABLE_SIZE-1)
+		>=
+		CPPAD_HASH_TABLE_SIZE
 	);
 	CPPAD_ASSERT_UNKNOWN( size_t (op) <= size_t(SubvvOp) );
 	CPPAD_ASSERT_UNKNOWN( sizeof(unsigned short) == 2 );
-	CPPAD_ASSERT_UNKNOWN( sizeof(size_t) % 2  == 0 );
+	CPPAD_ASSERT_UNKNOWN( sizeof(addr_t) % 2  == 0 );
 	CPPAD_ASSERT_UNKNOWN( sizeof(Base) % 2  == 0 );
-	static unsigned short op_fac = static_cast<unsigned short> (
+	unsigned short op_fac = static_cast<unsigned short> (
 	CPPAD_HASH_TABLE_SIZE / ( 1 + static_cast<unsigned short>(SubvvOp) ) 
 	);
 	CPPAD_ASSERT_UNKNOWN( op_fac > 0 );
 
-	// number of shorts per size_t value
-	size_t short_size_t   = sizeof(size_t) / 2;
+	// number of shorts per addr_t value
+	size_t short_addr_t   = sizeof(addr_t) / 2;
 
 	// number of shorts per Base value
 	size_t short_base     = sizeof(Base) /  2;
@@ -171,7 +170,7 @@ unsigned short hash_code(
 		while(i--)
 			code += v[i];
 		v = reinterpret_cast<const unsigned short*>(arg + 1);
-		i = short_size_t;
+		i = short_addr_t;
 		while(i--)
 			code += v[i];
 		break;
@@ -184,7 +183,7 @@ unsigned short hash_code(
 		case SubvvOp:
 		CPPAD_ASSERT_UNKNOWN( NumArg(op) == 2 );
 		v = reinterpret_cast<const unsigned short*>(arg + 0);
-		i = 2 * short_size_t;
+		i = 2 * short_addr_t;
 		while(i--)
 			code += v[i];
 		break;
@@ -195,7 +194,7 @@ unsigned short hash_code(
 		case SubvpOp:
 		CPPAD_ASSERT_UNKNOWN( NumArg(op) == 2 );
 		v = reinterpret_cast<const unsigned short*>(arg + 0);
-		i = short_size_t;
+		i = short_addr_t;
 		while(i--)
 			code += v[i];
 		v = reinterpret_cast<const unsigned short*>(par + arg[1]);
@@ -217,8 +216,10 @@ unsigned short hash_code(
 		case SinOp:
 		case SinhOp:
 		case SqrtOp:
+		case TanOp:
+		case TanhOp:
 		v = reinterpret_cast<const unsigned short*>(arg + 0);
-		i = short_size_t;
+		i = short_addr_t;
 		while(i--)
 			code += v[i];
 		break;
@@ -228,7 +229,7 @@ unsigned short hash_code(
 		CPPAD_ASSERT_UNKNOWN(false);
 	}
 
-	return code;
+	return code % CPPAD_HASH_TABLE_SIZE;
 }
 
 CPPAD_END_NAMESPACE
