@@ -1,9 +1,9 @@
-/* $Id: op_code.hpp 1659 2010-03-11 03:48:31Z bradbell $ */
+/* $Id: op_code.hpp 2240 2011-12-31 05:33:55Z bradbell $ */
 # ifndef CPPAD_OP_CODE_INCLUDED
 # define CPPAD_OP_CODE_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -17,6 +17,10 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <iomanip>
 
 # include <cppad/local/define.hpp>
+# include <cppad/local/cppad_assert.hpp>
+
+// needed before one can use CPPAD_ASSERT_FIRST_CALL_NOT_PARALLEL
+# include <cppad/thread_alloc.hpp>
 
 CPPAD_BEGIN_NAMESPACE
 /*! 
@@ -54,34 +58,42 @@ enum OpCode {
 	CosOp,    //  cos(variable)
 	CoshOp,   // cosh(variable)
 	CSumOp,   // Cummulative summation (has variable number of arguments)
-	DisOp,    //  dis(variable,    index)
+	DisOp,    //  discrete::eval(index, variable)
 	DivpvOp,  //      parameter  / variable
 	DivvpOp,  //      variable   / parameter
 	DivvvOp,  //      variable   / variable
 	EndOp,    //  used to mark the end of the tape
 	ExpOp,    //  exp(variable)
+	InvOp,    //                             independent variable
 	LdpOp,    //    z[parameter]
 	LdvOp,    //    z[variable]
-	InvOp,    //                             independent variable
 	LogOp,    //  log(variable)
 	MulpvOp,  //      parameter  * variable
 	MulvvOp,  //      variable   * variable
 	ParOp,    //      parameter
-	PowvpOp,  //  pow(variable,    parameter)
 	PowpvOp,  //  pow(parameter,   variable)
+	PowvpOp,  //  pow(variable,    parameter)
 	PowvvOp,  //  pow(variable,    variable)
-	PripOp,   //      text         parameter
-	PrivOp,   //      text         parameter
+	PriOp,    //  PrintFor(text, parameter or variable, parameter or variable)
+	SignOp,   // sign(variable)
 	SinOp,    //  sin(variable)
 	SinhOp,   // sinh(variable)
 	SqrtOp,   // sqrt(variable)
 	StppOp,   //    z[parameter] = parameter
-	StvpOp,   //    z[variable]  = parameter
 	StpvOp,   //    z[parameter] = variable
+	StvpOp,   //    z[variable]  = parameter
 	StvvOp,   //    z[variable]  = variable
 	SubpvOp,  //      parameter  - variable
 	SubvpOp,  //      variable   - parameter
-	SubvvOp   //      variable   - variable
+	SubvvOp,  //      variable   - variable
+	TanOp,    //  tan(variable)
+	TanhOp,   //  tan(variable)
+	// user atomic operation codes (note yet implemented)
+	UserOp,   //  start of a user atomic operaiton
+	UsrapOp,  //  this user atomic argument is a parameter
+	UsravOp,  //  this user atomic argument is a variable
+	UsrrpOp,  //  this user atomic result is a parameter
+	UsrrvOp   //  this user atomic result is a variable
 };
 
 /*!
@@ -117,28 +129,35 @@ const size_t NumArgTable[] = {
 	2, // DivvvOp
 	0, // EndOp
 	1, // ExpOp
+	0, // InvOp
 	3, // LdpOp
 	3, // LdvOp
-	0, // InvOp
 	1, // LogOp
-	2, // MulvvOp
 	2, // MulpvOp
+	2, // MulvvOp
 	1, // ParOp
-	2, // PowvpOp
 	2, // PowpvOp
+	2, // PowvpOp
 	2, // PowvvOp
-	2, // PripOp
-	2, // PrivOp
+	5, // PriOp
+	1, // SignOp
 	1, // SinOp
 	1, // SinhOp
 	1, // SqrtOp
 	3, // StppOp
-	3, // StvpOp
 	3, // StpvOp
+	3, // StvpOp
 	3, // StvvOp
 	2, // SubpvOp
 	2, // SubvpOp
-	2  // SubvvOp
+	2, // SubvvOp
+	1, // TanOp
+	1, // TanhOp
+	4, // UserOp
+	1, // UsrapOp
+	1, // UsravOp
+	1, // UsrrpOp
+	0  // UsrrvOp
 };
 
 /*!
@@ -149,13 +168,28 @@ Number of arguments corresponding to the specified operator.
 
 \param op 
 Operator for which we are fetching the number of arugments.
+
+- Check that \c UsrrvOp is the last defined operator.
+- Check that \c CPPAD_OP_CODE_TYPE can support all the operator codes.
+- Check that \c op is a valid operator value.
 */
 inline size_t NumArg( OpCode op)
-{
-	CPPAD_ASSERT_UNKNOWN( size_t(SubvvOp) == 
-		sizeof(NumArgTable) / sizeof(NumArgTable[0]) - 1
-	);
-	CPPAD_ASSERT_UNKNOWN( size_t(op) <= size_t(SubvvOp) );
+{	CPPAD_ASSERT_FIRST_CALL_NOT_PARALLEL;
+# ifndef NDEBUG
+	// only do these checks once to save time
+	static bool first = true;
+	if( first )
+	{	CPPAD_ASSERT_UNKNOWN( size_t(UsrrvOp) == 
+			sizeof(NumArgTable) / sizeof(NumArgTable[0]) - 1
+		);
+		CPPAD_ASSERT_UNKNOWN( size_t(UsrrvOp) <=
+			std::numeric_limits<CPPAD_OP_CODE_TYPE>::max()
+		);
+		first = false;
+	}
+	// do this check every time
+	CPPAD_ASSERT_UNKNOWN( size_t(op) <= size_t(UsrrvOp) );
+# endif
 
 	return NumArgTable[(size_t) op];
 }
@@ -193,29 +227,36 @@ const size_t NumResTable[] = {
 	1, // DivvvOp
 	0, // EndOp
 	1, // ExpOp
+	1, // InvOp
 	1, // LdpOp
 	1, // LdvOp
-	1, // InvOp
 	1, // LogOp
-	1, // MulvvOp
 	1, // MulpvOp
+	1, // MulvvOp
 	1, // ParOp
-	3, // PowvpOp
 	3, // PowpvOp
+	3, // PowvpOp
 	3, // PowvvOp
-	0, // PripOp
-	0, // PrivOp
+	0, // PriOp
+	1, // SignOp
 	2, // SinOp
 	2, // SinhOp
 	1, // SqrtOp
 	0, // StppOp
-	0, // StvpOp
 	0, // StpvOp
+	0, // StvpOp
 	0, // StvvOp
 	1, // SubpvOp
 	1, // SubvpOp
 	1, // SubvvOp
-	0  // Not used: avoids warning by g++ 4.3.2 when pycppad builds
+	2, // TanOp
+	2, // TanhOp
+	0, // UserOp
+	0, // UsrapOp
+	0, // UsravOp
+	0, // UsrrpOp
+	1, // UsrrvOp
+	0  // Last entry not used: avoids warning by g++ 4.3.2 when pycppad builds
 };
 
 /*!
@@ -229,11 +270,11 @@ Operator for which we are fetching the number of result variables.
 */
 inline size_t NumRes(OpCode op)
 {	// check ensuring conversion to size_t is as expected
-	CPPAD_ASSERT_UNKNOWN( size_t(SubvvOp) == 
+	CPPAD_ASSERT_UNKNOWN( size_t(UsrrvOp) == 
 		sizeof(NumResTable) / sizeof(NumResTable[0]) - 2
 	);
 	// this test ensures that all indices are within the table
-	CPPAD_ASSERT_UNKNOWN( size_t(op) <= size_t(SubvvOp) );
+	CPPAD_ASSERT_UNKNOWN( size_t(op) <= size_t(UsrrvOp) );
 
 	return NumResTable[(size_t) op];
 }
@@ -355,13 +396,17 @@ void printOp(
 	const player<Base>   *Rec     ,
 	size_t                 i_var  , 
 	OpCode                 op     ,
-	const size_t          *ind    ,
+	const addr_t          *ind    ,
 	size_t                 nfz    ,
 	const  Value          *fz     ,
 	size_t                 nrz    ,
 	const  Value          *rz     )
 {	size_t i;
 	
+	CPPAD_ASSERT_KNOWN(
+		! thread_alloc::in_parallel() ,
+		"cannot print trace of AD operations in parallel mode"
+	);
 	static const char *CompareOpName[] = 
 		{ "Lt", "Le", "Eq", "Ge", "Gt", "Ne" };
 	static const char *OpName[] = {
@@ -377,37 +422,44 @@ void printOp(
 		"Cos"   ,
 		"Cosh"  ,
 		"CSum"  ,
-		"DisOp" ,
+		"Dis"   ,
 		"Divpv" ,
 		"Divvp" ,
 		"Divvv" ,
 		"End"   ,
 		"Exp"   ,
+		"Inv"   ,
 		"Ldp"   ,
 		"Ldv"   ,
-		"Inv"   ,
 		"Log"   ,
 		"Mulpv" ,
 		"Mulvv" ,
 		"Par"   ,
-		"Powvp" ,
 		"Powpv" ,
+		"Powvp" ,
 		"Powvv" ,
-		"Prip"  ,
-		"Priv"  ,
+		"Pri"   ,
+		"Sign"  ,
 		"Sin"   ,
 		"Sinh"  ,
 		"Sqrt"  ,
 		"Stpp"  ,
-		"Stvp"  ,
 		"Stpv"  ,
+		"Stvp"  ,
 		"Stvv"  ,
 		"Subpv" ,
 		"Subvp" ,
-		"Subvv"
+		"Subvv" ,
+		"Tan"   ,
+		"Tanh"  ,
+		"User"  ,
+		"Usrap" ,
+		"Usrav" ,
+		"Usrrp" ,
+		"Usrrv"
 	};
 	CPPAD_ASSERT_UNKNOWN( 
-		size_t(SubvvOp) == sizeof(OpName) / sizeof(OpName[0]) - 1
+		size_t(UsrrvOp) == sizeof(OpName) / sizeof(OpName[0]) - 1
 	);
 
 	// print operator
@@ -519,40 +571,59 @@ void printOp(
 		case CoshOp:
 		case ExpOp:
 		case LogOp:
+		case SignOp:
 		case SinOp:
 		case SinhOp:
 		case SqrtOp:
+		case UsravOp:
+		case TanOp:
+		case TanhOp:
 		CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
 		printOpField(os, "  v=", ind[0], ncol);
 		break;
 
 		case ParOp:
+		case UsrapOp:
+		case UsrrpOp:
 		CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
 		printOpField(os, "  p=", Rec->GetPar(ind[0]), ncol);
 		break;
 
-		case PripOp:
-		CPPAD_ASSERT_UNKNOWN( NumArg(op) == 2 );
-		os << "txt=\"" << Rec->GetTxt(ind[0]);
-		os << "\"  p=" << Rec->GetPar(ind[1]);
+		case UserOp:
+		CPPAD_ASSERT_UNKNOWN( NumArg(op) == 4 );
+		{	const char* name = user_atomic<Base>::name(ind[0]);
+			printOpField(os, " f=",   name, ncol);
+			printOpField(os, " i=", ind[1], ncol);
+			printOpField(os, " n=", ind[2], ncol);
+			printOpField(os, " m=", ind[3], ncol);
+		}
 		break;
 
-		case PrivOp:
-		CPPAD_ASSERT_UNKNOWN( NumArg(op) == 2 );
-		os << "txt=\"" << Rec->GetTxt(ind[0]);
-		os << "\"  v=" << ind[1];
+		case PriOp:
+		CPPAD_ASSERT_NARG_NRES(op, 5, 0);
+		if( ind[0] & 1 )
+			printOpField(os, " v=", ind[1], ncol);
+		else	printOpField(os, " p=", Rec->GetPar(ind[1]), ncol);
+		os << "before=\"" << Rec->GetTxt(ind[2]) << "\"";
+		if( ind[0] & 2 )
+			printOpField(os, " v=", ind[3], ncol);
+		else	printOpField(os, " p=", Rec->GetPar(ind[3]), ncol);
+		os << "after=\"" << Rec->GetTxt(ind[4]) << "\"";
 		break;
 
 		case BeginOp:
 		case EndOp:
 		case InvOp:
+		case UsrrvOp:
 		CPPAD_ASSERT_UNKNOWN( NumArg(op) == 0 );
 		break;
 
 		case DisOp:
 		CPPAD_ASSERT_UNKNOWN( NumArg(op) == 2 );
-		printOpField(os, "  v=", ind[0], ncol);
-		printOpField(os, "  f=", ind[1], ncol);
+		{	const char* name = discrete<Base>::name(ind[0]);
+			printOpField(os, " f=", name, ncol);
+			printOpField(os, " x=", ind[1], ncol);
+		}
 		break;
 	
 
