@@ -1,9 +1,9 @@
-/* $Id: optimize.hpp 1661 2010-03-11 12:04:15Z bradbell $ */
+/* $Id: optimize.hpp 2233 2011-12-20 19:34:24Z bradbell $ */
 # ifndef CPPAD_OPTIMIZE_INCLUDED
 # define CPPAD_OPTIMIZE_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -22,7 +22,7 @@ $spell
 	cppad
 $$
 
-$section Optimize the Tape Corresponding to an ADFun object$$
+$section Optimize an ADFun Object Tape$$
 
 $index optimize$$
 $index tape, optimize$$
@@ -36,12 +36,12 @@ $icode%f%.optimize()%$$
 
 
 $head Purpose$$
-The operation sequence corresponding to an $cref/ADFun/$$ object can
+The operation sequence corresponding to an $cref ADFun$$ object can
 be very large and involve many operations; see the
-size functions in $cref/seq_property/$$.
-This enables one to reduce the number of operations
-and thereby reduce the time and the memory required to
-compute function and derivative values using an $code ADFun$$ object.
+size functions in $cref seq_property$$.
+The $icode%f%.optimize%$$ procedure reduces the number of operations,
+and thereby the time and the memory, required to
+compute function and derivative values. 
 
 $head f$$
 The object $icode f$$ has prototype
@@ -59,28 +59,17 @@ derivatives using the original operation sequence.
 
 $subhead Testing$$
 You can run the CppAD $cref/speed/speed_main/$$ tests and see
-the corresponding changes in number of variables and execution time.
-After the $cref/make test/InstallUnix/make test/$$ command
-is run in the $code speed/cppad$$ directory,
-you can run the speed tests with optimization 
-using the command
-$codep
-	speed/cppad/cppad speed 123 optimize
-$$ 
-and without optimization using the command
-$codep
-	speed/cppad/cppad speed 123 
-$$
-Note that $code 123$$ is used for a random number seed and can be
-replaced by any integer in the commands above.
+the corresponding changes in number of variables and execution time; see
+the speed tests in the install instructions
+$cref/Examples and Tests/InstallUnix/make/Examples and Tests/$$ list.
 
 $head Efficiency$$
 The $code optimize$$ member function
 may greatly reduce the number of variables 
 in the operation sequence; see $cref/size_var/seq_property/size_var/$$.
 If a $cref/zero order forward/ForwardZero/$$ calculation is done during
-the construction of f, it will require more memory
-and time that after the optimization procedure.
+the construction of $icode f$$, it will require more memory
+and time than required after the optimization procedure.
 In addition, it will need to be redone.
 For this reason, it is more efficient to use 
 $codei%
@@ -98,18 +87,18 @@ $cref/sequence constructors/FunConstruct/Sequence Constructor/$$.
 
 $head Comparison Operators$$
 Any comparison operators that are in the tape are removed by this operation.
-Hence the return value of $cref/CompareChange/$$ will always be zero
+Hence the return value of $cref CompareChange$$ will always be zero
 for an optimized tape (even if $code NDEBUG$$ is not defined).
 
 $head Checking Optimization$$
 $index NDEBUG$$
-If $code NDEBUG$$ is not defined
+If $cref/NDEBUG/Faq/Speed/NDEBUG/$$ is not defined,
 and $cref/f.size_taylor()/size_taylor/$$ is greater than zero,
-a $cref/ForwardZero/$$ calculation is done using the optimized version
+a $cref ForwardZero$$ calculation is done using the optimized version
 of $icode f$$ and the results are checked to see that they are
 the same as before.
 If they are not the same, the
-$cref/ErrorHandler/$$ is called with a known error message
+$cref ErrorHandler$$ is called with a known error message
 related to $icode%f%.optimize()%$$.
 
 $head Example$$
@@ -117,7 +106,7 @@ $children%
 	example/optimize.cpp
 %$$
 The file
-$xref/optimize.cpp/$$
+$cref optimize.cpp$$
 contains an example and test of this operation.
 It returns true if it succeeds and false otherwise.
 
@@ -169,14 +158,14 @@ struct optimize_old_variable {
 
 	/// Pointer to first argument (child) for this operator.
 	/// Set by the reverse sweep at beginning of optimization.
-	const size_t*       arg;
+	const addr_t*       arg;
 
 	/// How is this variable connected to the independent variables
 	optimize_connection connect; 
 
 	/// Set during forward sweep to the index in the
 	/// new operation sequence corresponding to this old varable.
-	size_t new_var;
+	addr_t new_var;
 };
 
 /*!
@@ -189,7 +178,7 @@ struct optimize_csum_variable {
 
 	/// Pointer to first argument (child) for this operator.
 	/// Set by the reverse sweep at beginning of optimization.
-	const size_t*       arg;
+	const addr_t*       arg;
 
 	/// Is this variable added to the summation
 	/// (if not it is subtracted)
@@ -304,15 +293,15 @@ size_t optimize_unary_match(
 	const Base*                                        par            ,
 	const CppAD::vector<size_t>&                       hash_table_var ,
 	unsigned short&                                    code           )
-{	const size_t *arg = tape[current].arg;
+{	const addr_t* arg = tape[current].arg;
 	OpCode        op  = tape[current].op;
-	size_t new_arg[1];
+	addr_t new_arg[1];
 	
 	CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(op) > 0  );
-	CPPAD_ASSERT_UNKNOWN( arg[0] < current );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < current );
 	new_arg[0] = tape[arg[0]].new_var;
-	CPPAD_ASSERT_UNKNOWN( new_arg[0] < current );
+	CPPAD_ASSERT_UNKNOWN( size_t(new_arg[0]) < current );
 	code = hash_code(
 		op                  , 
 		new_arg             ,
@@ -348,8 +337,8 @@ inline size_t optimize_binary_match(
 	const CppAD::vector<size_t>&                       hash_table_var ,
 	unsigned short&                                    code           )
 {	OpCode        op         = tape[current].op;
-	const size_t* arg        = tape[current].arg;
-	size_t        new_arg[2];
+	const addr_t* arg        = tape[current].arg;
+	addr_t        new_arg[2];
 	bool          parameter[2];
 
 	// initialize return value
@@ -367,11 +356,11 @@ inline size_t optimize_binary_match(
 		// arg[0]
 		parameter[0] = true;
 		new_arg[0]   = arg[0];
-		CPPAD_ASSERT_UNKNOWN( arg[0] < npar );
+		CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < npar );
 		// arg[1]
 		parameter[1] = false;
 		new_arg[1]   = tape[arg[1]].new_var;
-		CPPAD_ASSERT_UNKNOWN( arg[1] < current );
+		CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < current );
 		break;
 
 		// variable op parameter -----------------------------------
@@ -381,11 +370,11 @@ inline size_t optimize_binary_match(
 		// arg[0]
 		parameter[0] = false;
 		new_arg[0]   = tape[arg[0]].new_var;
-		CPPAD_ASSERT_UNKNOWN( arg[0] < current );
+		CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < current );
 		// arg[1]
 		parameter[1] = true;
 		new_arg[1]   = arg[1];
-		CPPAD_ASSERT_UNKNOWN( arg[1] < npar );
+		CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < npar );
 		break;
 
 		// variable op variable -----------------------------------
@@ -397,11 +386,11 @@ inline size_t optimize_binary_match(
 		// arg[0]
 		parameter[0] = false;
 		new_arg[0]   = tape[arg[0]].new_var;
-		CPPAD_ASSERT_UNKNOWN( arg[0] < current );
+		CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < current );
 		// arg[1]
 		parameter[1] = false;
 		new_arg[1]   = tape[arg[1]].new_var;
-		CPPAD_ASSERT_UNKNOWN( arg[1] < current );
+		CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < current );
 		break;
 
 		// must be one of the cases above
@@ -492,7 +481,7 @@ size_t optimize_record_pv(
 	const Base*                                        par            ,
 	recorder<Base>*                                    rec            ,
 	OpCode                                             op             ,
-	const size_t*                                      arg            )
+	const addr_t*                                      arg            )
 {
 # ifndef NDEBUG
 	switch(op)
@@ -507,14 +496,14 @@ size_t optimize_record_pv(
 		CPPAD_ASSERT_UNKNOWN(false);
 	}
 # endif
-	CPPAD_ASSERT_UNKNOWN( arg[0] < npar    );
-	CPPAD_ASSERT_UNKNOWN( arg[1] < current );
-	size_t new_arg[2];
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < npar    );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < current );
+	addr_t new_arg[2];
 	new_arg[0]   = rec->PutPar( par[arg[0]] );
 	new_arg[1]   = tape[ arg[1] ].new_var;
 	rec->PutArg( new_arg[0], new_arg[1] );
 	size_t i     = rec->PutOp(op);
-	CPPAD_ASSERT_UNKNOWN( new_arg[0] < i );
+	CPPAD_ASSERT_UNKNOWN( size_t(new_arg[0]) < i );
 	return i;
 }
 
@@ -546,7 +535,7 @@ size_t optimize_record_vp(
 	const Base*                                        par            ,
 	recorder<Base>*                                    rec            ,
 	OpCode                                             op             ,
-	const size_t*                                      arg            )
+	const addr_t*                                      arg            )
 {
 # ifndef NDEBUG
 	switch(op)
@@ -559,14 +548,14 @@ size_t optimize_record_vp(
 		CPPAD_ASSERT_UNKNOWN(false);
 	}
 # endif
-	CPPAD_ASSERT_UNKNOWN( arg[0] < current );
-	CPPAD_ASSERT_UNKNOWN( arg[1] < npar    );
-	size_t new_arg[2];
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < current );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < npar    );
+	addr_t new_arg[2];
 	new_arg[0]   = tape[ arg[0] ].new_var;
 	new_arg[1]   = rec->PutPar( par[arg[1]] );
 	rec->PutArg( new_arg[0], new_arg[1] );
 	size_t i     = rec->PutOp(op);
-	CPPAD_ASSERT_UNKNOWN( new_arg[0] < i );
+	CPPAD_ASSERT_UNKNOWN( size_t(new_arg[0]) < i );
 	return i;
 }
 
@@ -597,7 +586,7 @@ size_t optimize_record_vv(
 	const Base*                                        par            ,
 	recorder<Base>*                                    rec            ,
 	OpCode                                             op             ,
-	const size_t*                                      arg            )
+	const addr_t*                                      arg            )
 {
 # ifndef NDEBUG
 	switch(op)
@@ -612,14 +601,14 @@ size_t optimize_record_vv(
 		CPPAD_ASSERT_UNKNOWN(false);
 	}
 # endif
-	CPPAD_ASSERT_UNKNOWN( arg[0] < current );
-	CPPAD_ASSERT_UNKNOWN( arg[1] < current );
-	size_t new_arg[2];
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < current );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < current );
+	addr_t new_arg[2];
 	new_arg[0]   = tape[ arg[0] ].new_var;
 	new_arg[1]   = tape[ arg[1] ].new_var;
 	rec->PutArg( new_arg[0], new_arg[1] );
 	size_t i     = rec->PutOp(op);
-	CPPAD_ASSERT_UNKNOWN( new_arg[0] < i );
+	CPPAD_ASSERT_UNKNOWN( size_t(new_arg[0]) < i );
 	return i;
 }
 
@@ -679,7 +668,7 @@ size_t optimize_record_csum(
 
 	size_t                        i;
 	OpCode                        op;
-	const size_t*                 arg;
+	const addr_t*                 arg;
 	bool                          add;
 	struct optimize_csum_variable var;
 
@@ -698,7 +687,7 @@ size_t optimize_record_csum(
 		switch(op)
 		{	case AddpvOp:
 			case SubpvOp:
-			CPPAD_ASSERT_UNKNOWN( arg[0] < npar );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < npar );
 			if( add )
 				sum_par += par[arg[0]];
 			else	sum_par -= par[arg[0]];
@@ -709,7 +698,7 @@ size_t optimize_record_csum(
 			case SubvvOp:
 			if( tape[arg[0]].connect == csum_connected )
 			{	CPPAD_ASSERT_UNKNOWN(
-					tape[arg[0]].new_var == tape.size()
+					size_t(tape[arg[0]].new_var) == tape.size()
 				);
 				var.op  = tape[arg[0]].op;
 				var.arg = tape[arg[0]].arg;
@@ -728,7 +717,7 @@ size_t optimize_record_csum(
 		switch(op)
 		{
 			case SubvpOp:
-			CPPAD_ASSERT_UNKNOWN( arg[1] < npar );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < npar );
 			if( add )
 				sum_par -= par[arg[1]];
 			else	sum_par += par[arg[1]];
@@ -742,7 +731,7 @@ size_t optimize_record_csum(
 			case AddpvOp:
 			if( tape[arg[1]].connect == csum_connected )
 			{	CPPAD_ASSERT_UNKNOWN(
-					tape[arg[1]].new_var == tape.size()
+					size_t(tape[arg[1]].new_var) == tape.size()
 				);
 				var.op   = tape[arg[1]].op;
 				var.arg  = tape[arg[1]].arg;
@@ -829,7 +818,7 @@ void optimize(
 
 	// temporary variables
 	OpCode        op;   // current operator
-	const size_t *arg;  // operator arguments
+	const addr_t* arg;  // operator arguments
 	size_t        i_var;  // index of first result for current operator
 
 	// range and domain dimensions for F
@@ -838,6 +827,11 @@ void optimize(
 	// number of variables in the player
 	const size_t num_var = play->num_rec_var(); 
 
+# ifndef NDEBUG
+	// number of paraemters in the player
+	const size_t num_par = play->num_rec_par();
+# endif
+
 	// number of  VecAD indices 
 	size_t num_vecad_ind   = play->num_rec_vecad_ind();
 
@@ -879,11 +873,27 @@ void optimize(
 	}
 	CPPAD_ASSERT_UNKNOWN( j == num_vecad_ind );
 
+	// work space used by UserOp.
+	typedef std::set<size_t> size_set;
+	size_t user_q     = 0;       // maximum set element plus one
+	vector< size_set > user_r;   // sparsity pattern for the argument x
+	vector< size_set > user_s;   // sparisty pattern for the result y
+	size_t user_index = 0;       // indentifier for this user_atomic operation
+	size_t user_id    = 0;       // user identifier for this call to operator
+	size_t user_i     = 0;       // index in result vector
+	size_t user_j     = 0;       // index in argument vector
+	size_t user_m     = 0;       // size of result vector
+	size_t user_n     = 0;       // size of arugment vector
+	// next expected operator in a UserOp sequence
+	enum { user_start, user_arg, user_ret, user_end } user_state;
+	std::stack<bool> user_keep;
+
 	// Initialize a reverse mode sweep through the operation sequence
 	size_t i_op;
 	play->start_reverse(op, arg, i_op, i_var);
 	CPPAD_ASSERT_UNKNOWN( op == EndOp );
 	size_t mask;
+	user_state = user_end;
 	while(op != BeginOp)
 	{	// next op
 		play->next_reverse(op, arg, i_op, i_var);
@@ -908,7 +918,6 @@ void optimize(
 			case AtanOp:
 			case CosOp:
 			case CoshOp:
-			case DisOp:
 			case DivvpOp:
 			case ExpOp:
 			case LogOp:
@@ -916,15 +925,17 @@ void optimize(
 			case SinOp:
 			case SinhOp:
 			case SqrtOp:
+			case TanOp:
+			case TanhOp:
 			if( tape[i_var].connect != not_connected )
 				tape[arg[0]].connect = yes_connected;
 			break; // --------------------------------------------
 
 			// Unary operator where operand is arg[1]
+			case DisOp:
 			case DivpvOp:
 			case MulpvOp:
 			case PowpvOp:
-			case PrivOp:
 			if( tape[i_var].connect != not_connected )
 				tape[arg[1]].connect = yes_connected;
 			break; // --------------------------------------------
@@ -996,7 +1007,7 @@ void optimize(
 				mask = 1;
 				for(i = 2; i < 6; i++)
 				{	if( arg[1] & mask )
-					{	CPPAD_ASSERT_UNKNOWN( arg[i] < i_var );
+					{	CPPAD_ASSERT_UNKNOWN( size_t(arg[i]) < i_var );
 						tape[arg[i]].connect = yes_connected;
 					}
 					mask = mask << 1;
@@ -1010,8 +1021,7 @@ void optimize(
 			case EndOp:
 			case InvOp:
 			case ParOp:
-			case PripOp:
-			case StppOp:
+			case PriOp:
 			break;  // --------------------------------------------
 
 			// Load using a parameter index
@@ -1047,7 +1057,98 @@ void optimize(
 			{	tape[arg[1]].connect = yes_connected;
 				tape[arg[2]].connect = yes_connected;
 			}
-			break; // --------------------------------------------
+			break; 
+			// ============================================================
+			case UserOp:
+			// start or end atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( NumRes( UserOp ) == 0 );
+			CPPAD_ASSERT_UNKNOWN( NumArg( UserOp ) == 4 );
+			if( user_state == user_end )
+			{	user_index = arg[0];
+				user_id    = arg[1];
+				user_n     = arg[2];
+				user_m     = arg[3];
+				user_q     = 1;
+				if(user_r.size() < user_n )
+					user_r.resize(user_n);
+				if(user_s.size() < user_m )
+					user_s.resize(user_m);
+				user_j     = user_n;
+				user_i     = user_m;
+				user_state = user_ret;
+				user_keep.push(false);
+			}
+			else
+			{	CPPAD_ASSERT_UNKNOWN( user_state == user_start );
+				CPPAD_ASSERT_UNKNOWN( user_index == size_t(arg[0]) );
+				CPPAD_ASSERT_UNKNOWN( user_id    == size_t(arg[1]) );
+				CPPAD_ASSERT_UNKNOWN( user_n     == size_t(arg[2]) );
+				CPPAD_ASSERT_UNKNOWN( user_m     == size_t(arg[3]) );
+				user_state = user_end;
+               }
+			break;
+
+			case UsrapOp:
+			// parameter argument in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_arg );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_j && user_j <= user_n );
+			CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
+			--user_j;
+			if( user_j == 0 )
+				user_state = user_start;
+			break;
+
+			case UsravOp:
+			// variable argument in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_arg );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_j && user_j <= user_n );
+			CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) <= i_var );
+			CPPAD_ASSERT_UNKNOWN( 0 < arg[0] );
+			--user_j;
+			if( ! user_r[user_j].empty() )
+			{	tape[arg[0]].connect = yes_connected;
+				user_keep.top() = true;
+			}
+			if( user_j == 0 )
+				user_state = user_start;
+			break;
+
+			case UsrrpOp:
+			// parameter result in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_ret );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_i && user_i <= user_m );
+			CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
+			--user_i;
+			user_s[user_i].clear();
+			if( user_i == 0 )
+			{	// call users function for this operation
+				user_atomic<Base>::rev_jac_sparse(user_index, user_id,
+					user_n, user_m, user_q, user_r, user_s
+				);
+				user_state = user_arg;
+			}
+			break;
+
+			case UsrrvOp:
+			// variable result in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_ret );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_i && user_i <= user_m );
+			--user_i;
+			user_s[user_i].clear();
+			if( tape[i_var].connect != not_connected )
+				user_s[user_i].insert(0);
+			if( user_i == 0 )
+			{	// call users function for this operation
+				user_atomic<Base>::rev_jac_sparse(user_index, user_id,
+					user_n, user_m, user_q, user_r, user_s
+				);
+				user_state = user_arg;
+			}
+			break;
+			// ============================================================
 
 			// all cases should be handled above
 			default:
@@ -1109,12 +1210,13 @@ void optimize(
 	tape[i_var].new_var = rec->PutOp(BeginOp);
 
 	// temporary buffer for new argument values
-	size_t new_arg[6];
+	addr_t new_arg[6];
 
 	// temporary work space used by optimize_record_csum
 	// (decalared here to avoid realloaction of memory)
 	optimize_csum_stacks csum_work;
 
+	user_state = user_start;
 	while(op != EndOp)
 	{	// next op
 		play->next_forward(op, arg, i_op, i_var);
@@ -1126,8 +1228,7 @@ void optimize(
 		bool keep;
 		switch( op )
 		{	case ComOp:
-			case PripOp:
-			case PrivOp:
+			case PriOp:
 			keep = false;
 			break;
 
@@ -1154,6 +1255,14 @@ void optimize(
 			keep &= tape[i_var].connect != csum_connected;
 			break; 
 
+			case UserOp:
+			case UsrapOp:
+			case UsravOp:
+			case UsrrpOp:
+			case UsrrvOp:
+			keep = user_keep.top();
+			break;
+
 			default:
 			keep = tape[i_var].connect != not_connected;
 			break;
@@ -1171,12 +1280,13 @@ void optimize(
 			case AtanOp:
 			case CosOp:
 			case CoshOp:
-			case DisOp:
 			case ExpOp:
 			case LogOp:
 			case SinOp:
 			case SinhOp:
 			case SqrtOp:
+			case TanOp:
+			case TanhOp:
 			match_var = optimize_unary_match(
 				tape                ,  // inputs 
 				i_var               ,
@@ -1194,7 +1304,7 @@ void optimize(
 				rec->PutArg( new_arg[0] );
 				i                   = rec->PutOp(op);
 				tape[i_var].new_var = i;
-				CPPAD_ASSERT_UNKNOWN( new_arg[0] < i );
+				CPPAD_ASSERT_UNKNOWN( size_t(new_arg[0]) < i );
 			}
 			break;
 			// ---------------------------------------------------
@@ -1343,7 +1453,7 @@ void optimize(
 			{	if( arg[1] & mask )
 				{	new_arg[i] = tape[arg[i]].new_var;
 					CPPAD_ASSERT_UNKNOWN( 
-						new_arg[i] < num_var 
+						size_t(new_arg[i]) < num_var 
 					);
 				}
 				else	new_arg[i] = rec->PutPar( 
@@ -1388,7 +1498,7 @@ void optimize(
 			CPPAD_ASSERT_NARG_NRES(op, 3, 1);
 			new_arg[0] = new_vecad_ind[ arg[0] ];
 			new_arg[1] = arg[1];
-			CPPAD_ASSERT_UNKNOWN( new_arg[0] < num_vecad_ind );
+			CPPAD_ASSERT_UNKNOWN( size_t(new_arg[0]) < num_vecad_ind );
 			rec->PutArg( 
 				new_arg[0], 
 				new_arg[1], 
@@ -1402,8 +1512,8 @@ void optimize(
 			CPPAD_ASSERT_NARG_NRES(op, 3, 1);
 			new_arg[0] = new_vecad_ind[ arg[0] ];
 			new_arg[1] = tape[arg[1]].new_var;
-			CPPAD_ASSERT_UNKNOWN( new_arg[0] < num_vecad_ind );
-			CPPAD_ASSERT_UNKNOWN( new_arg[1] < num_var );
+			CPPAD_ASSERT_UNKNOWN( size_t(new_arg[0]) < num_vecad_ind );
+			CPPAD_ASSERT_UNKNOWN( size_t(new_arg[1]) < num_var );
 			rec->PutArg( 
 				new_arg[0], 
 				new_arg[1], 
@@ -1418,7 +1528,7 @@ void optimize(
 			new_arg[0] = new_vecad_ind[ arg[0] ];
 			new_arg[1] = rec->PutPar( play->GetPar(arg[1]) );
 			new_arg[2] = rec->PutPar( play->GetPar(arg[2]) );
-			CPPAD_ASSERT_UNKNOWN( new_arg[0] < num_vecad_ind );
+			CPPAD_ASSERT_UNKNOWN( size_t(new_arg[0]) < num_vecad_ind );
 			rec->PutArg(
 				new_arg[0], 
 				new_arg[1], 
@@ -1433,8 +1543,8 @@ void optimize(
 			new_arg[0] = new_vecad_ind[ arg[0] ];
 			new_arg[1] = tape[arg[1]].new_var;
 			new_arg[2] = rec->PutPar( play->GetPar(arg[2]) );
-			CPPAD_ASSERT_UNKNOWN( new_arg[0] < num_vecad_ind );
-			CPPAD_ASSERT_UNKNOWN( new_arg[1] < num_var );
+			CPPAD_ASSERT_UNKNOWN( size_t(new_arg[0]) < num_vecad_ind );
+			CPPAD_ASSERT_UNKNOWN( size_t(new_arg[1]) < num_var );
 			rec->PutArg(
 				new_arg[0], 
 				new_arg[1], 
@@ -1449,9 +1559,9 @@ void optimize(
 			new_arg[0] = new_vecad_ind[ arg[0] ];
 			new_arg[1] = rec->PutPar( play->GetPar(arg[1]) );
 			new_arg[2] = tape[arg[2]].new_var;
-			CPPAD_ASSERT_UNKNOWN( new_arg[0] < num_vecad_ind );
-			CPPAD_ASSERT_UNKNOWN( new_arg[1] < num_var );
-			CPPAD_ASSERT_UNKNOWN( new_arg[2] < num_var );
+			CPPAD_ASSERT_UNKNOWN( size_t(new_arg[0]) < num_vecad_ind );
+			CPPAD_ASSERT_UNKNOWN( size_t(new_arg[1]) < num_var );
+			CPPAD_ASSERT_UNKNOWN( size_t(new_arg[2]) < num_var );
 			rec->PutArg(
 				new_arg[0], 
 				new_arg[1], 
@@ -1466,9 +1576,9 @@ void optimize(
 			new_arg[0] = new_vecad_ind[ arg[0] ];
 			new_arg[1] = tape[arg[1]].new_var;
 			new_arg[2] = tape[arg[2]].new_var;
-			CPPAD_ASSERT_UNKNOWN( new_arg[0] < num_vecad_ind );
-			CPPAD_ASSERT_UNKNOWN( new_arg[1] < num_var );
-			CPPAD_ASSERT_UNKNOWN( new_arg[2] < num_var );
+			CPPAD_ASSERT_UNKNOWN( size_t(new_arg[0]) < num_vecad_ind );
+			CPPAD_ASSERT_UNKNOWN( size_t(new_arg[1]) < num_var );
+			CPPAD_ASSERT_UNKNOWN( size_t(new_arg[2]) < num_var );
 			rec->PutArg(
 				new_arg[0], 
 				new_arg[1], 
@@ -1476,7 +1586,48 @@ void optimize(
 			);
 			rec->PutOp(op);
 			break;
+
+			// -----------------------------------------------------------
+			case UserOp:
+			CPPAD_ASSERT_NARG_NRES(op, 4, 0);
+			if( user_state == user_start )
+				user_state = user_arg;
+			else
+			{	user_state = user_start;
+				user_keep.pop();	
+			}
+			// user_index, user_id, user_n, user_m
+			rec->PutArg(arg[0], arg[1], arg[2], arg[3]);
+			rec->PutOp(UserOp);
+			break;
+
+			case UsrapOp:
+			CPPAD_ASSERT_NARG_NRES(op, 1, 0);
+			new_arg[0] = rec->PutPar( play->GetPar(arg[0]) );
+			rec->PutArg(new_arg[0]);
+			rec->PutOp(UsrapOp);
+			break;
+
+			case UsravOp:
+			CPPAD_ASSERT_NARG_NRES(op, 1, 0);
+			new_arg[0] = tape[arg[0]].new_var;
+			rec->PutArg(new_arg[0]);
+			rec->PutOp(UsravOp);
+			break;
+
+			case UsrrpOp:
+			CPPAD_ASSERT_NARG_NRES(op, 1, 0);
+			new_arg[0] = rec->PutPar( play->GetPar(arg[0]) );
+			rec->PutArg(new_arg[0]);
+			rec->PutOp(UsrrpOp);
+			break;
+			
+			case UsrrvOp:
+			CPPAD_ASSERT_NARG_NRES(op, 0, 1);
+			tape[i_var].new_var = rec->PutOp(UsrrvOp);
+			break;
 			// ---------------------------------------------------
+
 			// all cases should be handled above
 			default:
 			CPPAD_ASSERT_UNKNOWN(false);
@@ -1492,7 +1643,7 @@ void optimize(
 	}
 	// modify the dependent variable vector to new indices
 	for(i = 0; i < dep_taddr.size(); i++ )
-	{	CPPAD_ASSERT_UNKNOWN( tape[ dep_taddr[i] ].new_var < num_var );
+	{	CPPAD_ASSERT_UNKNOWN( size_t(tape[ dep_taddr[i] ].new_var) < num_var );
 		dep_taddr[i] = tape[ dep_taddr[i] ].new_var;
 	}
 }
@@ -1521,6 +1672,7 @@ void ADFun<Base>::optimize(void)
 	size_t i, j, m = dep_taddr_.size();
 	CppAD::vector<Base> x(n), y(m), check(m);
 	bool check_zero_order = taylor_per_var_ > 0;
+	Base max_taylor(0);
 	if( check_zero_order )
 	{	// zero order coefficients for independent vars
 		for(j = 0; j < n; j++)
@@ -1533,6 +1685,11 @@ void ADFun<Base>::optimize(void)
 		{	CPPAD_ASSERT_UNKNOWN( dep_taddr_[i] < total_num_var_ );
 			y[i] = taylor_[ dep_taddr_[i] * taylor_col_dim_ + 0];
 		}
+		// maximum zero order coefficient
+		for(i = 0; i < total_num_var_; i++)
+		{	if(  abs_geq(taylor_[i*taylor_col_dim_+0] , max_taylor) )
+				max_taylor = taylor_[i*taylor_col_dim_+0];
+		}
 	}
 # endif
 
@@ -1551,9 +1708,7 @@ void ADFun<Base>::optimize(void)
 	for_jac_sparse_set_.resize(0,0);
 
 	// free old Taylor coefficient memory
-	if( taylor_ != CPPAD_NULL )
-		CPPAD_TRACK_DEL_VEC(taylor_);
-	taylor_         = CPPAD_NULL;
+	taylor_.erase();
 	taylor_per_var_ = 0;
 	taylor_col_dim_ = 0;
 
@@ -1564,8 +1719,9 @@ void ADFun<Base>::optimize(void)
 		check = Forward(0, x);
 
 		// check results
+		Base eps = 10. * epsilon<Base>();
 		for(i = 0; i < m; i++) CPPAD_ASSERT_KNOWN( 
-			check[i] == y[i] ,
+			abs_geq( eps * max_taylor , check[i] - y[i] ) ,
 			"Error during check of f.optimize()."
 		);
 
