@@ -1,9 +1,9 @@
-/* $Id: parameter_op.hpp 1641 2010-02-01 16:39:45Z bradbell $ */
+/* $Id: parameter_op.hpp 1986 2011-06-18 20:33:17Z bradbell $ */
 # ifndef CPPAD_PARAMETER_OP_INCLUDED
 # define CPPAD_PARAMETER_OP_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -63,22 +63,22 @@ is the zero order Taylor coefficient corresponding to z.
 \par Checked Assertions where op is the unary operator with one result:
 \li NumArg(op) == 1
 \li NumRes(op) == 1
-\li \a arg[0] < num_par 
+\li \a size_t(arg[0]) < num_par 
 \li \a 0 < \a nc_taylor
 */
 template <class Base>
 inline void forward_par_op_0(
 	size_t        i_z         ,
-	const size_t* arg         ,
+	const addr_t* arg         ,
 	size_t        num_par     ,
 	const Base*   parameter   ,
 	size_t        nc_taylor   , 
 	Base*         taylor      )
 {	
 	// check assumptions
-	CPPAD_ASSERT_UNKNOWN( NumArg(DisOp) == 2 );
-	CPPAD_ASSERT_UNKNOWN( NumRes(DisOp) == 1 );
-	CPPAD_ASSERT_UNKNOWN( arg[0] < num_par );
+	CPPAD_ASSERT_UNKNOWN( NumArg(ParOp) == 1 );
+	CPPAD_ASSERT_UNKNOWN( NumRes(ParOp) == 1 );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
 	CPPAD_ASSERT_UNKNOWN( 0 < nc_taylor );
 
 	Base* z = taylor + i_z * nc_taylor;
