@@ -1,9 +1,9 @@
-/* $Id: pow.hpp 1742 2010-12-27 17:38:20Z bradbell $ */
+/* $Id: pow.hpp 2057 2011-08-11 14:07:11Z bradbell $ */
 # ifndef CPPAD_POW_INCLUDED
 # define CPPAD_POW_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -107,13 +107,6 @@ $end
 //  BEGIN CppAD namespace
 namespace CppAD {
  
-// copy of standard functions in CppAD namespace
-inline float pow(const float &x, const float &y)
-{ return std::pow(x, y); }
-
-inline double pow(const double &x, const double &y)
-{ return std::pow(x, y); }
-
 // case where x and y are AD<Base> -----------------------------------------
 template <class Base> AD<Base> 
 pow(const AD<Base> &x, const AD<Base> &y)
@@ -122,7 +115,7 @@ pow(const AD<Base> &x, const AD<Base> &y)
 	if( tape != CPPAD_NULL )
 		tape_id = tape->id_;
 
-	// id_ == 1 is initial setting for parameters so cannot match 0
+	// id_ setting for parameters cannot match 0
 	bool var_x = x.id_  == tape_id;
 	bool var_y = y.id_ == tape_id;
 	CPPAD_ASSERT_KNOWN(
@@ -162,7 +155,7 @@ pow(const AD<Base> &x, const AD<Base> &y)
 			CPPAD_ASSERT_UNKNOWN( NumArg(PowvpOp) == 2 );
 
 			// put operand addresses in tape
-			size_t p = tape->Rec_.PutPar(y.value_);
+			addr_t p = tape->Rec_.PutPar(y.value_);
 			tape->Rec_.PutArg(x.taddr_, p);
 
 			// put operator in the tape
@@ -182,7 +175,7 @@ pow(const AD<Base> &x, const AD<Base> &y)
 			CPPAD_ASSERT_UNKNOWN( NumArg(PowpvOp) == 2 );
 
 			// put operand addresses in tape
-			size_t p = tape->Rec_.PutPar(x.value_);
+			addr_t p = tape->Rec_.PutPar(x.value_);
 			tape->Rec_.PutArg(p, y.taddr_);
 
 			// put operator in the tape
