@@ -1,8 +1,8 @@
-/* $Id: recorder.hpp 1641 2010-02-01 16:39:45Z bradbell $ */
+/* $Id: recorder.hpp 2082 2011-08-31 17:50:58Z bradbell $ */
 # ifndef CPPAD_RECORDER_INCLUDED
 # define CPPAD_RECORDER_INCLUDED
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -12,6 +12,7 @@ A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 # include <cppad/local/hash_code.hpp>
+# include <cppad/local/pod_vector.hpp>
 
 CPPAD_BEGIN_NAMESPACE
 /*!
@@ -32,96 +33,43 @@ class recorder {
 	friend class player<Base>;
 
 private:
+	/// offset for this thread in the static hash table
+	const size_t thread_offset_;
+
 	/// Number of variables in the recording.
 	size_t    num_rec_var_;
 
-	/// Length of the operation vector rec_op_.
-	size_t    len_rec_op_;
-
-	/// Number of operators currently in the recording. 
-	size_t    num_rec_op_;
-
 	/// The operators in the recording.
-	OpCode   *rec_op_;
-
-	/// Length of the VecAD index vector rec_vecad_ind_
-	size_t    len_rec_vecad_ind_;
-
-	/// Number of VecAD indices currently in the recording. 
-	size_t    num_rec_vecad_ind_;
+	pod_vector<CPPAD_OP_CODE_TYPE> rec_op_;
 
 	/// The VecAD indices in the recording.
-	size_t   *rec_vecad_ind_;
-
-	/// Length of operation argument index vector rec_op_arg_.
-	size_t    len_rec_op_arg_;
-
-	/// Number of operation arguments indices currently in the recording. 
-	size_t    num_rec_op_arg_;
+	pod_vector<addr_t> rec_vecad_ind_;
 
 	/// The argument indices in the recording
-	size_t   *rec_op_arg_;
-
-	/// Length of parameter vector rec_par_.
-	size_t    len_rec_par_;
-
-	/// Number of parameters currently in the recording.
-	size_t    num_rec_par_;
+	pod_vector<addr_t> rec_op_arg_;
 
 	/// The parameters in the recording.
-	Base     *rec_par_;
-
-	/// Length of text character vector rec_text_.
-	size_t    len_rec_text_;
-
-	/// Number of text characters currently in recording.
-	size_t    num_rec_text_;
+	/// Note that Base may not be plain old data, so use false in consructor.
+	pod_vector<Base> rec_par_;
 
 	/// Character strings ('\\0' terminated) in the recording.
-	char     *rec_text_;
-
+	pod_vector<char> rec_text_;
 // ---------------------- Public Functions -----------------------------------
 public:
 	/// Default constructor
-	recorder(void) 
-	{	
-		num_rec_var_         = 0;
-
-		num_rec_op_          = 0;
-		len_rec_op_          = 0;
-		rec_op_              = CPPAD_NULL;
-
-		num_rec_vecad_ind_   = 0;
-		len_rec_vecad_ind_   = 0;
-		rec_vecad_ind_       = CPPAD_NULL;
-
-		num_rec_op_arg_      = 0;
-		len_rec_op_arg_      = 0;
-		rec_op_arg_          = CPPAD_NULL;
-
-		num_rec_par_         = 0;
-		len_rec_par_         = 0;
-		rec_par_             = CPPAD_NULL;
-
-		num_rec_text_        = 0;
-		len_rec_text_        = 0;
-		rec_text_            = CPPAD_NULL;
-
-	}
+	recorder(void) : 
+	thread_offset_( thread_alloc::thread_num() * CPPAD_HASH_TABLE_SIZE ) ,
+	num_rec_var_(0)                                      ,
+	rec_op_( std::numeric_limits<addr_t>::max() )        ,
+	rec_vecad_ind_( std::numeric_limits<addr_t>::max() ) ,
+	rec_op_arg_( std::numeric_limits<addr_t>::max() )    ,
+	rec_par_( std::numeric_limits<addr_t>::max() )       ,
+	rec_text_( std::numeric_limits<addr_t>::max() )
+	{ }
 
 	/// Destructor
 	~recorder(void)
-	{	if( len_rec_op_ > 0 )
-			CPPAD_TRACK_DEL_VEC(rec_op_);
-		if( len_rec_vecad_ind_ > 0 )
-			CPPAD_TRACK_DEL_VEC(rec_vecad_ind_);
-		if( len_rec_op_arg_ > 0 )
-			CPPAD_TRACK_DEL_VEC(rec_op_arg_);
-		if( len_rec_par_ > 0 )
-			CPPAD_TRACK_DEL_VEC(rec_par_);
-		if( len_rec_text_ > 0 )
-			CPPAD_TRACK_DEL_VEC(rec_text_);
-	}
+	{ }
 
 	/*!
 	Erase all information in recording.
@@ -132,30 +80,12 @@ public:
 	to the system (so as to conserve on memory).
 	*/
 	void Erase(void)
-	{	
-		num_rec_var_          = 0;
-		num_rec_op_           = 0;
-		num_rec_vecad_ind_    = 0;
-		num_rec_op_arg_       = 0;
-		num_rec_par_          = 0;
-		num_rec_text_         = 0;
-
-		if( len_rec_op_ > 0 )
-			CPPAD_TRACK_DEL_VEC(rec_op_);
-		if( len_rec_vecad_ind_ > 0 )
-			CPPAD_TRACK_DEL_VEC(rec_vecad_ind_);
-		if( len_rec_op_arg_ > 0 )
-			CPPAD_TRACK_DEL_VEC(rec_op_arg_);
-		if( len_rec_par_ > 0 )
-			CPPAD_TRACK_DEL_VEC(rec_par_);
-		if( len_rec_text_ > 0 )
-			CPPAD_TRACK_DEL_VEC(rec_text_);
-
-		len_rec_op_           = 0;
-		len_rec_vecad_ind_    = 0;
-		len_rec_op_arg_       = 0;
-		len_rec_par_          = 0;
-		len_rec_text_         = 0;
+	{	num_rec_var_  = 0;
+		rec_op_.erase();
+		rec_vecad_ind_.erase();
+		rec_op_arg_.erase();
+		rec_par_.erase();
+		rec_text_.erase();
 	}
 	/// Start recording the next operator in the operation sequence.
 	inline size_t PutOp(OpCode op);
@@ -164,19 +94,19 @@ public:
 	/// Find or add a parameter to the current vector of parameters.
 	inline size_t PutPar(const Base &par);
 	/// Put one operation argument index in the recording
-	inline void PutArg(size_t arg0); 
+	inline void PutArg(addr_t arg0); 
 	/// Put two operation argument index in the recording
-	inline void PutArg(size_t arg0, size_t arg1); 
+	inline void PutArg(addr_t arg0, addr_t arg1); 
 	/// Put three operation argument index in the recording
-	inline void PutArg(size_t arg0, size_t arg1, size_t arg2); 
+	inline void PutArg(addr_t arg0, addr_t arg1, addr_t arg2); 
 	/// Put four operation argument index in the recording
-	inline void PutArg(size_t arg0, size_t arg1, size_t arg2, size_t arg3); 
+	inline void PutArg(addr_t arg0, addr_t arg1, addr_t arg2, addr_t arg3); 
 	/// Put five operation argument index in the recording
-	inline void PutArg(size_t arg0, size_t arg1, size_t arg2, size_t arg3,
-		size_t arg4);
+	inline void PutArg(addr_t arg0, addr_t arg1, addr_t arg2, addr_t arg3,
+		addr_t arg4);
 	/// Put six operation argument index in the recording
-	inline void PutArg(size_t arg0, size_t arg1, size_t arg2, size_t arg3,
-		size_t arg4, size_t arg5);
+	inline void PutArg(addr_t arg0, addr_t arg1, addr_t arg2, addr_t arg3,
+		addr_t arg4, addr_t arg5);
 
 	/// Put a character string in the text for this recording.
 	inline size_t PutTxt(const char *text);
@@ -187,11 +117,11 @@ public:
 
 	/// Approximate amount of memory used by the recording 
 	size_t Memory(void) const
-	{	return len_rec_op_ * sizeof(OpCode) 
-		     + len_rec_vecad_ind_ * sizeof(size_t)
-		     + len_rec_op_arg_ * sizeof(size_t)
-		     + len_rec_par_ * sizeof(Base)
-		     + len_rec_text_ * sizeof(char);
+	{	return rec_op_.capacity()        * sizeof(CPPAD_OP_CODE_TYPE) 
+		     + rec_vecad_ind_.capacity() * sizeof(size_t)
+		     + rec_op_arg_.capacity()    * sizeof(addr_t)
+		     + rec_par_.capacity()       * sizeof(Base)
+		     + rec_text_.capacity()      * sizeof(char);
 	}
 };
 
@@ -224,19 +154,12 @@ and after each call to Erase.
 */
 template <class Base>
 inline size_t recorder<Base>::PutOp(OpCode op)
-{
-	CPPAD_ASSERT_UNKNOWN( num_rec_op_ <= len_rec_op_ );
-	if( num_rec_op_ == len_rec_op_ )
-	{	len_rec_op_ = 2 * len_rec_op_ + 8;
-		rec_op_ = CPPAD_TRACK_EXTEND(
-			len_rec_op_, num_rec_op_, rec_op_
-		);
-	}
-	CPPAD_ASSERT_UNKNOWN( num_rec_op_ < len_rec_op_ );
-	rec_op_[num_rec_op_++]  = op;
-	num_rec_var_ += NumRes(op);
+{	size_t i    = rec_op_.extend(1);
+	rec_op_[i]  = static_cast<CPPAD_OP_CODE_TYPE>(op);
+	CPPAD_ASSERT_UNKNOWN( rec_op_.size() == i + 1 );
 
 	// first operator should be a BeginOp and NumRes( BeginOp ) > 0
+	num_rec_var_ += NumRes(op);
 	CPPAD_ASSERT_UNKNOWN( num_rec_var_ > 0 );
 
 	return num_rec_var_ - 1;
@@ -262,18 +185,11 @@ It increments by one for each call to PutVecInd..
 */
 template <class Base>
 inline size_t recorder<Base>::PutVecInd(size_t vec_ind)
-{	
-	CPPAD_ASSERT_UNKNOWN( num_rec_vecad_ind_ <= len_rec_vecad_ind_ );
-	if( num_rec_vecad_ind_ == len_rec_vecad_ind_ )
-	{	len_rec_vecad_ind_ = 2 * len_rec_vecad_ind_ + 8;
-		rec_vecad_ind_ = CPPAD_TRACK_EXTEND(
-			len_rec_vecad_ind_, num_rec_vecad_ind_, rec_vecad_ind_
-		);
-	}
-	CPPAD_ASSERT_UNKNOWN( num_rec_vecad_ind_ < len_rec_vecad_ind_ );
-	rec_vecad_ind_[num_rec_vecad_ind_++] = vec_ind;
+{	size_t i          = rec_vecad_ind_.extend(1);
+	rec_vecad_ind_[i] = vec_ind;
+	CPPAD_ASSERT_UNKNOWN( rec_vecad_ind_.size() == i + 1 );
 
-	return num_rec_vecad_ind_ - 1;
+	return i;
 }
 
 /*!
@@ -289,42 +205,32 @@ This value is not necessarily placed at the end of the vector
 */
 template <class Base>
 size_t recorder<Base>::PutPar(const Base &par)
-{	static size_t   hash_table[CPPAD_HASH_TABLE_SIZE];
-	static bool     init = true;
+{	static size_t   hash_table[CPPAD_HASH_TABLE_SIZE * CPPAD_MAX_NUM_THREADS];
 	size_t          i;
-	unsigned short  code;
-	CPPAD_ASSERT_UNKNOWN( num_rec_par_ <= len_rec_par_ );
+	size_t          code;
+
+	CPPAD_ASSERT_UNKNOWN( 
+		thread_offset_ / CPPAD_HASH_TABLE_SIZE
+		== 
+		thread_alloc::thread_num() 
+	);
 
-	if( init )
-	{	// initialize hash table
-		for(i = 0; i < CPPAD_HASH_TABLE_SIZE; i++)
-			hash_table[i] = 0;
-		init = false;
-	}
-	
 	// get hash code for this value
-	code = hash_code(par);
+	code = static_cast<size_t>( hash_code(par) );
+	CPPAD_ASSERT_UNKNOWN( code < CPPAD_HASH_TABLE_SIZE );
 
 	// If we have a match, return the parameter index
-	i = hash_table[code];
-	if( i < num_rec_par_ )
-	{	if( IdenticalEqualPar(rec_par_[i], par) )
+	i = hash_table[code + thread_offset_];
+	if( i < rec_par_.size() && IdenticalEqualPar(rec_par_[i], par) )
 			return i;
-	}
 	
 	// place a new value in the table
-	if( num_rec_par_ == len_rec_par_ )
-	{	len_rec_par_ = 2 * len_rec_par_ + 8;
-		rec_par_ = CPPAD_TRACK_EXTEND(
-			len_rec_par_, num_rec_par_, rec_par_
-		);
-	}
-	CPPAD_ASSERT_UNKNOWN( num_rec_par_ < len_rec_par_ );
-	i           = num_rec_par_++;
+	i           = rec_par_.extend(1);
 	rec_par_[i] = par;
+	CPPAD_ASSERT_UNKNOWN( rec_par_.size() == i + 1 );
 
 	// make the hash code point to this new value
-	hash_table[code] = i;
+	hash_table[code + thread_offset_] = i;
 
 	// return the parameter index
 	return i;
@@ -367,17 +273,11 @@ The operation argument index
 \copydetails prototype_put_arg 
 */
 template <class Base>
-inline void recorder<Base>::PutArg(size_t arg0)
+inline void recorder<Base>::PutArg(addr_t arg0)
 { 
-	CPPAD_ASSERT_UNKNOWN( num_rec_op_arg_ <= len_rec_op_arg_ );
-	if( num_rec_op_arg_ == len_rec_op_arg_ )
-	{	len_rec_op_arg_ = 2 * len_rec_op_arg_ + 8;
-		rec_op_arg_ = CPPAD_TRACK_EXTEND(
-			len_rec_op_arg_, num_rec_op_arg_, rec_op_arg_
-		);
-	}
-	CPPAD_ASSERT_UNKNOWN( num_rec_op_arg_ < len_rec_op_arg_ );
-	rec_op_arg_[num_rec_op_arg_++] = arg0;
+	size_t i       = rec_op_arg_.extend(1);
+	rec_op_arg_[i] =  static_cast<addr_t>( arg0 );
+	CPPAD_ASSERT_UNKNOWN( rec_op_arg_.size() == i + 1 );
 }
 /*!
 Put two operation argument index in the recording
@@ -391,18 +291,12 @@ Second operation argument index.
 \copydetails prototype_put_arg 
 */
 template <class Base>
-inline void recorder<Base>::PutArg(size_t arg0, size_t arg1)
+inline void recorder<Base>::PutArg(addr_t arg0, addr_t arg1)
 { 
-	CPPAD_ASSERT_UNKNOWN( num_rec_op_arg_ <= len_rec_op_arg_ );
-	if( num_rec_op_arg_ + 1 >= len_rec_op_arg_ )
-	{	len_rec_op_arg_ = 2 * len_rec_op_arg_ + 8;
-		rec_op_arg_ = CPPAD_TRACK_EXTEND(
-			len_rec_op_arg_, num_rec_op_arg_, rec_op_arg_
-		);
-	}
-	CPPAD_ASSERT_UNKNOWN( num_rec_op_arg_ + 1 < len_rec_op_arg_ );
-	rec_op_arg_[num_rec_op_arg_++] = arg0;
-	rec_op_arg_[num_rec_op_arg_++] = arg1;
+	size_t i         = rec_op_arg_.extend(2);
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg0 );
+	rec_op_arg_[i]   =  static_cast<addr_t>( arg1 );
+	CPPAD_ASSERT_UNKNOWN( rec_op_arg_.size() == i + 1 );
 }
 /*!
 Put three operation argument index in the recording
@@ -419,19 +313,13 @@ Third operation argument index.
 \copydetails prototype_put_arg 
 */
 template <class Base>
-inline void recorder<Base>::PutArg(size_t arg0, size_t arg1, size_t arg2)
+inline void recorder<Base>::PutArg(addr_t arg0, addr_t arg1, addr_t arg2)
 { 
-	CPPAD_ASSERT_UNKNOWN( num_rec_op_arg_ <= len_rec_op_arg_ );
-	if( num_rec_op_arg_ + 2 >= len_rec_op_arg_ )
-	{	len_rec_op_arg_ = 2 * len_rec_op_arg_ + 8;
-		rec_op_arg_ = CPPAD_TRACK_EXTEND(
-			len_rec_op_arg_, num_rec_op_arg_, rec_op_arg_
-		);
-	}
-	CPPAD_ASSERT_UNKNOWN( num_rec_op_arg_ + 2 < len_rec_op_arg_ );
-	rec_op_arg_[num_rec_op_arg_++] = arg0;
-	rec_op_arg_[num_rec_op_arg_++] = arg1;
-	rec_op_arg_[num_rec_op_arg_++] = arg2;
+	size_t i         = rec_op_arg_.extend(3);
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg0 );
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg1 );
+	rec_op_arg_[i]   =  static_cast<addr_t>( arg2 );
+	CPPAD_ASSERT_UNKNOWN( rec_op_arg_.size() == i + 1 );
 }
 /*!
 Put four operation argument index in the recording
@@ -451,21 +339,15 @@ Fourth operation argument index.
 \copydetails prototype_put_arg 
 */
 template <class Base>
-inline void recorder<Base>::PutArg(size_t arg0, size_t arg1, size_t arg2,
-	size_t arg3)
+inline void recorder<Base>::PutArg(addr_t arg0, addr_t arg1, addr_t arg2,
+	addr_t arg3)
 { 
-	CPPAD_ASSERT_UNKNOWN( num_rec_op_arg_ <= len_rec_op_arg_ );
-	if( num_rec_op_arg_ + 3 >= len_rec_op_arg_ )
-	{	len_rec_op_arg_ = 2 * len_rec_op_arg_ + 8;
-		rec_op_arg_ = CPPAD_TRACK_EXTEND(
-			len_rec_op_arg_, num_rec_op_arg_, rec_op_arg_
-		);
-	}
-	CPPAD_ASSERT_UNKNOWN( num_rec_op_arg_ + 3 < len_rec_op_arg_ );
-	rec_op_arg_[num_rec_op_arg_++] = arg0;
-	rec_op_arg_[num_rec_op_arg_++] = arg1;
-	rec_op_arg_[num_rec_op_arg_++] = arg2;
-	rec_op_arg_[num_rec_op_arg_++] = arg3;
+	size_t i         = rec_op_arg_.extend(4);
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg0 );
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg1 );
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg2 );
+	rec_op_arg_[i]   =  static_cast<addr_t>( arg3 );
+	CPPAD_ASSERT_UNKNOWN( rec_op_arg_.size() == i + 1 );
 
 }
 /*!
@@ -489,22 +371,16 @@ Fifth operation argument index.
 \copydetails prototype_put_arg 
 */
 template <class Base>
-inline void recorder<Base>::PutArg(size_t arg0, size_t arg1, size_t arg2,
-	size_t arg3, size_t arg4)
+inline void recorder<Base>::PutArg(addr_t arg0, addr_t arg1, addr_t arg2,
+	addr_t arg3, addr_t arg4)
 { 
-	CPPAD_ASSERT_UNKNOWN( num_rec_op_arg_ <= len_rec_op_arg_ );
-	if( num_rec_op_arg_ + 4 >= len_rec_op_arg_ )
-	{	len_rec_op_arg_ = 2 * len_rec_op_arg_ + 8;
-		rec_op_arg_ = CPPAD_TRACK_EXTEND(
-			len_rec_op_arg_, num_rec_op_arg_, rec_op_arg_
-		);
-	}
-	CPPAD_ASSERT_UNKNOWN( num_rec_op_arg_ + 4 < len_rec_op_arg_ );
-	rec_op_arg_[num_rec_op_arg_++] = arg0;
-	rec_op_arg_[num_rec_op_arg_++] = arg1;
-	rec_op_arg_[num_rec_op_arg_++] = arg2;
-	rec_op_arg_[num_rec_op_arg_++] = arg3;
-	rec_op_arg_[num_rec_op_arg_++] = arg4;
+	size_t i         = rec_op_arg_.extend(5);
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg0 );
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg1 );
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg2 );
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg3 );
+	rec_op_arg_[i]   =  static_cast<addr_t>( arg4 );
+	CPPAD_ASSERT_UNKNOWN( rec_op_arg_.size() == i + 1 );
 
 }
 /*!
@@ -531,23 +407,17 @@ Sixth operation argument index.
 \copydetails prototype_put_arg 
 */
 template <class Base>
-inline void recorder<Base>::PutArg(size_t arg0, size_t arg1, size_t arg2, 
-	size_t arg3, size_t arg4, size_t arg5)
+inline void recorder<Base>::PutArg(addr_t arg0, addr_t arg1, addr_t arg2, 
+	addr_t arg3, addr_t arg4, addr_t arg5)
 { 
-	CPPAD_ASSERT_UNKNOWN( num_rec_op_arg_ <= len_rec_op_arg_ );
-	if( num_rec_op_arg_ + 5 >= len_rec_op_arg_ )
-	{	len_rec_op_arg_ = 2 * len_rec_op_arg_ + 8;
-		rec_op_arg_ = CPPAD_TRACK_EXTEND(
-			len_rec_op_arg_, num_rec_op_arg_, rec_op_arg_
-		);
-	}
-	CPPAD_ASSERT_UNKNOWN( num_rec_op_arg_ + 5 < len_rec_op_arg_ );
-	rec_op_arg_[num_rec_op_arg_++] = arg0;
-	rec_op_arg_[num_rec_op_arg_++] = arg1;
-	rec_op_arg_[num_rec_op_arg_++] = arg2;
-	rec_op_arg_[num_rec_op_arg_++] = arg3;
-	rec_op_arg_[num_rec_op_arg_++] = arg4;
-	rec_op_arg_[num_rec_op_arg_++] = arg5;
+	size_t i         = rec_op_arg_.extend(6);
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg0 );
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg1 );
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg2 );
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg3 );
+	rec_op_arg_[i++] =  static_cast<addr_t>( arg4 );
+	rec_op_arg_[i]   =  static_cast<addr_t>( arg5 );
+	CPPAD_ASSERT_UNKNOWN( rec_op_arg_.size() == i + 1 );
 }
 // --------------------------------------------------------------------------
 /*!
@@ -564,30 +434,23 @@ the character string starts.
 */
 template <class Base>
 inline size_t recorder<Base>::PutTxt(const char *text)
-{	size_t i;
-
+{
 	// determine length of the text including terminating '\0'
-	size_t n;
-	for(n = 0; text[n] != '\0'; n++)
-		CPPAD_ASSERT_UNKNOWN( n < 1000 ); // should check in PrintFor
+	size_t n = 0;
+	while( text[n] != '\0' )
+		n++;
+	CPPAD_ASSERT_UNKNOWN( n <= 1000 ); 
 	n++;
-
-	CPPAD_ASSERT_UNKNOWN( num_rec_text_ <= len_rec_text_ );
-
-	if( num_rec_text_ + n >= len_rec_text_ )
-	{	len_rec_text_  = 2 * len_rec_text_ + n + 8;
-		rec_text_ = CPPAD_TRACK_EXTEND(
-			len_rec_text_, num_rec_text_, rec_text_
-		);
-	}
-	CPPAD_ASSERT_UNKNOWN( num_rec_text_ + n < len_rec_text_ );
+	CPPAD_ASSERT_UNKNOWN( text[n-1] == '\0' );
 
 	// copy text including terminating '\0'
-	for(i = 0; i < n; i++)
-		rec_text_[num_rec_text_++] = text[i];
-	CPPAD_ASSERT_UNKNOWN( text[i-1] == '\0' );
+	size_t i = rec_text_.extend(n); 
+	size_t j;
+	for(j = 0; j < n; j++)
+		rec_text_[i + j] = text[j];
+	CPPAD_ASSERT_UNKNOWN( rec_text_.size() == i + n );
 
-	return num_rec_text_ - n;
+	return i;
 }
 // -------------------------------------------------------------------------
 
