@@ -1,9 +1,9 @@
-/* $Id: rev_hes_sweep.hpp 1659 2010-03-11 03:48:31Z bradbell $ */
+/* $Id: rev_hes_sweep.hpp 2240 2011-12-31 05:33:55Z bradbell $ */
 # ifndef CPPAD_REV_HES_SWEEP_INCLUDED
 # define CPPAD_REV_HES_SWEEP_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -112,7 +112,7 @@ void RevHesSweep(
 	size_t         i_op;
 	size_t        i_var;
 
-	const size_t   *arg = 0;
+	const addr_t*   arg = 0;
 
 	// length of the parameter vector (used by CppAD assert macros)
 	const size_t num_par = play->num_rec_par();
@@ -127,7 +127,7 @@ void RevHesSweep(
 
 	// upper limit exclusive for set elements
 	size_t limit   = rev_hes_sparse.end();
-	CPPAD_ASSERT_UNKNOWN( rev_hes_sparse.end() == limit );
+	CPPAD_ASSERT_UNKNOWN( for_jac_sparse.end() == limit );
 
 	// check number of sets match
 	CPPAD_ASSERT_UNKNOWN( 
@@ -141,12 +141,12 @@ void RevHesSweep(
 	size_t num_vecad_vec   = play->num_rec_vecad_vec();
 	Vector_set vecad_sparse;
 	vecad_sparse.resize(num_vecad_vec, limit);
-	size_t* vecad_ind   = CPPAD_NULL;
-	bool*   vecad_jac   = CPPAD_NULL;
+	pod_vector<size_t> vecad_ind;
+	pod_vector<bool>   vecad_jac;
 	if( num_vecad_vec > 0 )
 	{	size_t length;
-		vecad_ind     = CPPAD_TRACK_NEW_VEC(num_vecad_ind, vecad_ind);
-		vecad_jac     = CPPAD_TRACK_NEW_VEC(num_vecad_vec, vecad_jac);
+		vecad_ind.extend(num_vecad_ind);
+		vecad_jac.extend(num_vecad_vec);
 		j             = 0;
 		for(i = 0; i < num_vecad_vec; i++)
 		{	// length of this VecAD
@@ -164,6 +164,27 @@ void RevHesSweep(
 		CPPAD_ASSERT_UNKNOWN( j == play->num_rec_vecad_ind() );
 	}
 
+	// work space used by UserOp.
+	typedef std::set<size_t> size_set;
+	const size_t user_q = limit; // maximum element plus one
+	size_set::iterator set_itr;  // iterator for a standard set
+	size_set::iterator set_end;  // end of iterator sequence
+	vector<size_t>     user_ix;  // variable indices for argument vector x
+	vector< size_set > user_r;   // forward Jacobian sparsity pattern for x
+	vector<bool>       user_s;   // reverse Jacobian sparsity for y
+	vector<bool>       user_t;   // reverse Jacobian sparsity for x
+	vector< size_set > user_u;   // reverse Hessian sparsity for y
+	vector< size_set > user_v;   // reverse Hessian sparsity for x
+	size_t user_index = 0;       // indentifier for this user_atomic operation
+	size_t user_id    = 0;       // user identifier for this call to operator
+	size_t user_i     = 0;       // index in result vector
+	size_t user_j     = 0;       // index in argument vector
+	size_t user_m     = 0;       // size of result vector
+	size_t user_n     = 0;       // size of arugment vector
+	// next expected operator in a UserOp sequence
+	enum { user_start, user_arg, user_ret, user_end } user_state = user_end;
+
+
 	// Initialize
 	play->start_reverse(op, arg, i_op, i_var);
 	CPPAD_ASSERT_UNKNOWN( op == EndOp );
@@ -211,8 +232,7 @@ void RevHesSweep(
 			// -------------------------------------------------
 
 			case AcosOp:
-			// acos(x) and sqrt(1 - x * x) are computed in pairs
-			// but i_var + 1 should only be used here
+			// sqrt(1 - x * x), acos(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2)
 			reverse_sparse_hessian_nonlinear_unary_op(
 			i_var, arg[0], RevJac, for_jac_sparse, rev_hes_sparse
@@ -221,8 +241,7 @@ void RevHesSweep(
 			// -------------------------------------------------
 
 			case AsinOp:
-			// asin(x) and sqrt(1 - x * x) are computed in pairs
-			// but i_var + 1 should only be used here
+			// sqrt(1 - x * x), asin(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2)
 			reverse_sparse_hessian_nonlinear_unary_op(
 			i_var, arg[0], RevJac, for_jac_sparse, rev_hes_sparse
@@ -231,8 +250,7 @@ void RevHesSweep(
 			// -------------------------------------------------
 
 			case AtanOp:
-			// atan(x) and 1 + x * x must be computed in pairs
-			// but i_var + 1 should only be used here
+			// 1 + x * x, atan(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2)
 			reverse_sparse_hessian_nonlinear_unary_op(
 			i_var, arg[0], RevJac, for_jac_sparse, rev_hes_sparse
@@ -270,8 +288,7 @@ void RevHesSweep(
 			// --------------------------------------------------
 
 			case CosOp:
-			// cosine and sine must come in pairs
-			// but i_var should only be used here
+			// sin(x), cos(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2)
 			reverse_sparse_hessian_nonlinear_unary_op(
 			i_var, arg[0], RevJac, for_jac_sparse, rev_hes_sparse
@@ -280,8 +297,7 @@ void RevHesSweep(
 			// ---------------------------------------------------
 
 			case CoshOp:
-			// hyperbolic cosine and sine must come in pairs
-			// but i_var should only be used here
+			// sinh(x), cosh(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2)
 			reverse_sparse_hessian_nonlinear_unary_op(
 			i_var, arg[0], RevJac, for_jac_sparse, rev_hes_sparse
@@ -291,7 +307,7 @@ void RevHesSweep(
 
 			case DisOp:
 			CPPAD_ASSERT_NARG_NRES(op, 2, 1)
-
+			// derivativve is identically zero
 			break;
 			// -------------------------------------------------
 
@@ -339,11 +355,11 @@ void RevHesSweep(
 				i_var,
 				arg,
 				num_vecad_ind,
-				vecad_ind,
+				vecad_ind.data(),
 				rev_hes_sparse,
 				vecad_sparse,
 				RevJac,
-				vecad_jac
+				vecad_jac.data()
 			);
 			break;
 			// -------------------------------------------------
@@ -354,11 +370,11 @@ void RevHesSweep(
 				i_var,
 				arg,
 				num_vecad_ind,
-				vecad_ind,
+				vecad_ind.data(),
 				rev_hes_sparse,
 				vecad_sparse,
 				RevJac,
-				vecad_jac
+				vecad_jac.data()
 			);
 			break;
 			// -------------------------------------------------
@@ -417,19 +433,19 @@ void RevHesSweep(
 			break;
 			// -------------------------------------------------
 
-			case PripOp:
-			CPPAD_ASSERT_NARG_NRES(op, 2, 0);
+			case PriOp:
+			CPPAD_ASSERT_NARG_NRES(op, 5, 0);
 			break;
 			// -------------------------------------------------
 
-			case PrivOp:
-			CPPAD_ASSERT_NARG_NRES(op, 2, 0);
+			case SignOp:
+			CPPAD_ASSERT_NARG_NRES(op, 1, 1);
+			// Derivative is identiaclly zero
 			break;
 			// -------------------------------------------------
 
 			case SinOp:
-			// sine and cosine must come in pairs
-			// but i_var should only be used here
+			// cos(x), sin(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2)
 			reverse_sparse_hessian_nonlinear_unary_op(
 			i_var, arg[0], RevJac, for_jac_sparse, rev_hes_sparse
@@ -438,8 +454,7 @@ void RevHesSweep(
 			// -------------------------------------------------
 
 			case SinhOp:
-			// sine and cosine must come in pairs
-			// but i_var should only be used here
+			// cosh(x), sinh(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2)
 			reverse_sparse_hessian_nonlinear_unary_op(
 			i_var, arg[0], RevJac, for_jac_sparse, rev_hes_sparse
@@ -466,11 +481,11 @@ void RevHesSweep(
 				op,
 				arg,
 				num_vecad_ind,
-				vecad_ind,
+				vecad_ind.data(),
 				rev_hes_sparse,
 				vecad_sparse,
 				RevJac,
-				vecad_jac
+				vecad_jac.data()
 			);
 			break;
 			// -------------------------------------------------
@@ -486,11 +501,11 @@ void RevHesSweep(
 				op,
 				arg,
 				num_vecad_ind,
-				vecad_ind,
+				vecad_ind.data(),
 				rev_hes_sparse,
 				vecad_sparse,
 				RevJac,
-				vecad_jac
+				vecad_jac.data()
 			);
 			break;
 			// -------------------------------------------------
@@ -519,6 +534,136 @@ void RevHesSweep(
 			break;
 			// -------------------------------------------------
 
+			case TanOp:
+			// tan(x)^2, tan(x)
+			CPPAD_ASSERT_NARG_NRES(op, 1, 2)
+			reverse_sparse_hessian_nonlinear_unary_op(
+			i_var, arg[0], RevJac, for_jac_sparse, rev_hes_sparse
+			);
+			break;
+			// -------------------------------------------------
+
+			case TanhOp:
+			// tanh(x)^2, tanh(x)
+			CPPAD_ASSERT_NARG_NRES(op, 1, 2)
+			reverse_sparse_hessian_nonlinear_unary_op(
+			i_var, arg[0], RevJac, for_jac_sparse, rev_hes_sparse
+			);
+			break;
+			// -------------------------------------------------
+
+			case UserOp:
+			// start or end an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( NumRes( UserOp ) == 0 );
+			CPPAD_ASSERT_UNKNOWN( NumArg( UserOp ) == 4 );
+			if( user_state == user_end )
+			{	user_index = arg[0];
+				user_id    = arg[1];
+				user_n     = arg[2];
+				user_m     = arg[3];
+				if(user_ix.size() < user_n)
+				{	user_ix.resize(user_n);
+					user_r.resize(user_n);
+					user_t.resize(user_n);
+					user_v.resize(user_n);
+				}
+				if(user_s.size() < user_m)
+				{	user_s.resize(user_m);
+					user_u.resize(user_m);
+				}
+				user_j     = user_n;
+				user_i     = user_m;
+				user_state = user_ret;
+			}
+			else
+			{	CPPAD_ASSERT_UNKNOWN( user_state == user_start );
+				CPPAD_ASSERT_UNKNOWN( user_index == size_t(arg[0]) );
+				CPPAD_ASSERT_UNKNOWN( user_id    == size_t(arg[1]) );
+				CPPAD_ASSERT_UNKNOWN( user_n     == size_t(arg[2]) );
+				CPPAD_ASSERT_UNKNOWN( user_m     == size_t(arg[3]) );
+				user_state = user_end;
+
+				// call users function for this operation
+				user_atomic<Base>::rev_hes_sparse(user_index, user_id,
+					user_n, user_m, 
+					user_q, user_r, user_s, user_t, user_u, user_v
+				);
+				for(j = 0; j < user_n; j++) if( user_ix[j] > 0 )
+				{	size_t i_x = user_ix[j];
+					RevJac[i_x] = user_t[j];
+					set_itr = user_v[j].begin();
+					set_end = user_v[j].end();
+					while( set_itr != set_end )
+						rev_hes_sparse.add_element(i_x, *set_itr++);
+				}
+               }
+			break;
+
+			case UsrapOp:
+			// parameter argument in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_arg );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_j && user_j <= user_n );
+			CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
+			--user_j;
+			user_ix[user_j] = 0;
+			user_r[user_j].clear();
+			if( user_j == 0 )
+				user_state = user_start;
+			break;
+
+			case UsravOp:
+			// variable argument in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_arg );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_j && user_j <= user_n );
+			CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) <= i_var );
+			CPPAD_ASSERT_UNKNOWN( 0 < arg[0] );
+			--user_j;
+			user_ix[user_j] = arg[0];
+			user_r[user_j].clear();
+			for_jac_sparse.begin(arg[0]);
+			i = for_jac_sparse.next_element();
+			while( i < user_q )
+			{	user_r[user_j].insert(i);
+				i = for_jac_sparse.next_element();
+			}
+			if( user_j == 0 )
+				user_state = user_start;
+			break;
+
+			case UsrrpOp:
+			// parameter result in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_ret );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_i && user_i <= user_m );
+			CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
+			--user_i;
+			user_s[user_i] = false;
+			user_u[user_i].clear();
+			if( user_i == 0 )
+				user_state = user_arg;
+			break;
+
+			case UsrrvOp:
+			// variable result in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_ret );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_i && user_i <= user_m );
+			--user_i;
+			user_s[user_i] = RevJac[i_var];
+			user_u[user_i].clear();
+			rev_hes_sparse.begin(i_var);
+			i = rev_hes_sparse.next_element();
+			while( i < user_q )
+			{	user_u[user_i].insert(i);
+				i = rev_hes_sparse.next_element();
+			}
+			if( user_i == 0 )
+				user_state = user_arg;
+			break;
+
+			// -------------------------------------------------
+
 			default:
 			CPPAD_ASSERT_UNKNOWN(0);
 		}
@@ -558,14 +703,11 @@ void RevHesSweep(
 	CPPAD_ASSERT_UNKNOWN( i_op == 0 );
 	CPPAD_ASSERT_UNKNOWN( i_var == 0 );
 
-	if( vecad_jac != CPPAD_NULL )
-		CPPAD_TRACK_DEL_VEC(vecad_jac);
-	if( vecad_ind != CPPAD_NULL )
-		CPPAD_TRACK_DEL_VEC(vecad_ind);
 	return;
 }
+CPPAD_END_NAMESPACE
 
+// preprocessor symbols that are local to this file
 # undef CPPAD_REV_HES_SWEEP_TRACE
 
-CPPAD_END_NAMESPACE
 # endif
