@@ -1,9 +1,9 @@
-/* $Id: rev_jac_sweep.hpp 1659 2010-03-11 03:48:31Z bradbell $ */
+/* $Id: rev_jac_sweep.hpp 2240 2011-12-31 05:33:55Z bradbell $ */
 # ifndef CPPAD_REV_JAC_SWEEP_INCLUDED
 # define CPPAD_REV_JAC_SWEEP_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -92,7 +92,7 @@ void RevJacSweep(
 	size_t         i_op;
 	size_t        i_var;
 
-	const size_t   *arg = 0;
+	const addr_t*   arg = 0;
 
 	size_t            i, j, k;
 
@@ -114,10 +114,10 @@ void RevJacSweep(
 	size_t num_vecad_vec   = play->num_rec_vecad_vec();
 	Vector_set  vecad_sparsity;
 	vecad_sparsity.resize(num_vecad_vec, limit);
-	size_t* vecad_ind      = CPPAD_NULL;
+	pod_vector<size_t> vecad_ind;
 	if( num_vecad_vec > 0 )
 	{	size_t length;
-		vecad_ind     = CPPAD_TRACK_NEW_VEC(num_vecad_ind, vecad_ind);
+		vecad_ind.extend(num_vecad_ind);
 		j             = 0;
 		for(i = 0; i < num_vecad_vec; i++)
 		{	// length of this VecAD
@@ -132,6 +132,22 @@ void RevJacSweep(
 		CPPAD_ASSERT_UNKNOWN( j == play->num_rec_vecad_ind() );
 	}
 
+	// work space used by UserOp.
+	typedef std::set<size_t> size_set;
+	const size_t user_q = limit; // maximum element plus one
+	size_set::iterator set_itr;  // iterator for a standard set
+	size_set::iterator set_end;  // end of iterator sequence
+	vector< size_set > user_r;   // sparsity pattern for the argument x
+	vector< size_set > user_s;   // sparisty pattern for the result y
+	size_t user_index = 0;       // indentifier for this user_atomic operation
+	size_t user_id    = 0;       // user identifier for this call to operator
+	size_t user_i     = 0;       // index in result vector
+	size_t user_j     = 0;       // index in argument vector
+	size_t user_m     = 0;       // size of result vector
+	size_t user_n     = 0;       // size of arugment vector
+	// next expected operator in a UserOp sequence
+	enum { user_start, user_arg, user_ret, user_end } user_state = user_end;
+
 	// Initialize
 	play->start_reverse(op, arg, i_op, i_var);
 	CPPAD_ASSERT_UNKNOWN( op == EndOp );
@@ -178,8 +194,7 @@ void RevJacSweep(
 			// -------------------------------------------------
 
 			case AcosOp:
-			// acos(x) and sqrt(1 - x * x) are computed in pairs
-			// but i_var + 1 should only be used here
+			// sqrt(1 - x * x), acos(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
 			reverse_sparse_jacobian_unary_op(
 				i_var, arg[0], var_sparsity
@@ -188,8 +203,7 @@ void RevJacSweep(
 			// -------------------------------------------------
 
 			case AsinOp:
-			// asin(x) and sqrt(1 - x * x) are computed in pairs
-			// but i_var + 1 should only be used here
+			// sqrt(1 - x * x), asin(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
 			reverse_sparse_jacobian_unary_op(
 				i_var, arg[0], var_sparsity
@@ -198,8 +212,7 @@ void RevJacSweep(
 			// -------------------------------------------------
 
 			case AtanOp:
-			// atan(x) and 1 + x * x must be computed in pairs
-			// but i_var + 1 should only be used here
+			// 1 + x * x, atan(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
 			reverse_sparse_jacobian_unary_op(
 				i_var, arg[0], var_sparsity
@@ -237,8 +250,7 @@ void RevJacSweep(
 			// --------------------------------------------------
 
 			case CosOp:
-			// cosine and sine must come in pairs
-			// but i_var should only be used here
+			// sin(x), cos(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
 			reverse_sparse_jacobian_unary_op(
 				i_var, arg[0], var_sparsity
@@ -247,8 +259,7 @@ void RevJacSweep(
 			// ---------------------------------------------------
 
 			case CoshOp:
-			// hyperbolic cosine and sine must come in pairs
-			// but i_var should only be used here
+			// sinh(x), cosh(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
 			reverse_sparse_jacobian_unary_op(
 				i_var, arg[0], var_sparsity
@@ -258,7 +269,7 @@ void RevJacSweep(
 
 			case DisOp:
 			CPPAD_ASSERT_NARG_NRES(op, 2, 1);
-
+			// derivative is identically zero
 			break;
 			// -------------------------------------------------
 
@@ -305,7 +316,7 @@ void RevJacSweep(
 				i_var,
 				arg,
 				num_vecad_ind,
-				vecad_ind,
+				vecad_ind.data(),
 				var_sparsity,
 				vecad_sparsity
 			);
@@ -318,7 +329,7 @@ void RevJacSweep(
 				i_var,
 				arg,
 				num_vecad_ind,
-				vecad_ind,
+				vecad_ind.data(),
 				var_sparsity,
 				vecad_sparsity
 			);
@@ -378,20 +389,19 @@ void RevJacSweep(
 			break;
 			// -------------------------------------------------
 
-			case PripOp:
- 			CPPAD_ASSERT_NARG_NRES(op, 2, 0);
-
+			case PriOp:
+ 			CPPAD_ASSERT_NARG_NRES(op, 5, 0);
 			break;
 			// -------------------------------------------------
 
-			case PrivOp:
- 			CPPAD_ASSERT_NARG_NRES(op, 2, 0);
+			case SignOp:
+			CPPAD_ASSERT_NARG_NRES(op, 1, 1);
+			// derivative is identically zero
 			break;
 			// -------------------------------------------------
 
 			case SinOp:
-			// sine and cosine must come in pairs
-			// but i_var should only be used here
+			// cos(x), sin(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
 			reverse_sparse_jacobian_unary_op(
 				i_var, arg[0], var_sparsity
@@ -400,8 +410,7 @@ void RevJacSweep(
 			// -------------------------------------------------
 
 			case SinhOp:
-			// hyperbolic sine and cosine must come in pairs
-			// but i_var should only be used here
+			// cosh(x), sinh(x)
 			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
 			reverse_sparse_jacobian_unary_op(
 				i_var, arg[0], var_sparsity
@@ -428,7 +437,7 @@ void RevJacSweep(
 				op,
 				arg,
 				num_vecad_ind,
-				vecad_ind,
+				vecad_ind.data(),
 				var_sparsity,
 				vecad_sparsity
 			);
@@ -445,7 +454,7 @@ void RevJacSweep(
 				op,
 				arg,
 				num_vecad_ind,
-				vecad_ind,
+				vecad_ind.data(),
 				var_sparsity,
 				vecad_sparsity
 			);
@@ -476,6 +485,119 @@ void RevJacSweep(
 			break;
 			// -------------------------------------------------
 
+			case TanOp:
+			// tan(x)^2, tan(x)
+			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
+			reverse_sparse_jacobian_unary_op(
+				i_var, arg[0], var_sparsity
+			);
+			break;
+			// -------------------------------------------------
+
+			case TanhOp:
+			// tanh(x)^2, tanh(x)
+			CPPAD_ASSERT_NARG_NRES(op, 1, 2);
+			reverse_sparse_jacobian_unary_op(
+				i_var, arg[0], var_sparsity
+			);
+			break;
+			// -------------------------------------------------
+
+			case UserOp:
+			// start or end atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( NumRes( UserOp ) == 0 );
+			CPPAD_ASSERT_UNKNOWN( NumArg( UserOp ) == 4 );
+			if( user_state == user_end )
+			{	user_index = arg[0];
+				user_id    = arg[1];
+				user_n     = arg[2];
+				user_m     = arg[3];
+				if(user_r.size() < user_n )
+					user_r.resize(user_n);
+				if(user_s.size() < user_m )
+					user_s.resize(user_m);
+				user_j     = user_n;
+				user_i     = user_m;
+				user_state = user_ret;
+			}
+			else
+			{	CPPAD_ASSERT_UNKNOWN( user_state == user_start );
+				CPPAD_ASSERT_UNKNOWN( user_index == size_t(arg[0]) );
+				CPPAD_ASSERT_UNKNOWN( user_id    == size_t(arg[1]) );
+				CPPAD_ASSERT_UNKNOWN( user_n     == size_t(arg[2]) );
+				CPPAD_ASSERT_UNKNOWN( user_m     == size_t(arg[3]) );
+				user_state = user_end;
+               }
+			break;
+
+			case UsrapOp:
+			// parameter argument in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_arg );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_j && user_j <= user_n );
+			CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
+			--user_j;
+			if( user_j == 0 )
+				user_state = user_start;
+			break;
+
+			case UsravOp:
+			// variable argument in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_arg );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_j && user_j <= user_n );
+			CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) <= i_var );
+			CPPAD_ASSERT_UNKNOWN( 0 < arg[0] );
+			--user_j;
+			// It might be faster if we add set union to var_sparsity
+			// where one of the sets is not in var_sparsity.
+			set_itr = user_r[user_j].begin();
+			set_end = user_r[user_j].end();
+			while( set_itr != set_end )
+				var_sparsity.add_element(arg[0], *set_itr++);	
+			if( user_j == 0 )
+				user_state = user_start;
+			break;
+
+			case UsrrpOp:
+			// parameter result in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_ret );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_i && user_i <= user_m );
+			CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
+			--user_i;
+			user_s[user_i].clear();
+			if( user_i == 0 )
+			{	// call users function for this operation
+				user_atomic<Base>::rev_jac_sparse(user_index, user_id,
+					user_n, user_m, user_q, user_r, user_s
+				);
+				user_state = user_arg;
+			}
+			break;
+
+			case UsrrvOp:
+			// variable result in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_ret );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_i && user_i <= user_m );
+			--user_i;
+			user_s[user_i].clear();
+			var_sparsity.begin(i_var);
+			i = var_sparsity.next_element();
+			while( i < user_q )
+			{	user_s[user_i].insert(i);
+				i = var_sparsity.next_element();
+			}
+			if( user_i == 0 )
+			{	// call users function for this operation
+				user_atomic<Base>::rev_jac_sparse(user_index, user_id,
+					user_n, user_m, user_q, user_r, user_s
+				);
+				user_state = user_arg;
+			}
+			break;
+			// -------------------------------------------------
+
 			default:
 			CPPAD_ASSERT_UNKNOWN(0);
 		}
@@ -505,13 +627,11 @@ void RevJacSweep(
 	CPPAD_ASSERT_UNKNOWN( i_op == 0 );
 	CPPAD_ASSERT_UNKNOWN( i_var == 0 );
 
-	if( vecad_ind != CPPAD_NULL )
-		CPPAD_TRACK_DEL_VEC( vecad_ind);
-
 	return;
 }
+CPPAD_END_NAMESPACE
 
+// preprocessor symbols that are local to this file
 # undef CPPAD_REV_JAC_SWEEP_TRACE
 
-CPPAD_END_NAMESPACE
 # endif
