@@ -1,9 +1,9 @@
-/* $Id: rev_sparse_hes.hpp 1698 2010-06-02 16:34:43Z bradbell $ */
+/* $Id: rev_sparse_hes.hpp 2023 2011-07-25 17:44:12Z bradbell $ */
 # ifndef CPPAD_REV_SPARSE_HES_INCLUDED
 # define CPPAD_REV_SPARSE_HES_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -47,7 +47,7 @@ We define the matrix $latex H(x) \in \R^{q \times n}$$
 as the partial with respect to $latex x$$,
 of the partial with respect to $latex u$$ (at $latex u = 0$$),
 of $latex S * F[ x + R * u ]$$ where
-$latex R \in \R^{q \times n}$$ and $latex S \in \R^{1 \times m}$$; i.e.,
+$latex R \in \R^{n \times q}$$ and $latex S \in \R^{1 \times m}$$; i.e.,
 $latex \[
 	H(x)  =  R^\T (S * F)^{(2)} ( x )
 \] $$
@@ -72,7 +72,7 @@ The argument $icode q$$ has prototype
 $codei%
 	size_t %q%
 %$$
-It specifies the number of columns in $latex R \in \R{n \times q}$$
+It specifies the number of columns in $latex R \in \R^{n \times q}$$
 and the number of rows in 
 $latex H(x) \in \R^{q \times n}$$.
 It must be the same value as in the previous $xref/ForSparseJac/$$ call 
@@ -160,6 +160,8 @@ $end
 -----------------------------------------------------------------------------
 */
 # include <algorithm>
+# include <cppad/local/pod_vector.hpp>
+# include <cppad/local/std_set.hpp>
 
 CPPAD_BEGIN_NAMESPACE
 /*!
@@ -263,8 +265,8 @@ void RevSparseHesBool(
 
 	// Array that will hold reverse Jacobian dependency flag.
 	// Initialize as true for the dependent variables.
-	bool *RevJac = CPPAD_NULL;
-	RevJac       = CPPAD_TRACK_NEW_VEC(total_num_var, RevJac);	
+	pod_vector<bool> RevJac;
+	RevJac.extend(total_num_var);	
 	for(i = 0; i < total_num_var; i++)
 		RevJac[i] = false;
 	for(i = 0; i < m; i++)
@@ -283,7 +285,7 @@ void RevSparseHesBool(
 		total_num_var,
 		&play,
 		for_jac_sparsity, 
-		RevJac,
+		RevJac.data(),
 		rev_hes_sparsity
 	);
 
@@ -310,9 +312,6 @@ void RevSparseHesBool(
 		}
 	}
 
-	// free local memory used for the calculation
-	CPPAD_TRACK_DEL_VEC(RevJac);
-
 	return;
 }
 
@@ -395,14 +394,9 @@ void RevSparseHesSet(
 	std::set<size_t>::const_iterator itr;
 
 	// check VectorSet is Simple Vector class with sets for elements
-	static std::set<size_t> two, three;
-	if( two.empty() )
-	{	two.insert(2);
-		three.insert(3);
-	}
-	CPPAD_ASSERT_UNKNOWN( two.size() == 1 );
-	CPPAD_ASSERT_UNKNOWN( three.size() == 1 );
-	CheckSimpleVector<std::set<size_t>, VectorSet>(two, three);
+	CheckSimpleVector<std::set<size_t>, VectorSet>(
+		one_element_std_set<size_t>(), two_element_std_set<size_t>()
+	);
 
 	// range and domain dimensions for F
 # ifndef NDEBUG
@@ -422,8 +416,8 @@ void RevSparseHesSet(
 
 	// Array that will hold reverse Jacobian dependency flag.
 	// Initialize as true for the dependent variables.
-	bool *RevJac = CPPAD_NULL;
-	RevJac       = CPPAD_TRACK_NEW_VEC(total_num_var, RevJac);	
+	pod_vector<bool> RevJac;
+	RevJac.extend(total_num_var);	
 	for(i = 0; i < total_num_var; i++)
 		RevJac[i] = false;
 	itr = s[0].begin();
@@ -449,7 +443,7 @@ void RevSparseHesSet(
 		total_num_var,
 		&play,
 		for_jac_sparsity, 
-		RevJac,
+		RevJac.data(),
 		rev_hes_sparsity
 	);
 
@@ -472,9 +466,6 @@ void RevSparseHesSet(
 		}
 	}
 
-	// free local memory used for the calculation
-	CPPAD_TRACK_DEL_VEC(RevJac);
-
 	return;
 }
 
@@ -527,6 +518,8 @@ VectorSet ADFun<Base>::RevSparseHes(size_t q,  const VectorSet& s)
 {	VectorSet h;
 	typedef typename VectorSet::value_type Set_type;
 
+	// Should check to make sure q is same as in previous call to
+	// forward sparse Jacobian.
 	RevSparseHesCase(
 		Set_type()    ,
 		q             ,
