@@ -1,9 +1,9 @@
-/* $Id: rev_sparse_jac.hpp 1641 2010-02-01 16:39:45Z bradbell $ */
+/* $Id: rev_sparse_jac.hpp 2006 2011-07-12 17:35:39Z bradbell $ */
 # ifndef CPPAD_REV_SPARSE_JAC_INCLUDED
 # define CPPAD_REV_SPARSE_JAC_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -36,10 +36,6 @@ $index pattern, reverse Jacobian$$
 
 $head Syntax$$
 $icode%r% = %F%.RevSparseJac(%p%, %s%)%$$
-$pre
-$$
-$icode%r% = %F%.RevSparseJac(%p%, %s%, %packed%)%$$
-
 
 $head Purpose$$
 We use $latex F : \R^n \rightarrow R^m$$ to denote the
@@ -131,6 +127,8 @@ $end
 -----------------------------------------------------------------------------
 */
 
+# include <cppad/local/std_set.hpp>
+
 CPPAD_BEGIN_NAMESPACE
 /*!
 \file rev_sparse_jac.hpp
@@ -323,14 +321,9 @@ void RevSparseJacSet(
 	std::set<size_t>::const_iterator itr;
 
 	// check VectorSet is Simple Vector class with sets for elements
-	static std::set<size_t> two, three;
-	if( two.empty() )
-	{	two.insert(2);
-		three.insert(3);
-	}
-	CPPAD_ASSERT_UNKNOWN( two.size() == 1 );
-	CPPAD_ASSERT_UNKNOWN( three.size() == 1 );
-	CheckSimpleVector<std::set<size_t>, VectorSet>(two, three);
+	CheckSimpleVector<std::set<size_t>, VectorSet>(
+		one_element_std_set<size_t>(), two_element_std_set<size_t>()
+	);
 
 	// range and domain dimensions for F
 	size_t m = dep_taddr.size();
