@@ -1,9 +1,9 @@
-/* $Id: reverse_sweep.hpp 1659 2010-03-11 03:48:31Z bradbell $ */
+/* $Id: reverse_sweep.hpp 2240 2011-12-31 05:33:55Z bradbell $ */
 # ifndef CPPAD_REVERSE_SWEEP_INCLUDED
 # define CPPAD_REVERSE_SWEEP_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -143,7 +143,7 @@ void ReverseSweep(
 	size_t         i_op;
 	size_t        i_var;
 
-	const size_t   *arg = 0;
+	const addr_t*   arg = 0;
 
 	// check numvar argument
 	CPPAD_ASSERT_UNKNOWN( Rec->num_rec_var() == numvar );
@@ -157,6 +157,26 @@ void ReverseSweep(
 	if( num_par > 0 )
 		parameter = Rec->GetPar();
 
+	// work space used by UserOp.
+	const size_t user_k  = d;    // order of this forward mode calculation
+	const size_t user_k1 = d+1;  // number of orders for this calculation
+	vector<size_t> user_ix;      // variable indices for argument vector
+	vector<Base> user_tx;        // argument vector Taylor coefficients
+	vector<Base> user_ty;        // result vector Taylor coefficients
+	vector<Base> user_px;        // partials w.r.t argument vector
+	vector<Base> user_py;        // partials w.r.t. result vector
+	size_t user_index = 0;       // indentifier for this user_atomic operation
+	size_t user_id    = 0;       // user identifier for this call to operator
+	size_t user_i     = 0;       // index in result vector
+	size_t user_j     = 0;       // index in argument vector
+	size_t user_m     = 0;       // size of result vector
+	size_t user_n     = 0;       // size of arugment vector
+	// next expected operator in a UserOp sequence
+	enum { user_start, user_arg, user_ret, user_end } user_state = user_end;
+
+	// temporary indices
+	size_t j, ell;
+
 	// Initialize
 	Rec->start_reverse(op, arg, i_op, i_var);
 	CPPAD_ASSERT_UNKNOWN( op == EndOp );
@@ -210,7 +230,7 @@ void ReverseSweep(
 			// --------------------------------------------------
 
 			case AddpvOp:
-			CPPAD_ASSERT_UNKNOWN( arg[0] < num_par );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
 			reverse_addpv_op(
 				d, i_var, arg, parameter, J, Taylor, K, Partial
 			);
@@ -218,7 +238,7 @@ void ReverseSweep(
 			// --------------------------------------------------
 
 			case AcosOp:
-                        // results: sqrt(1 - x * x), acos(x) 
+                        // sqrt(1 - x * x), acos(x)
 			CPPAD_ASSERT_UNKNOWN( i_var < numvar );
 			reverse_acos_op(
 				d, i_var, arg[0], J, Taylor, K, Partial
@@ -227,7 +247,7 @@ void ReverseSweep(
 			// --------------------------------------------------
 
 			case AsinOp:
-                        // results: sqrt(1 - x * x), sin(x) 
+                        // sqrt(1 - x * x), asin(x)
 			CPPAD_ASSERT_UNKNOWN( i_var < numvar );
 			reverse_asin_op(
 				d, i_var, arg[0], J, Taylor, K, Partial
@@ -236,7 +256,7 @@ void ReverseSweep(
 			// --------------------------------------------------
 
 			case AtanOp:
-                        // results: 1 + x * x, atan(x) 
+                        // 1 + x * x, atan(x)
 			CPPAD_ASSERT_UNKNOWN( i_var < numvar );
 			reverse_atan_op(
 				d, i_var, arg[0], J, Taylor, K, Partial
@@ -310,7 +330,7 @@ void ReverseSweep(
 			// --------------------------------------------------
 
 			case DivpvOp:
-			CPPAD_ASSERT_UNKNOWN( arg[0] < num_par );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
 			reverse_divpv_op(
 				d, i_var, arg, parameter, J, Taylor, K, Partial
 			);
@@ -318,7 +338,7 @@ void ReverseSweep(
 			// --------------------------------------------------
 
 			case DivvpOp:
-			CPPAD_ASSERT_UNKNOWN( arg[1] < num_par );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < num_par );
 			reverse_divvp_op(
 				d, i_var, arg, parameter, J, Taylor, K, Partial
 			);
@@ -364,7 +384,7 @@ void ReverseSweep(
 			// --------------------------------------------------
 
 			case MulpvOp:
-			CPPAD_ASSERT_UNKNOWN( arg[0] < num_par );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
 			reverse_mulpv_op(
 				d, i_var, arg, parameter, J, Taylor, K, Partial
 			);
@@ -376,7 +396,7 @@ void ReverseSweep(
 			// --------------------------------------------------
 
 			case PowvpOp:
-			CPPAD_ASSERT_UNKNOWN( arg[1] < num_par );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < num_par );
 			reverse_powvp_op(
 				d, i_var, arg, parameter, J, Taylor, K, Partial
 			);
@@ -384,7 +404,7 @@ void ReverseSweep(
 			// -------------------------------------------------
 
 			case PowpvOp:
-			CPPAD_ASSERT_UNKNOWN( arg[0] < num_par );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
 			reverse_powpv_op(
 				d, i_var, arg, parameter, J, Taylor, K, Partial
 			);
@@ -398,15 +418,17 @@ void ReverseSweep(
 			break;
 			// --------------------------------------------------
 
-			case PripOp:
+			case PriOp:
 			// no result so nothing to do
 			break;
 			// --------------------------------------------------
 
-			case PrivOp:
-			// no result so nothing to do
+			case SignOp:
+			CPPAD_ASSERT_UNKNOWN( i_var < numvar );
+			reverse_sign_op(
+				d, i_var, arg[0], J, Taylor, K, Partial
+			);
 			break;
-
 			// -------------------------------------------------
 
 			case SinOp:
@@ -456,7 +478,7 @@ void ReverseSweep(
 			// --------------------------------------------------
 
 			case SubpvOp:
-			CPPAD_ASSERT_UNKNOWN( arg[0] < num_par );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
 			reverse_subpv_op(
 				d, i_var, arg, parameter, J, Taylor, K, Partial
 			);
@@ -464,15 +486,138 @@ void ReverseSweep(
 			// --------------------------------------------------
 
 			case SubvpOp:
-			CPPAD_ASSERT_UNKNOWN( arg[1] < num_par );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < num_par );
 			reverse_subvp_op(
 				d, i_var, arg, parameter, J, Taylor, K, Partial
 			);
 			break;
+			// -------------------------------------------------
+
+			case TanOp:
+			CPPAD_ASSERT_UNKNOWN( i_var < numvar );
+			reverse_tan_op(
+				d, i_var, arg[0], J, Taylor, K, Partial
+			);
+			break;
+			// -------------------------------------------------
+
+			case TanhOp:
+			CPPAD_ASSERT_UNKNOWN( i_var < numvar );
+			reverse_tanh_op(
+				d, i_var, arg[0], J, Taylor, K, Partial
+			);
+			break;
 			// --------------------------------------------------
 
+			case UserOp:
+			// start or end an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( NumRes( UserOp ) == 0 );
+			CPPAD_ASSERT_UNKNOWN( NumArg( UserOp ) == 4 );
+			if( user_state == user_end )
+			{	user_index = arg[0];
+				user_id    = arg[1];
+				user_n     = arg[2];
+				user_m     = arg[3];
+				if(user_ix.size() < user_n)
+					user_ix.resize(user_n);
+				if(user_tx.size() < user_n * user_k1)
+				{	user_tx.resize(user_n * user_k1);
+					user_px.resize(user_n * user_k1);
+				}
+				if(user_ty.size() < user_m * user_k1)
+				{	user_ty.resize(user_m * user_k1);
+					user_py.resize(user_m * user_k1);
+				}
+				user_j     = user_n;
+				user_i     = user_m;
+				user_state = user_ret;
+			}
+			else
+			{	CPPAD_ASSERT_UNKNOWN( user_state == user_start );
+				CPPAD_ASSERT_UNKNOWN( user_index == size_t(arg[0]) );
+				CPPAD_ASSERT_UNKNOWN( user_id    == size_t(arg[1]) );
+				CPPAD_ASSERT_UNKNOWN( user_n     == size_t(arg[2]) );
+				CPPAD_ASSERT_UNKNOWN( user_m     == size_t(arg[3]) );
+				user_state = user_end;
+
+				// call users function for this operation
+				user_atomic<Base>::reverse(user_index, user_id,
+					user_k, user_n, user_m, user_tx, user_ty,
+					user_px, user_py
+				);
+				for(j = 0; j < user_n; j++) if( user_ix[j] > 0 )
+				{	for(ell = 0; ell < user_k1; ell++)
+						Partial[user_ix[j] * K + ell] +=
+							user_px[j * user_k1 + ell];
+				}
+			}
+			break;
+
+			case UsrapOp:
+			// parameter argument in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_arg );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_j && user_j <= user_n );
+			CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
+			--user_j;
+			user_ix[user_j] = 0;
+			user_tx[user_j * user_k1 + 0] = parameter[ arg[0]];
+			for(ell = 1; ell < user_k1; ell++)
+				user_tx[user_j * user_k1 + ell] = Base(0.);
+			
+			if( user_j == 0 )
+				user_state = user_start;
+			break;
+
+			case UsravOp:
+			// variable argument in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_arg );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_j && user_j <= user_n );
+			CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) <= i_var );
+			CPPAD_ASSERT_UNKNOWN( 0 < arg[0] );
+			--user_j;
+			user_ix[user_j] = arg[0];
+			for(ell = 0; ell < user_k1; ell++)
+				user_tx[user_j*user_k1 + ell] = Taylor[ arg[0] * J + ell];
+			if( user_j == 0 )
+				user_state = user_start;
+			break;
+
+			case UsrrpOp:
+			// parameter result in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_ret );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_i && user_i <= user_m );
+			CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
+			--user_i;
+			for(ell = 0; ell < user_k1; ell++)
+			{	user_py[user_i * user_k1 + ell] = Base(0.);
+				user_ty[user_i * user_k1 + ell] = Base(0.);
+			}
+			user_ty[user_i * user_k1 + 0] = parameter[ arg[0] ];
+			if( user_i == 0 )
+				user_state = user_arg;
+			break;
+
+			case UsrrvOp:
+			// variable result in an atomic operation sequence
+			CPPAD_ASSERT_UNKNOWN( user_state == user_ret );
+			CPPAD_ASSERT_UNKNOWN( 0 < user_i && user_i <= user_m );
+			--user_i;
+			for(ell = 0; ell < user_k1; ell++)
+			{	user_py[user_i * user_k1 + ell] =
+						Partial[i_var * K + ell];
+				user_ty[user_i * user_k1 + ell] =
+						Taylor[i_var * J + ell];
+			}
+			if( user_i == 0 )
+				user_state = user_arg;
+			break;
+			// ------------------------------------------------------------
+
 			default:
-			CPPAD_ASSERT_UNKNOWN(0);
+			CPPAD_ASSERT_UNKNOWN(false);
 		}
 	}
 # if CPPAD_REVERSE_SWEEP_TRACE
@@ -483,7 +628,9 @@ void ReverseSweep(
 	CPPAD_ASSERT_UNKNOWN( i_var == 0 );
 }
 
+CPPAD_END_NAMESPACE
+
+// preprocessor symbols that are local to this file
 # undef CPPAD_REVERSE_SWEEP_TRACE
 
-CPPAD_END_NAMESPACE
 # endif
