@@ -1,9 +1,9 @@
-/* $Id: sparse_jacobian.hpp 1641 2010-02-01 16:39:45Z bradbell $ */
+/* $Id: sparse_jacobian.hpp 2006 2011-07-12 17:35:39Z bradbell $ */
 # ifndef CPPAD_SPARSE_JACOBIAN_INCLUDED
 # define CPPAD_SPARSE_JACOBIAN_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -154,6 +154,7 @@ It return $code true$$, if it succeeds and $code false$$ otherwise.
 $end
 -----------------------------------------------------------------------------
 */
+# include <cppad/local/std_set.hpp>
 
 CPPAD_BEGIN_NAMESPACE
 /*!
@@ -392,14 +393,9 @@ void ADFun<Base>::SparseJacobianCase(
 	const Base one(1);
 
 	// check VectorSet is Simple Vector class with sets for elements
-	static std::set<size_t> two, three;
-	if( two.empty() )
-	{	two.insert(2);
-		three.insert(3);
-	}
-	CPPAD_ASSERT_UNKNOWN( two.size() == 1 );
-	CPPAD_ASSERT_UNKNOWN( three.size() == 1 );
-	CheckSimpleVector<std::set<size_t>, VectorSet>(two, three);
+	CheckSimpleVector<std::set<size_t>, VectorSet>(
+		one_element_std_set<size_t>(), two_element_std_set<size_t>()
+	);
 
 	// check VectorBase is Simple Vector class with Base type elements
 	CheckSimpleVector<Base, VectorBase>();
