@@ -1,3 +1,4 @@
+// $Id: sparse_set.hpp 2178 2011-10-30 06:52:58Z bradbell $
 # ifndef CPPAD_SPARSE_SET_INCLUDED
 # define CPPAD_SPARSE_SET_INCLUDED
 
@@ -13,6 +14,7 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 # include <set>
 # include <algorithm>
+# include <iterator>
 # include <cppad/local/cppad_assert.hpp>
 
 
@@ -107,7 +109,10 @@ public:
 	\li element  < end_
 	*/
 	void add_element(size_t index, size_t element)
-	{
+	{	// This routine should use the std::insert operator
+		// that cashes the iterator of previous insertion for when
+		// insertions occur in order. We should speed test that this
+		// actually makes things faster.
 		CPPAD_ASSERT_UNKNOWN( index   < n_set_ );
 		CPPAD_ASSERT_UNKNOWN( element < end_ );
 		data_[ index ].insert( element );
