@@ -1,9 +1,9 @@
-/* $Id: sub_op.hpp 1681 2010-04-25 02:24:21Z bradbell $ */
+/* $Id: sub_op.hpp 1986 2011-06-18 20:33:17Z bradbell $ */
 # ifndef CPPAD_SUB_OP_INCLUDED
 # define CPPAD_SUB_OP_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -38,7 +38,7 @@ template <class Base>
 inline void forward_subvv_op(
 	size_t        d           , 
 	size_t        i_z         ,
-	const size_t* arg         ,
+	const addr_t* arg         ,
 	const Base*   parameter   ,
 	size_t        nc_taylor   ,
 	Base*         taylor      )
@@ -46,8 +46,8 @@ inline void forward_subvv_op(
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(SubvvOp) == 2 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(SubvvOp) == 1 );
-	CPPAD_ASSERT_UNKNOWN( arg[0] < i_z );
-	CPPAD_ASSERT_UNKNOWN( arg[1] < i_z );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < i_z );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < i_z );
 	CPPAD_ASSERT_UNKNOWN( d < nc_taylor );
 
 	// Taylor coefficients corresponding to arguments and result
@@ -75,7 +75,7 @@ and the argument \a parameter is not used.
 template <class Base>
 inline void forward_subvv_op_0(
 	size_t        i_z         ,
-	const size_t* arg         ,
+	const addr_t* arg         ,
 	const Base*   parameter   ,
 	size_t        nc_taylor   ,
 	Base*         taylor      )
@@ -83,8 +83,8 @@ inline void forward_subvv_op_0(
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(SubvvOp) == 2 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(SubvvOp) == 1 );
-	CPPAD_ASSERT_UNKNOWN( arg[0] < i_z );
-	CPPAD_ASSERT_UNKNOWN( arg[1] < i_z );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < i_z );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < i_z );
 
 	// Taylor coefficients corresponding to arguments and result
 	Base* x = taylor + arg[0] * nc_taylor;
@@ -112,7 +112,7 @@ template <class Base>
 inline void reverse_subvv_op(
 	size_t        d           , 
 	size_t        i_z         ,
-	const size_t* arg         ,
+	const addr_t* arg         ,
 	const Base*   parameter   ,
 	size_t        nc_taylor   ,
 	const Base*   taylor      ,
@@ -122,8 +122,8 @@ inline void reverse_subvv_op(
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(SubvvOp) == 2 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(SubvvOp) == 1 );
-	CPPAD_ASSERT_UNKNOWN( arg[0] < i_z );
-	CPPAD_ASSERT_UNKNOWN( arg[1] < i_z );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < i_z );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < i_z );
 	CPPAD_ASSERT_UNKNOWN( d < nc_taylor );
 	CPPAD_ASSERT_UNKNOWN( d < nc_partial );
 
@@ -159,7 +159,7 @@ template <class Base>
 inline void forward_subpv_op(
 	size_t        d           , 
 	size_t        i_z         ,
-	const size_t* arg         ,
+	const addr_t* arg         ,
 	const Base*   parameter   ,
 	size_t        nc_taylor   ,
 	Base*         taylor      )
@@ -167,7 +167,7 @@ inline void forward_subpv_op(
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(SubpvOp) == 2 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(SubpvOp) == 1 );
-	CPPAD_ASSERT_UNKNOWN( arg[1] < i_z );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < i_z );
 	CPPAD_ASSERT_UNKNOWN( d < nc_taylor );
 
 	// Taylor coefficients corresponding to arguments and result
@@ -201,7 +201,7 @@ this operations is for the case where x is a parameter and y is a variable.
 template <class Base>
 inline void forward_subpv_op_0(
 	size_t        i_z         ,
-	const size_t* arg         ,
+	const addr_t* arg         ,
 	const Base*   parameter   ,
 	size_t        nc_taylor   ,
 	Base*         taylor      )
@@ -209,7 +209,7 @@ inline void forward_subpv_op_0(
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(SubpvOp) == 2 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(SubpvOp) == 1 );
-	CPPAD_ASSERT_UNKNOWN( arg[1] < i_z );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < i_z );
 
 	// Paraemter value
 	Base x = parameter[ arg[0] ];
@@ -238,7 +238,7 @@ template <class Base>
 inline void reverse_subpv_op(
 	size_t        d           , 
 	size_t        i_z         ,
-	const size_t* arg         ,
+	const addr_t* arg         ,
 	const Base*   parameter   ,
 	size_t        nc_taylor   ,
 	const Base*   taylor      ,
@@ -248,7 +248,7 @@ inline void reverse_subpv_op(
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(SubvvOp) == 2 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(SubvvOp) == 1 );
-	CPPAD_ASSERT_UNKNOWN( arg[1] < i_z );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < i_z );
 	CPPAD_ASSERT_UNKNOWN( d < nc_taylor );
 	CPPAD_ASSERT_UNKNOWN( d < nc_partial );
 
@@ -282,7 +282,7 @@ template <class Base>
 inline void forward_subvp_op(
 	size_t        d           , 
 	size_t        i_z         ,
-	const size_t* arg         ,
+	const addr_t* arg         ,
 	const Base*   parameter   ,
 	size_t        nc_taylor   ,
 	Base*         taylor      )
@@ -290,7 +290,7 @@ inline void forward_subvp_op(
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(SubvpOp) == 2 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(SubvpOp) == 1 );
-	CPPAD_ASSERT_UNKNOWN( arg[0] < i_z );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < i_z );
 	CPPAD_ASSERT_UNKNOWN( d < nc_taylor );
 
 	// Taylor coefficients corresponding to arguments and result
@@ -326,7 +326,7 @@ this operations is for the case where x is a variable and y is a parameter.
 template <class Base>
 inline void forward_subvp_op_0(
 	size_t        i_z         ,
-	const size_t* arg         ,
+	const addr_t* arg         ,
 	const Base*   parameter   ,
 	size_t        nc_taylor   ,
 	Base*         taylor      )
@@ -334,7 +334,7 @@ inline void forward_subvp_op_0(
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(SubvpOp) == 2 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(SubvpOp) == 1 );
-	CPPAD_ASSERT_UNKNOWN( arg[0] < i_z );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < i_z );
 
 	// Parameter value
 	Base y = parameter[ arg[1] ];
@@ -363,7 +363,7 @@ template <class Base>
 inline void reverse_subvp_op(
 	size_t        d           , 
 	size_t        i_z         ,
-	const size_t* arg         ,
+	const addr_t* arg         ,
 	const Base*   parameter   ,
 	size_t        nc_taylor   ,
 	const Base*   taylor      ,
@@ -373,7 +373,7 @@ inline void reverse_subvp_op(
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(SubvpOp) == 2 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(SubvpOp) == 1 );
-	CPPAD_ASSERT_UNKNOWN( arg[0] < i_z );
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < i_z );
 	CPPAD_ASSERT_UNKNOWN( d < nc_taylor );
 	CPPAD_ASSERT_UNKNOWN( d < nc_partial );
 
