@@ -1,9 +1,9 @@
-/* $Id: vec_ad.hpp 1550 2009-10-14 15:24:54Z bradbell $ */
+/* $Id: vec_ad.hpp 2091 2011-09-02 19:47:24Z bradbell $ */
 # ifndef CPPAD_VEC_AD_INCLUDED
 # define CPPAD_VEC_AD_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-09 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -307,6 +307,7 @@ $lend
 $end
 ------------------------------------------------------------------------ 
 */
+# include <cppad/local/pod_vector.hpp>
 
 # define CPPAD_VEC_AD_COMPUTED_ASSIGNMENT(op, name)                     \
 VecAD_reference& operator op (const VecAD_reference<Base> &right)       \
@@ -372,7 +373,7 @@ public:
 		CPPAD_ASSERT_UNKNOWN( i < vec_->length_ );
 
 		// AD<Base> value corresponding to this element
-		result.value_ = *(vec_->data_ + i);
+		result.value_ = vec_->data_[i];
 
 		// this address will be recorded in tape and must be
 		// zero for parameters
@@ -446,7 +447,7 @@ private:
 	const  size_t   length_; 
 
 	// elements of this vector 
-	Base *data_; 
+	pod_vector<Base> data_; 
 
 	// offset in cummulate vector corresponding to this object
 	size_t offset_; 
@@ -458,18 +459,23 @@ public:
 	typedef VecAD_reference<Base> reference;
 
 	// default constructor
-	// initialize id_ to one so not a variable
-	VecAD(void) : length_(0) , data_(CPPAD_NULL), offset_(0), id_(1)
+	// initialize id_ same as for default constructor; see default.hpp
+	VecAD(void) 
+	: length_(0) 
+	, offset_(0)
+	, id_(CPPAD_MAX_NUM_THREADS)
 	{	CPPAD_ASSERT_UNKNOWN( Parameter(*this) ); }
 
 	// constructor 
-	// initialize id_ to one so not a variable
-	VecAD(size_t n) : length_(n), offset_(0), id_(1)
-	{	data_  = CPPAD_NULL;
-		if( length_ > 0 )
+	// initialize id_ same as for parameters; see ad_copy.hpp
+	VecAD(size_t n) 
+	: length_(n)
+	, offset_(0)
+	, id_(CPPAD_MAX_NUM_THREADS)
+	{	if( length_ > 0 )
 		{	size_t i;
 			Base zero(0);
-			data_  = CPPAD_TRACK_NEW_VEC(length_, data_);
+			data_.extend(length_);
 
 			// Initialize data to zero so all have same value.
 			// This uses less memory and avoids a valgrind error
@@ -482,9 +488,7 @@ public:
 
 	// destructor
 	~VecAD(void)
-	{	if( data_ != CPPAD_NULL )
-			CPPAD_TRACK_DEL_VEC(data_); 
-	}
+	{ }
 
 	// size
 	size_t size(void)
@@ -582,7 +586,7 @@ void VecAD_reference<Base>::operator=(const AD<Base> &y)
 	CPPAD_ASSERT_UNKNOWN( i < vec_->length_ );
 
 	// assign value for this element (as an AD<Base> object) 
-	*(vec_->data_ + i) = y.value_;
+	vec_->data_[i] = y.value_;
 
 	// record the setting of this array element
 	CPPAD_ASSERT_UNKNOWN( vec_->offset_ > 0 );
@@ -615,8 +619,8 @@ void VecAD_reference<Base>::operator=(const Base &y)
 	size_t i = static_cast<size_t>( Integer(x_) );
 	CPPAD_ASSERT_UNKNOWN( i < vec_->length_ );
 
-	// assign value for this element (target is an AD<Base> object) 
-	*(vec_->data_ + i) = y;
+	// assign value for this element 
+	vec_->data_[i] = y;
 
 	// check if this ADVec object is a parameter
 	if( Parameter(*vec_) )
@@ -626,7 +630,7 @@ void VecAD_reference<Base>::operator=(const Base &y)
 	CPPAD_ASSERT_UNKNOWN( tape != CPPAD_NULL );
 
 	// put value of the parameter y in the tape
-	size_t p = tape->Rec_.PutPar(y);
+	addr_t p = tape->Rec_.PutPar(y);
 
 	// record the setting of this array element
 	CPPAD_ASSERT_UNKNOWN( vec_->offset_ > 0 );
@@ -655,17 +659,18 @@ void VecAD_reference<Base>::operator=(const Base &y)
 
 // fold this case into AD<Base> case above
 template <class Base>
-CPPAD_INLINE void VecAD_reference<Base>::operator=
+inline void VecAD_reference<Base>::operator=
 (const VecAD_reference<Base> &y)
 {	*this = y.ADBase(); }
 
 // fold this case into Base case above
 template <class Base>
-CPPAD_INLINE void VecAD_reference<Base>::operator=(int y)
+inline void VecAD_reference<Base>::operator=(int y)
 {	*this = Base(y); }
 
 template <class Base>
-CPPAD_INLINE std::ostream& operator << (std::ostream &os, const VecAD<Base> &v)
+CPPAD_INLINE_FRIEND_TEMPLATE_FUNCTION
+std::ostream& operator << (std::ostream &os, const VecAD<Base> &v)
 {
  	os << "vecAD( length = " << v.length_ 
 	   << ", offset = "      << v.offset_ << ")";
@@ -675,6 +680,7 @@ CPPAD_INLINE std::ostream& operator << (std::ostream &os, const VecAD<Base> &v)
 
 } // END CppAD namespace
 
+// preprocessor symbols that are local to this file
 # undef CPPAD_VEC_AD_COMPUTED_ASSIGNMENT
 
 # endif
