@@ -1,6 +1,6 @@
-/* $Id: cppad_ipopt_nlp.cpp 1733 2010-12-22 18:55:11Z bradbell $ */
+/* $Id: cppad_ipopt_nlp.cpp 2234 2011-12-21 13:44:54Z bradbell $ */
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -9,6 +9,8 @@ the terms of the
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
+# include <limits>
+
 # include "cppad_ipopt_nlp.hpp"
 # include "sparse_map2vec.hpp"
 # include "jac_g_map.hpp"
@@ -28,6 +30,10 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <cstdio>
 # endif
 
+// ---------------------------------------------------------------------------
+namespace cppad_ipopt {
+// ---------------------------------------------------------------------------
+
 
 /*! 
 Constructor for the \ref Nonlinear_Programming_Problem.
@@ -117,7 +123,8 @@ cppad_ipopt_nlp::cppad_ipopt_nlp(
 	  g_l_ ( g_l ),
 	  g_u_ ( g_u ),
 	  fg_info_ ( fg_info ) ,
-	  solution_ (solution)
+	  solution_ (solution) ,
+	  infinity_ ( std::numeric_limits<Number>::infinity() )
 {	size_t k;
 
 	// set information needed in cppad_ipopt_fg_info
@@ -177,7 +184,7 @@ cppad_ipopt_nlp::cppad_ipopt_nlp(
 	// record r[k] for functions that do not need retaping
 	for(k = 0; k < K_; k++)
 	{	tape_ok_[k] = false;
-		 if( ! retape_[k] )
+		if( ! retape_[k] )
 		{	// Operation sequence does not depend on value 
 			// of u so record it once here in the constructor.
 			fg_info_->index(k, 0, I_, J_);
@@ -191,6 +198,9 @@ cppad_ipopt_nlp::cppad_ipopt_nlp(
 				J_              ,
 				r_fun_              // output
 			);
+			// take time to optimize because only recording once
+			r_fun_[k].optimize();
+			// ok and will stay that way
 			tape_ok_[k] = true;
 		}
 	}
@@ -410,7 +420,7 @@ bool cppad_ipopt_nlp::eval_f(
 
 	// update tape_ok_ flag
 	for(k = 0; k < K_; k++) 
-	{	if( new_x && retape_[k] )
+	{	if( retape_[k] && (new_x || L_[k] > 1) )
 			tape_ok_[k] = false;
 	}
 
@@ -429,9 +439,7 @@ bool cppad_ipopt_nlp::eval_f(
 					J_              ,
 					r_fun_             // output
 				);
-				if( retape_[k] )
-					tape_ok_[k] = L_[k] <= 1;
-				else	tape_ok_[k] = true;
+				tape_ok_[k] = ! (retape_[k] || L_[k] > 1);
 			}
 			NumberVector u(q_[k]);
 			NumberVector r(p_[k]);
@@ -448,6 +456,12 @@ bool cppad_ipopt_nlp::eval_f(
 	for(j = 0; j < n_; j++)
 		printf("cppad_ipopt_nlp::eval_f::x[%d] = %20.14g\n", j, x[j]);
 	printf("cppad_ipopt_nlp::eval_f::obj_value = %20.14g\n", obj_value);
+# endif
+# ifndef NDEBUG
+	CPPAD_ASSERT_KNOWN(
+		(-infinity_ < obj_value) && (obj_value < infinity_),
+		"cppad_ipopt_nlp::eval_f:: objective value is not finite"
+	);
 # endif
 	return true;
 }
@@ -488,7 +502,7 @@ bool cppad_ipopt_nlp::eval_grad_f(
 
 	// update tape_ok_ flag
 	for(k = 0; k < K_; k++) 
-	{	if( new_x && retape_[k] )
+	{	if( retape_[k] && (new_x || L_[k] > 1) )
 			tape_ok_[k] = false;
 	}
 
@@ -507,9 +521,7 @@ bool cppad_ipopt_nlp::eval_grad_f(
 					J_              ,
 					r_fun_              // output
 				);
-				if( retape_[k] )
-					tape_ok_[k] = L_[k] <= 1;
-				else	tape_ok_[k] = true;
+				tape_ok_[k] = ! (retape_[k] || L_[k] > 1);
 			}
 			NumberVector u(q_[k]);
 			NumberVector w(p_[k]);
@@ -537,6 +549,12 @@ bool cppad_ipopt_nlp::eval_grad_f(
 	for(j = 0; j < n_; j++) printf(
 	"cppad_ipopt_nlp::eval_grad_f::grad_f[%d] = %20.14g\n", j, grad_f[j]
 	);
+# endif
+# ifndef NDEBUG
+	for(j = 0; j < n_; j++) CPPAD_ASSERT_KNOWN(
+		(-infinity_ < grad_f[j]) && (grad_f[j] < infinity_),
+		"cppad_ipopt_nlp::grad_f:: gradient of objective is not finite"
+	);
 # endif
 	return true;
 }
@@ -580,7 +598,7 @@ bool cppad_ipopt_nlp::eval_g(
 
 	// update tape_ok_ flag
 	for(k = 0; k < K_; k++) 
-	{	if( new_x && retape_[k] )
+	{	if( retape_[k] && (new_x || L_[k] > 1) )
 			tape_ok_[k] = false;
 	}
 
@@ -599,9 +617,7 @@ bool cppad_ipopt_nlp::eval_g(
 				r_fun_              // output
 			);
 		}
-		if( retape_[k] )
-			tape_ok_[k] = L_[k] <= 1;
-		else	tape_ok_[k] = true;
+		tape_ok_[k] = ! (retape_[k] || L_[k] > 1);
 		NumberVector u(q_[k]);
 		NumberVector r(p_[k]);
 		for(j = 0; j < q_[k]; j++)
@@ -621,6 +637,12 @@ bool cppad_ipopt_nlp::eval_g(
 		printf("cppad_ipopt_nlp::eval_g::x[%d] = %20.14g\n", j, x[j]);
 	for(i = 0; i < m_; i++)
 		printf("cppad_ipopt_nlp::eval_g::g[%d] = %20.14g\n", i, g[i]);
+# endif
+# ifndef NDEBUG
+	for(i = 0; i < m_; i++) CPPAD_ASSERT_KNOWN(
+		(-infinity_ < g[i]) && (g[i] < infinity_),
+		"cppad_ipopt_nlp::eval_g:: not all constraints are not finite"
+	);
 # endif
 	return true;
 }
@@ -705,7 +727,7 @@ bool cppad_ipopt_nlp::eval_jac_g(Index n, const Number* x, bool new_x,
 
 	// update tape_ok_ flag
 	for(k = 0; k < K_; k++) 
-	{	if( new_x && retape_[k] )
+	{	if( retape_[k] && (new_x || L_[k] > 1) )
 			tape_ok_[k] = false;
 	}
 
@@ -724,9 +746,7 @@ bool cppad_ipopt_nlp::eval_jac_g(Index n, const Number* x, bool new_x,
 				r_fun_              // output
 			);
 		}
-		if( retape_[k] )
-			tape_ok_[k] = L_[k] <= 1;
-		else	tape_ok_[k] = true;
+		tape_ok_[k] = ! (retape_[k] || L_[k] > 1);
 		NumberVector u(q_[k]);
 		NumberVector jac_r(p_[k] * q_[k]);
 		for(j = 0; j < q_[k]; j++)
@@ -750,6 +770,14 @@ bool cppad_ipopt_nlp::eval_jac_g(Index n, const Number* x, bool new_x,
 			}
 		}
 	}
+# ifndef NDEBUG
+	for(l = 0; l < nnz_jac_g_; l++) CPPAD_ASSERT_KNOWN(
+		(-infinity_ < values[l]) && (values[l] < infinity_),
+		"cppad_ipopt_nlp::eval_jac_g:: a component of "
+		"gradient of g is not finite"
+	);
+# endif
+
   	return true;
 }
 
@@ -854,7 +882,7 @@ bool cppad_ipopt_nlp::eval_h(Index n, const Number* x, bool new_x,
 
 	// update tape_ok_ flag
 	for(k = 0; k < K_; k++) 
-	{	if( new_x && retape_[k] )
+	{	if( retape_[k] && (new_x || L_[k] > 1) )
 			tape_ok_[k] = false;
 	}
 
@@ -880,9 +908,7 @@ bool cppad_ipopt_nlp::eval_h(Index n, const Number* x, bool new_x,
 					J_              ,
 					r_fun_              // output
 				);
-				if( retape_[k] )
-					tape_ok_[k] = L_[k] <= 1;
-				else	tape_ok_[k] = true;
+				tape_ok_[k] = ! (retape_[k] || L_[k] > 1);
 			}
 			NumberVector w(p_[k]);
 			NumberVector r_hes(q_[k] * q_[k]);
@@ -915,6 +941,13 @@ bool cppad_ipopt_nlp::eval_h(Index n, const Number* x, bool new_x,
 			}
 		}
 	}
+# ifndef NDEBUG
+	for(l = 0; l < nnz_h_lag_; l++) CPPAD_ASSERT_KNOWN(
+		(-infinity_ < values[l]) && (values[l] < infinity_),
+		"cppad_ipopt_nlp::eval_h:: a component of "
+		"Hessian of Lagragian is not finite"
+	);
+# endif
 	return true;
 }
 
@@ -1104,3 +1137,7 @@ bool cppad_ipopt_nlp::intermediate_callback(
 	// std::cout << "intermediate_callback called" << std::endl;
 	return true;
 }
+
+// ---------------------------------------------------------------------------
+} // end namespace cppad_ipopt
+// ---------------------------------------------------------------------------
