@@ -1,8 +1,8 @@
-/* $Id: cppad_ipopt_nlp.hpp 1733 2010-12-22 18:55:11Z bradbell $ */
-# ifndef CPPAD_IPOPT_NLP_INCLUDED
-# define CPPAD_IPOPT_NLP_INCLUDED
+/* $Id: cppad_ipopt_nlp.hpp 2236 2011-12-26 14:08:37Z bradbell $ */
+# ifndef CPPAD_CPPAD_IPOPT_NLP_INCLUDED
+# define CPPAD_CPPAD_IPOPT_NLP_INCLUDED
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -13,7 +13,10 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 /*
 $begin cppad_ipopt_nlp$$
+$dollar @$$
 $spell
+	namespace
+	dir
 	cppad
 	bool
 	doesn't
@@ -43,11 +46,13 @@ $index AD, Ipopt$$
 $head Syntax$$
 $codei%# include "cppad_ipopt_nlp.hpp"
 %$$
-$codei%# cppad_ipopt_solution %solution%;
+$codei%cppad_ipopt_solution %solution%;
 %$$
 $codei%cppad_ipopt_nlp %cppad_nlp%(
 	%n%, %m%, %x_i%, %x_l%, %x_u%, %g_l%, %g_u%, &%fg_info%, &%solution%
 )%$$
+$codei%
+export LD_LIBRARY_PATH=@LD_LIBRARY_PATH:%ipopt_library_paths%$$
 
 $head Purpose$$
 The class $code cppad_ipopt_nlp$$ is used to solve nonlinear programming
@@ -63,7 +68,7 @@ $latex \[
 \] $$
 This is done using 
 $href%
-	https://www.coin-or.org/projects/Ipopt%
+	http://www.coin-or.org/projects/Ipopt.xml%
 	Ipopt
 %$$
 optimizer and 
@@ -73,6 +78,23 @@ $href%
 %$$
 Algorithmic Differentiation package.
 
+$head cppad_ipopt namespace$$
+All of the declarations for these routines
+are in the $code cppad_ipopt$$ namespace 
+(not the $code CppAD$$ namespace).
+For example; $cref/SizeVector/cppad_ipopt_nlp/SizeVector/$$ below
+actually denotes the type $code cppad_ipopt::SizeVector$$.
+
+$head ipopt_library_paths$$
+If you are linking to a shared version of the Ipopt library,
+you may have to add some paths the $code LD_LIBRARY_PATH$$ 
+shell variable using the $code export$$ command in the syntax above.
+For example, perhaps 
+$codei%
+	%ipopt_library_paths%=%IpoptDir%/lib/coin:%IpoptDir%/lib/coin/ThirdParty
+%$$
+see $cref/IpoptDir/InstallUnix/IpoptDir/$$.
+
 $head fg(x)$$
 The function $latex fg : \R^n \rightarrow \R^{m+1}$$ is defined by
 $latex \[
@@ -591,6 +613,9 @@ $end
 \brief CppAD interface to Ipopt
 */
 
+// ---------------------------------------------------------------------------
+namespace cppad_ipopt {
+// ---------------------------------------------------------------------------
 
 /// A scalar value used to record operation sequence.
 typedef CppAD::AD<Ipopt::Number>       ADNumber;
@@ -791,6 +816,8 @@ private:
 	/// pointer to object where final results are stored
 	/// (passed to ctor)
 	cppad_ipopt_solution* const     solution_;
+	/// plus infinity as a value of type Number
+	const Number                    infinity_;
 
 	// ------------------------------------------------------------------
 	// Effectively const values determined during constructor using calls 
@@ -1048,5 +1075,8 @@ public:
 };
 
 
+// ---------------------------------------------------------------------------
+} // end namespace cppad_ipopt
+// ---------------------------------------------------------------------------
 
 # endif
