@@ -14,10 +14,11 @@ var list_down1 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_current0 = [
