@@ -15,10 +15,11 @@ var list_down2 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down1 = [
@@ -35,7 +36,8 @@ var list_down0 = [
 'std_math_ad.xml',
 'mathother.xml',
 'condexp.xml',
-'discrete.xml'
+'discrete.xml',
+'user_atomic.xml'
 ];
 var list_current0 = [
 'advalued.xml#Contents'
