@@ -16,10 +16,11 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down2 = [
@@ -36,7 +37,8 @@ var list_down1 = [
 'std_math_ad.xml',
 'mathother.xml',
 'condexp.xml',
-'discrete.xml'
+'discrete.xml',
+'user_atomic.xml'
 ];
 var list_down0 = [
 'unaryplus.xml',
