@@ -16,10 +16,11 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down2 = [
@@ -32,6 +33,12 @@ var list_down2 = [
 'base_require.xml'
 ];
 var list_down1 = [
+'base_cond_exp.xml',
+'base_identical.xml',
+'base_ordered.xml',
+'base_std_math.xml',
+'base_float.hpp.xml',
+'base_double.hpp.xml',
 'base_complex.hpp.xml',
 'base_adolc.hpp.xml'
 ];
@@ -42,12 +49,16 @@ var list_current0 = [
 'base_adolc.hpp.xml#Syntax',
 'base_adolc.hpp.xml#Example',
 'base_adolc.hpp.xml#Include File',
-'base_adolc.hpp.xml#Standard Math Functions Defined by Adolc Package',
 'base_adolc.hpp.xml#CondExpOp',
 'base_adolc.hpp.xml#EqualOpSeq',
 'base_adolc.hpp.xml#Identical',
+'base_adolc.hpp.xml#Integer',
+'base_adolc.hpp.xml#epsilon',
 'base_adolc.hpp.xml#Ordered',
-'base_adolc.hpp.xml#Integer'
+'base_adolc.hpp.xml#Unary Standard Math',
+'base_adolc.hpp.xml#sign',
+'base_adolc.hpp.xml#abs',
+'base_adolc.hpp.xml#pow'
 ];
 function choose_across0(item)
 {	var index          = item.selectedIndex;
