@@ -16,10 +16,11 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down2 = [
@@ -32,6 +33,12 @@ var list_down2 = [
 'base_require.xml'
 ];
 var list_down1 = [
+'base_cond_exp.xml',
+'base_identical.xml',
+'base_ordered.xml',
+'base_std_math.xml',
+'base_float.hpp.xml',
+'base_double.hpp.xml',
 'base_complex.hpp.xml',
 'base_adolc.hpp.xml'
 ];
@@ -42,15 +49,18 @@ var list_down0 = [
 var list_current0 = [
 'base_complex.hpp.xml#Example',
 'base_complex.hpp.xml#See Also',
-'base_complex.hpp.xml#Include File',
+'base_complex.hpp.xml#Include Order',
 'base_complex.hpp.xml#CondExpOp',
+'base_complex.hpp.xml#CondExpRel',
 'base_complex.hpp.xml#EqualOpSeq',
 'base_complex.hpp.xml#Identical',
 'base_complex.hpp.xml#Ordered',
 'base_complex.hpp.xml#Integer',
-'base_complex.hpp.xml#Standard Functions',
-'base_complex.hpp.xml#Standard Functions.Valid Complex Functions',
-'base_complex.hpp.xml#Standard Functions.Invalid Complex Functions'
+'base_complex.hpp.xml#epsilon',
+'base_complex.hpp.xml#isnan',
+'base_complex.hpp.xml#Valid Unary Math',
+'base_complex.hpp.xml#Invalid Unary Math',
+'base_complex.hpp.xml#pow'
 ];
 function choose_across0(item)
 {	var index          = item.selectedIndex;
