@@ -16,10 +16,11 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down2 = [
@@ -36,7 +37,8 @@ var list_down1 = [
 'std_math_ad.xml',
 'mathother.xml',
 'condexp.xml',
-'discrete.xml'
+'discrete.xml',
+'user_atomic.xml'
 ];
 var list_down0 = [
 'condexp.cpp.xml'
@@ -48,8 +50,8 @@ var list_current0 = [
 'condexp.xml#Type',
 'condexp.xml#left',
 'condexp.xml#right',
-'condexp.xml#exp_if_true',
-'condexp.xml#exp_if_false',
+'condexp.xml#if_true',
+'condexp.xml#if_false',
 'condexp.xml#result',
 'condexp.xml#CondExp',
 'condexp.xml#Operation Sequence',
