@@ -15,10 +15,11 @@ var list_down2 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down1 = [
@@ -30,7 +31,7 @@ var list_down1 = [
 'bugs.xml',
 'wishlist.xml',
 'whats_new.xml',
-'include_deprecated.xml',
+'deprecated.xml',
 'license.xml'
 ];
 var list_current0 = [
@@ -47,6 +48,8 @@ var list_current0 = [
 'faq.xml#Namespace.Test Vector Preprocessor Symbol',
 'faq.xml#Namespace.Using',
 'faq.xml#Speed',
+'faq.xml#Speed.NDEBUG',
+'faq.xml#Speed.Optimize',
 'faq.xml#Tape Storage: Disk or Memory'
 ];
 function choose_across0(item)
