@@ -15,10 +15,11 @@ var list_down2 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down1 = [
@@ -30,9 +31,7 @@ var list_down1 = [
 'funeval.xml',
 'drivers.xml',
 'funcheck.xml',
-'omp_max_thread.xml',
-'optimize.xml',
-'fundeprecated.xml'
+'optimize.xml'
 ];
 var list_down0 = [
 'fun_assign.cpp.xml'
@@ -49,7 +48,7 @@ var list_current0 = [
 'funconstruct.xml#Assignment Operator',
 'funconstruct.xml#Assignment Operator.Taylor Coefficients',
 'funconstruct.xml#Assignment Operator.Sparsity Patterns',
-'funconstruct.xml#OpenMP',
+'funconstruct.xml#Parallel Mode',
 'funconstruct.xml#Example',
 'funconstruct.xml#Example.Sequence Constructor',
 'funconstruct.xml#Example.Default Constructor',
