@@ -8,20 +8,22 @@ var list_across0 = [
 var list_up0 = [
 'cppad.xml',
 'appendix.xml',
+'deprecated.xml',
 'include_deprecated.xml'
 ];
-var list_down2 = [
+var list_down3 = [
 'install.xml',
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
-var list_down1 = [
+var list_down2 = [
 'faq.xml',
 'speed.xml',
 'theory.xml',
@@ -30,9 +32,16 @@ var list_down1 = [
 'bugs.xml',
 'wishlist.xml',
 'whats_new.xml',
-'include_deprecated.xml',
+'deprecated.xml',
 'license.xml'
 ];
+var list_down1 = [
+'include_deprecated.xml',
+'fundeprecated.xml',
+'omp_max_thread.xml',
+'tracknewdel.xml',
+'omp_alloc.xml'
+];
 var list_current0 = [
 'include_deprecated.xml#Purpose',
 'include_deprecated.xml#Linking New Files to Deprecated Commands'
@@ -49,6 +58,12 @@ function choose_up0(item)
 	if(index > 0)
 		document.location = list_up0[index-1];
 }
+function choose_down3(item)
+{	var index          = item.selectedIndex;
+	item.selectedIndex = 0;
+	if(index > 0)
+		document.location = list_down3[index-1];
+}
 function choose_down2(item)
 {	var index          = item.selectedIndex;
 	item.selectedIndex = 0;
