@@ -15,10 +15,11 @@ var list_down2 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down1 = [
@@ -30,9 +31,7 @@ var list_down1 = [
 'funeval.xml',
 'drivers.xml',
 'funcheck.xml',
-'omp_max_thread.xml',
-'optimize.xml',
-'fundeprecated.xml'
+'optimize.xml'
 ];
 var list_down0 = [
 'independent.cpp.xml'
@@ -40,11 +39,11 @@ var list_down0 = [
 var list_current0 = [
 'independent.xml#Syntax',
 'independent.xml#Purpose',
-'independent.xml#Variables for a Tape',
+'independent.xml#Start Recording',
+'independent.xml#Stop Recording',
 'independent.xml#x',
 'independent.xml#VectorAD',
-'independent.xml#Memory Leak',
-'independent.xml#OpenMP',
+'independent.xml#Parallel Mode',
 'independent.xml#Example'
 ];
 function choose_across0(item)
