@@ -15,10 +15,11 @@ var list_down2 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down1 = [
@@ -37,22 +38,17 @@ var list_current0 = [
 'installunix.xml#Download.Web Link',
 'installunix.xml#Download.Unix Tar Files',
 'installunix.xml#Download.Tar File Extraction',
+'installunix.xml#Download.Work Directory',
 'installunix.xml#Configure',
-'installunix.xml#make test',
-'installunix.xml#Introduction',
-'installunix.xml#Introduction.Getting Started',
-'installunix.xml#Introduction.exp_apx',
-'installunix.xml#CppAD Examples',
-'installunix.xml#More Testing',
-'installunix.xml#Speed Testing',
-'installunix.xml#Speed Testing.CppAD Derivative Speed Tests',
-'installunix.xml#Speed Testing.Function Speed Tests',
-'installunix.xml#Speed Testing.Examples For Speed Tests',
+'installunix.xml#make',
+'installunix.xml#make.Examples and Tests',
 'installunix.xml#Profiling CppAD',
-'installunix.xml#PrintFor',
 'installunix.xml#PrefixDir',
 'installunix.xml#--with-Documentation',
 'installunix.xml#--with-stdvector',
+'installunix.xml#--with-boostvector',
+'installunix.xml#CompilerFlags',
+'installunix.xml#OpenmpFlags',
 'installunix.xml#PostfixDir',
 'installunix.xml#AdolcDir',
 'installunix.xml#AdolcDir.Linux',
@@ -61,7 +57,7 @@ var list_current0 = [
 'installunix.xml#SacadoDir',
 'installunix.xml#BoostDir',
 'installunix.xml#IpoptDir',
-'installunix.xml#CompilerFlags',
+'installunix.xml#TapeAddrType',
 'installunix.xml#make install'
 ];
 function choose_across0(item)
