@@ -21,7 +21,7 @@ var list_down3 = [
 'bugs.xml',
 'wishlist.xml',
 'whats_new.xml',
-'include_deprecated.xml',
+'deprecated.xml',
 'license.xml'
 ];
 var list_down2 = [
@@ -36,6 +36,7 @@ var list_down2 = [
 var list_down1 = [
 'link_det_lu.xml',
 'link_det_minor.xml',
+'link_mat_mul.xml',
 'link_ode.xml',
 'link_poly.xml',
 'link_sparse_hessian.xml',
