@@ -17,6 +17,7 @@ var list_down3 = [
 'nearequal.xml',
 'speed_test.xml',
 'speedtest.xml',
+'time_test.xml',
 'numerictype.xml',
 'checknumerictype.xml',
 'simplevector.xml',
@@ -35,9 +36,9 @@ var list_down3 = [
 'benderquad.xml',
 'opt_val_hes.xml',
 'luratio.xml',
-'std_math_unary.xml',
 'cppad_vector.xml',
-'tracknewdel.xml'
+'thread_alloc.xml',
+'memory_leak.xml'
 ];
 var list_down2 = [
 'lusolve.xml',
