@@ -16,10 +16,11 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down2 = [
@@ -27,6 +28,7 @@ var list_down2 = [
 'nearequal.xml',
 'speed_test.xml',
 'speedtest.xml',
+'time_test.xml',
 'numerictype.xml',
 'checknumerictype.xml',
 'simplevector.xml',
@@ -45,9 +47,9 @@ var list_down2 = [
 'benderquad.xml',
 'opt_val_hes.xml',
 'luratio.xml',
-'std_math_unary.xml',
 'cppad_vector.xml',
-'tracknewdel.xml'
+'thread_alloc.xml',
+'memory_leak.xml'
 ];
 var list_down1 = [
 'lusolve.xml',
