@@ -16,10 +16,11 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down2 = [
@@ -36,14 +37,20 @@ var list_down1 = [
 'std_math_ad.xml',
 'mathother.xml',
 'condexp.xml',
-'discrete.xml'
+'discrete.xml',
+'user_atomic.xml'
 ];
 var list_down0 = [
 'abs.xml',
+'sign.xml',
 'atan2.xml',
+'epsilon.xml',
 'erf.xml',
 'pow.xml'
 ];
+var list_current0 = [
+'mathother.xml#Contents'
+];
 function choose_across0(item)
 {	var index          = item.selectedIndex;
 	item.selectedIndex = 0;
