@@ -7,43 +7,48 @@ var list_across0 = [
 ];
 var list_up0 = [
 'cppad.xml',
-'adfun.xml',
+'appendix.xml',
+'deprecated.xml',
 'omp_max_thread.xml'
 ];
-var list_down2 = [
+var list_down3 = [
 'install.xml',
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
-var list_down1 = [
-'independent.xml',
-'funconstruct.xml',
-'dependent.xml',
-'abort_recording.xml',
-'seq_property.xml',
-'funeval.xml',
-'drivers.xml',
-'funcheck.xml',
-'omp_max_thread.xml',
-'optimize.xml',
-'fundeprecated.xml'
+var list_down2 = [
+'faq.xml',
+'speed.xml',
+'theory.xml',
+'glossary.xml',
+'bib.xml',
+'bugs.xml',
+'wishlist.xml',
+'whats_new.xml',
+'deprecated.xml',
+'license.xml'
 ];
-var list_down0 = [
-'openmp_run.sh.xml'
+var list_down1 = [
+'include_deprecated.xml',
+'fundeprecated.xml',
+'omp_max_thread.xml',
+'tracknewdel.xml',
+'omp_alloc.xml'
 ];
 var list_current0 = [
+'omp_max_thread.xml#Deprecated',
 'omp_max_thread.xml#Syntax',
 'omp_max_thread.xml#Purpose',
 'omp_max_thread.xml#number',
 'omp_max_thread.xml#Independent',
-'omp_max_thread.xml#Restriction',
-'omp_max_thread.xml#Example and Tests'
+'omp_max_thread.xml#Restriction'
 ];
 function choose_across0(item)
 {	var index          = item.selectedIndex;
@@ -57,6 +62,12 @@ function choose_up0(item)
 	if(index > 0)
 		document.location = list_up0[index-1];
 }
+function choose_down3(item)
+{	var index          = item.selectedIndex;
+	item.selectedIndex = 0;
+	if(index > 0)
+		document.location = list_down3[index-1];
+}
 function choose_down2(item)
 {	var index          = item.selectedIndex;
 	item.selectedIndex = 0;
