@@ -15,10 +15,11 @@ var list_down2 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down1 = [
@@ -26,6 +27,7 @@ var list_down1 = [
 'nearequal.xml',
 'speed_test.xml',
 'speedtest.xml',
+'time_test.xml',
 'numerictype.xml',
 'checknumerictype.xml',
 'simplevector.xml',
@@ -44,9 +46,9 @@ var list_down1 = [
 'benderquad.xml',
 'opt_val_hes.xml',
 'luratio.xml',
-'std_math_unary.xml',
 'cppad_vector.xml',
-'tracknewdel.xml'
+'thread_alloc.xml',
+'memory_leak.xml'
 ];
 var list_down0 = [
 'poly.cpp.xml',
