@@ -16,10 +16,11 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down2 = [
@@ -31,7 +32,7 @@ var list_down2 = [
 'bugs.xml',
 'wishlist.xml',
 'whats_new.xml',
-'include_deprecated.xml',
+'deprecated.xml',
 'license.xml'
 ];
 var list_down1 = [
@@ -46,7 +47,8 @@ var list_down0 = [
 'sincosreverse.xml',
 'atanreverse.xml',
 'asinreverse.xml',
-'acosreverse.xml'
+'acosreverse.xml',
+'tan_reverse.xml'
 ];
 var list_current0 = [
 'reversetheory.xml#Taylor Notation',
@@ -55,7 +57,8 @@ var list_current0 = [
 'reversetheory.xml#Binary Operators.Subtraction',
 'reversetheory.xml#Binary Operators.Multiplication',
 'reversetheory.xml#Binary Operators.Division',
-'reversetheory.xml#Standard Math Functions'
+'reversetheory.xml#Standard Math Functions',
+'reversetheory.xml#Contents'
 ];
 function choose_across0(item)
 {	var index          = item.selectedIndex;
