@@ -3,14 +3,14 @@
 // ------------------------------------------------------- 
 Keyword = 
 [
-"CppAD  cppad-20110101.3: A Package for Differentiation of C++ Algorithms   algorithmic automatic derivative version introduction include cppad.hpp symbol preprocessor namespace",
+"CppAD  cppad-20120101.4: A Package for Differentiation of C++ Algorithms   algorithmic automatic derivative version introduction include cppad.hpp symbol preprocessor namespace",
 "Install  CppAD Download, Test, and Installation Instructions  ",
-"InstallUnix  Unix Download, Test and Installation   cppad free fedora rpm cppad.spec tar file configure get_started run exp_apx introduction example more testing speed check function utility profile print forward mode prefix directory documentation std::vector postfix adolc fadbad sacado boost ipopt compile flags",
+"InstallUnix  Unix Download, Test and Installation   cppad free fedora rpm cppad.spec tar file configure speed profile prefix directory documentation std::vector boost compile flags openmp postfix adolc fadbad sacado ipopt memory usage tape",
 "subversion  Using Subversion To Download Source Code  ",
 "pkgconfig  CppAD pkg-config Files   pc",
 "InstallWindows  Windows Download and Test   free cppad zip file getstarted introduction example more print forward mode speed double utility",
 "Introduction  An Introduction by Example to Algorithmic Differentiation   ad automatic",
-"get_started.cpp  A Simple Program Using CppAD to Compute Derivatives   getstarted example",
+"get_started.cpp  Getting Started Using CppAD to Compute Derivatives   simple example",
 "exp_2  Second Order Exponential Approximation   example algorithm",
 "exp_2.hpp  exp_2: Implementation  ",
 "exp_2.cpp  exp_2: Test  ",
@@ -39,7 +39,7 @@ Keyword =
 "exp_eps_for2.cpp  exp_eps: Verify Second Order Forward Sweep   first exp_2",
 "exp_eps_rev2.cpp  exp_eps: Verify Second Order Reverse Sweep  ",
 "exp_eps_cppad  exp_eps: CppAD Forward and Reverse Sweeps  ",
-"exp_apx_main.cpp  Run the exp_2 and exp_eps Tests  ",
+"exp_apx_main.cpp  Correctness Tests For Exponential Approximation in Introduction   run",
 "AD  AD Objects   base require",
 "Default  AD Default Constructor  ",
 "Default.cpp  Default AD Constructor: Example and Test  ",
@@ -55,7 +55,8 @@ Keyword =
 "Output  AD Output Stream Operator   << write",
 "Output.cpp  AD Output Operator: Example and Test   <<",
 "PrintFor  Printing AD Values During Forward Mode   text output debug",
-"PrintFor.cpp  Printing During Forward Mode: Example and Test  ",
+"print_for_cout.cpp  Printing During Forward Mode: Example and Test  ",
+"print_for_string.cpp  Print During Zero Order Forward Mode: Example and Test  ",
 "Var2Par  Convert an AD Variable to a Parameter   from value_ obtain during taping",
 "Var2Par.cpp  Convert an AD Variable to a Parameter: Example and Test   value during taping",
 "ADValued  AD Valued Operations and Functions  ",
@@ -88,11 +89,15 @@ Keyword =
 "Sqrt.cpp  The AD sqrt Function: Example and Test  ",
 "Tan.cpp  The AD tan Function: Example and Test  ",
 "Tanh.cpp  The AD tanh Function: Example and Test  ",
-"MathOther  Other AD Math Functions   atan2",
-"abs  AD Absolute Value Function   value_ directional derivative",
-"Abs.cpp  AD Absolute Value Function: Example and Test   derivative directional",
+"MathOther  Other AD Math Functions  ",
+"abs  AD Absolute Value Function  ",
+"abs.cpp  AD Absolute Value Function: Example and Test   derivative directional",
+"sign  Sign Function   ad",
+"sign.cpp  Sign Function: Example and Test  ",
 "atan2  AD Two Argument Inverse Tangent Function  ",
 "Atan2.cpp  The AD atan2 Function: Example and Test  ",
+"epsilon  Machine Epsilon For AD Types  ",
+"epsilon.cpp  Machine Epsilon: Example and Test  ",
 "erf  The AD Error Function  ",
 "Erf.cpp  The AD erf Function: Example and Test  ",
 "pow  The AD Power Function   exponent",
@@ -100,10 +105,14 @@ Keyword =
 "pow_int.cpp  The Pow Integer Exponent: Example and Test  ",
 "CondExp  AD Conditional Expressions   assign",
 "CondExp.cpp  Conditional Expressions: Example and Test  ",
-"Discrete  Discrete AD Functions   cppad_discrete_function cppadcreatediscrete deprecated",
+"Discrete  Discrete AD Functions   cppad_discrete_function parallel cppadcreatediscrete deprecated",
 "TapeIndex.cpp  Taping Array Index Operation: Example and Test  ",
 "interp_onetape.cpp  Interpolation With Out Retaping: Example and Test   interpolate retape",
 "interp_retape.cpp  Interpolation With Retaping: Example and Test   interpolate",
+"user_atomic  User Defined Atomic AD Functions   cppad_user_atomic operation parallel",
+"user_tan.cpp  Tan and Tanh as User Atomic Operations: Example and Test   user_atomic",
+"mat_mul.cpp  Matrix Multiply as a User Atomic Operation: Example and Test   user_atomic",
+"mat_mul.hpp  Define Matrix Multiply as a User Atomic Operation   user_atomic test example",
 "BoolValued  Bool Valued Operations and Functions with AD Arguments  ",
 "Compare  AD Binary Comparison Operators   < <= > >= == !=",
 "Compare.cpp  AD Binary Comparison Operators: Example and Test   < <= > >= == !=",
@@ -113,22 +122,28 @@ Keyword =
 "BoolFun.cpp  AD Boolean Functions: Example and Test  ",
 "ParVar  Is an AD Object a Parameter or Variable  ",
 "ParVar.cpp  AD Parameter and Variable Functions: Example and Test  ",
-"EqualOpSeq  Check if Equal and Correspond to Same Operation Sequence  ",
+"EqualOpSeq  Check if Two Value are Identically Equal   operation sequence",
 "EqualOpSeq.cpp  EqualOpSeq: Example and Test  ",
 "VecAD  AD Vectors that Record Index Operations   tape vecad<base>::reference",
 "vec_ad.cpp  AD Vectors that Record Index Operations: Example and Test   vecad",
-"base_require  AD<Base> Requirements for Base Type   condexp equalopseq identical integer greaterthanzero lessthanorzero pow math",
+"base_require  AD<Base> Requirements for Base Type   integer epsilon machine",
+"base_cond_exp  Base Type Requirements for Conditional Expressions   condexp cppad_cond_exp_rel",
+"base_identical  Base Type Requirements for Identically Equal Comparisons   equalopseq",
+"base_ordered  Base Type Requirements for Ordered Comparisons  ",
+"base_std_math  Base Type Requirements for Standard Math Functions   unary cppad_standard_math_unary sign pow",
+"base_float.hpp  Enable use of AD<Base> where Base is float  ",
+"base_double.hpp  Enable use of AD<Base> where Base is double  ",
 "base_complex.hpp  Enable use of AD<Base> where Base is std::complex<double>  ",
 "ComplexPoly.cpp  Complex Polynomial: Example and Test  ",
 "not_complex_ad.cpp  Not Complex Differentiable: Example and Test   polynomial imag() real()",
 "base_adolc.hpp  Enable use of AD<Base> where Base is Adolc's adouble Type  ",
 "mul_level_adolc.cpp  Using Adolc with Multiple Levels of Taping: Example and Test  ",
 "ADFun  ADFun Objects  ",
-"Independent  Declare Independent Variables and Start Recording   openmp",
+"Independent  Declare Independent Variables and Start Recording   parallel",
 "Independent.cpp  Independent and ADFun Constructor: Example and Test  ",
-"FunConstruct  Construct an ADFun Object and Stop Recording   tape default constructor sequence copy assignment operator openmp dependent",
+"FunConstruct  Construct an ADFun Object and Stop Recording   tape default constructor sequence copy assignment operator parallel",
 "fun_assign.cpp  ADFun Assignment: Example and Test  ",
-"Dependent  Stop Recording and Store Operation Sequence   adfun tape",
+"Dependent  Stop Recording and Store Operation Sequence   adfun tape parallel",
 "abort_recording  Abort Recording of an Operation Sequence   tape",
 "abort_recording.cpp  Abort Current Recording: Example and Test  ",
 "seq_property  ADFun Sequence Properties   domain range parameter size_var size_par size_vecad",
@@ -180,37 +195,49 @@ Keyword =
 "sparse_hessian.cpp  Sparse Hessian: Example and Test   spare",
 "FunCheck  Check an ADFun Sequence of Operations  ",
 "FunCheck.cpp  ADFun Check and Re-Tape: Example and Test   dependent",
-"omp_max_thread  OpenMP Maximum Thread Number   multiple cppad",
-"openmp_run.sh  Compile and Run the OpenMP Test   example",
-"example_a11c.cpp  A Simple Parallel Loop   openmp a.1.1c",
-"multi_newton.cpp  Multi-Threaded Newton's Method Main Program   openmp example",
-"multi_newton  Multi-Threaded Newton's Method Routine   openmp example",
-"multi_newton.hpp  OpenMP Multi-Threading Newton's Method Source Code   example",
-"sum_i_inv.cpp  Sum of 1/i Main Program   openmp example",
-"optimize  Optimize the Tape Corresponding to an ADFun object   sequence operations speed memory ndebug",
+"optimize  Optimize an ADFun Object Tape   sequence operations speed memory ndebug",
 "optimize.cpp  ADFun Operation Sequence Optimization: Example and Test  ",
-"FunDeprecated  ADFun Object Deprecated Member Functions   dependent order memory size taylor_size use_vecad",
+"multi_thread  Using CppAD in a Multi-Threading Environment   parallel mode execution maximum number of threads cppad_max_num_threads",
+"parallel_ad  Enable AD Calculations During Parallel Mode  ",
+"team_thread.hpp  Specifications for A Team of AD Threads  ",
+"team_openmp.cpp  OpenMP Implementation of a Team of AD Threads  ",
+"team_bthread.cpp  Boost Thread Implementation of a Team of AD Threads  ",
+"team_pthread.cpp  Pthread Implementation of a Team of AD Threads   bug cygwin pthread_exit",
+"thread_test.cpp  Run Multi-Threading Examples and Speed Tests   openmp pthread bthread",
+"a11c_openmp.cpp  A Simple OpenMP Example and Test   a.1.1c thread",
+"a11c_bthread.cpp  A Simple Boost Thread Example and Test   a.1.1c",
+"a11c_pthread.cpp  A Simple Parallel Pthread Example and Test   openmp a.1.1c",
+"simple_ad.cpp  Simple Multi-Threading AD: Example and Test   multiple multi_thread",
+"arc_tan.cpp  Two Argument Inverse Tangent Function   multi_thread example",
+"harmonic.cpp  Multi-Threaded Implementation of Summation of 1/i   multi_thread",
+"harmonic_time.cpp  Timing Test of Multi-Threaded Summation of 1/i   multi_thread speed",
+"harmonic_work.cpp  Multi-threading Sum of 1/i Utility Routines   harmonic_setup harmonic_worker harmonic_combine",
+"multi_newton.cpp  A Multi-Threaded Newton's Method   threading multi-threading",
+"multi_newton_time.cpp  Timing Test of Multi-Threaded Newton Method   multi_thread speed",
+"multi_newton_work.cpp  Multi-threading Newton Method Utility Routines   multi_newton_setup multi_newton_worker multi_newton_combine",
 "library  The CppAD General Purpose Library   numerical c++ template concept",
-"ErrorHandler  Replacing the CppAD Error Handler   replace assert exception",
+"ErrorHandler  Replacing the CppAD Error Handler   replace assert exception parallel",
 "ErrorHandler.cpp  Replacing The CppAD Error Handler: Example and Test  ",
-"cppad_assert  CppAD Assertions During Execution   error macro cppad_assert_known cppad_assert_unknown",
+"cppad_assert  CppAD Assertions During Execution   error macro ndebug cppad_assert_known cppad_assert_unknown",
 "NearEqual  Determine if Two Values Are Nearly Equal   absolute difference relative exercise",
 "Near_Equal.cpp  NearEqual Function: Example and Test  ",
 "speed_test  Run One Speed Test and Return Results  ",
 "SpeedTest  Run One Speed Test and Print Results  ",
-"elapsed_seconds  Returns Elapsed Number of Seconds   time",
-"elapsed_seconds.cpp  Elapsed Seconds: Example and Test   timer",
 "speed_test.cpp  speed_test: Example and test  ",
 "speed_program.cpp  Example Use of SpeedTest  ",
+"time_test  Determine Amount of Time to Execute a Test   speed",
+"elapsed_seconds  Returns Elapsed Number of Seconds   time",
+"elapsed_seconds.cpp  Elapsed Seconds: Example and Test   timer",
+"time_test.cpp  time_test: Example and test  ",
 "NumericType  Definition of a Numeric Type   default constructor int copy exercise",
 "NumericType.cpp  The NumericType: Example and Test  ",
-"CheckNumericType  Check NumericType Class Concept  ",
+"CheckNumericType  Check NumericType Class Concept   parallel",
 "CheckNumericType.cpp  The CheckNumericType Function: Example and Test  ",
 "SimpleVector  Definition of a Simple Vector   class template default constructor size copy element destructor assignment resize value_type [] exercise ndebug",
 "SimpleVector.cpp  Simple Vector Template Class: Example and Test  ",
-"CheckSimpleVector  Check Simple Vector Concept  ",
+"CheckSimpleVector  Check Simple Vector Concept   parallel",
 "CheckSimpleVector.cpp  The CheckSimpleVector Function: Example and Test  ",
-"nan  Obtain Nan and Determine if a Value is Nan   isnan hasnan macro",
+"nan  Obtain Nan or Determine if a Value is Nan   isnan hasnan macro parallel user_atomic",
 "nan.cpp  nan: Example and Test  ",
 "pow_int  The Integer Power Function   exponent",
 "Poly  Evaluate a Polynomial or its Derivative   template",
@@ -230,10 +257,10 @@ Keyword =
 "RombergOne.cpp  One Dimensional Romberg Integration: Example and Test  ",
 "RombergMul  Multi-dimensional Romberg Integration   integrate",
 "RombergMul.cpp  One Dimensional Romberg Integration: Example and Test  ",
-"Runge45  An Embedded 4th and 5th Order Runge-Kutta ODE Solver   differential equation",
+"Runge45  An Embedded 4th and 5th Order Runge-Kutta ODE Solver   differential equation parallel",
 "runge_45_1.cpp  Runge45: Example and Test  ",
 "runge_45_2.cpp  Runge45: Example and Test  ",
-"Rosen34  A 3rd and 4th Order Rosenbrock ODE Solver   stiff differential equation",
+"Rosen34  A 3rd and 4th Order Rosenbrock ODE Solver   stiff differential equation parallel",
 "Rosen34.cpp  Rosen34: Example and Test  ",
 "OdeErrControl  An Error Controller for ODE Solvers   differential equation",
 "OdeErrControl.cpp  OdeErrControl: Example and Test  ",
@@ -248,12 +275,23 @@ Keyword =
 "opt_val_hes.cpp  opt_val_hes: Example and Test  ",
 "LuRatio  LU Factorization of A Square Matrix and Stability Calculation   linear equation determinant solve",
 "LuRatio.cpp  LuRatio: Example and Test  ",
-"std_math_unary  Float and Double Standard Math Unary Functions   abs acos asin atan cosh exp log log10 sinh sqrt tanh",
-"CppAD_vector  The CppAD::vector Template Class   assignment [] push_back push_vector vectorbool exercise",
+"CppAD_vector  The CppAD::vector Template Class   assignment [] push_back push_vector vectorbool thread_alloc exercise",
 "CppAD_vector.cpp  CppAD::vector Template Class: Example and Test  ",
 "vectorBool.cpp  CppAD::vectorBool Class: Example and Test  ",
-"TrackNewDel  Routines That Track Use of New and Delete   memory openmp tracknewvec ndebug cppad_track_new_vec cppadtracknewvec trackdelvec cppad_track_del_vec cppadtrackdelvec trackextend cppad_track_extend cppadtrackextend trackcount cppad_track_count",
-"TrackNewDel.cpp  Tracking Use of New and Delete: Example and Test  ",
+"thread_alloc  A Fast Multi-Threading Memory Allocator   allocation",
+"thread_alloc.cpp  Fast Multi-Threading Memory Allocator: Example and Test   openmp allocation pthread boost",
+"ta_parallel_setup  Setup thread_alloc For Use in Multi-Threading Environment   num_threads in_parallel thread_num initialize",
+"ta_num_threads  Get Number of Threads   thread_alloc",
+"ta_in_parallel  Is The Current Execution in Parallel Mode   thread_alloc sequential",
+"ta_thread_num  Get the Current Thread Number   thread_alloc",
+"ta_get_memory  Get At Least A Specified Amount of Memory   thread_num thread_alloc allocate",
+"ta_return_memory  Return Memory to thread_alloc   available",
+"ta_free_available  Free Memory Currently Available for Quick Use by a Thread   thread_alloc",
+"ta_inuse  Amount of Memory a Thread is Currently Using   thread_alloc",
+"ta_available  Amount of Memory Available for Quick Use by a Thread   thread_alloc",
+"ta_create_array  Allocate An Array and Call Default Constructor for its Elements   thread_alloc",
+"ta_delete_array  Deallocate An Array and Call Destructor for its Elements   thread_alloc",
+"memory_leak  Memory Leak Detection   check",
 "cppad_ipopt_nlp  Nonlinear Programming Using the CppAD Interface to Ipopt  ",
 "cppad_ipopt_windows  Linking the CppAD Interface to Ipopt in Visual Studio 9.0  ",
 "ipopt_get_started.cpp  Nonlinear Programming Using CppAD and Ipopt: Example and Test  ",
@@ -273,6 +311,7 @@ Keyword =
 "ListAllExamples  List of All the CppAD Examples  ",
 "ad_fun.cpp  Creating Your Own Interface to an ADFun Object   example test",
 "ad_in_c.cpp  Example and Test Linking CppAD to Languages Other than C++   algorithmic differentiation automatic",
+"conj_grad.cpp  Differentiate Conjugate Gradient Algorithm: Example and Test  ",
 "HesMinorDet.cpp  Gradient of Determinant Using Expansion by Minors: Example and Test  ",
 "HesLuDet.cpp  Gradient of Determinant Using LU Factorization: Example and Test  ",
 "Interface2C.cpp  Interfacing to C: Example and Test   difference central",
@@ -284,18 +323,19 @@ Keyword =
 "ode_taylor.cpp  Taylor's Ode Solver: An Example and Test  ",
 "ode_taylor_adolc.cpp  Using Adolc with Taylor's Ode Solver: An Example and Test  ",
 "StackMachine.cpp  Example Differentiating a Stack Machine Interpreter   test",
-"Example.cpp  Program That Runs the CppAD Examples   all",
-"speed_example.cpp  Program That Runs the Speed Examples  ",
+"example.cpp  CppAD Examples and Tests  ",
+"speed_example.cpp  Run the Speed Examples   program",
 "LuVecAD  Lu Factor and Solve with Recorded Pivoting   linear equation determinant",
 "LuVecADOk.cpp  Lu Factor and Solve With Recorded Pivoting: Example and Test  ",
 "test_vector  Choosing The Vector Testing Template Class   cppad_test_vector cppadvector deprecated",
-"configure  Preprocessor Definitions Used by CppAD   symbol package version config.h",
+"preprocessor  CppAD API Preprocessor Symbols   cppad_ null pointer cppad_null",
 "Appendix  Appendix  ",
 "Faq  Frequently Asked Questions and Answers   assignment operator independent bugs reporting comparechange ndebug complex test exception errorhandler variable tape avoid record speed taping math functions inverse matrix forward reverse mode namespace cppad_test_vector preprocessor symbols standard using storage memory disk",
 "speed  Speed Test Routines   windows",
 "speed_main  Speed Testing Main Program   cppad uniform_01",
 "link_det_lu  Speed Testing Gradient of Determinant Using Lu Factorization  ",
 "link_det_minor  Speed Testing Gradient of Determinant by Minor Expansion  ",
+"link_mat_mul  Speed Testing Derivative of Matrix Multiply   multiple",
 "link_ode  Speed Testing the Jacobian of Ode Solution  ",
 "link_poly  Speed Testing Second Derivative of a Polynomial  ",
 "link_sparse_hessian  Speed Testing Sparse Hessian  ",
@@ -317,22 +357,27 @@ Keyword =
 "det_33.hpp  Source: det_33  ",
 "det_grad_33  Check Gradient of Determinant of 3 by 3 matrix   correct",
 "det_grad_33.hpp  Source: det_grad_33  ",
+"mat_sum_sq  Sum Elements of a Matrix Times Itself   multiply speed test",
+"mat_sum_sq.cpp  Sum of the Elements of the Square of a Matrix: Example and Test  ",
+"mat_sum_sq.hpp  Source: mat_sum_sq  ",
 "ode_evaluate  Evaluate a Function Defined in Terms of an ODE  ",
 "ode_evaluate.cpp  ode_evaluate: Example and test  ",
 "ode_evaluate.hpp  Source: ode_evaluate  ",
 "sparse_evaluate  Evaluate a Function That Has a Sparse Hessian  ",
 "sparse_evaluate.cpp  sparse_evaluate: Example and test  ",
 "sparse_evaluate.hpp  Source: sparse_evaluate  ",
-"speed_double  Speed Test Functions in Double  ",
+"speed_double  Speed Test of Functions in Double  ",
 "double_det_minor.cpp  Double Speed: Determinant by Minor Expansion   cppad link_det_minor",
 "double_det_lu.cpp  Double Speed: Determinant Using Lu Factorization   link_det_lu",
+"double_mat_mul.cpp  CppAD Speed: Matrix Multiplication (Double Version)   multiply link_mat_mul",
 "double_ode.cpp  Double Speed: Ode Solution   link_ode",
 "double_poly.cpp  Double Speed: Evaluate a Polynomial   cppad link_poly",
 "double_sparse_hessian.cpp  Double Speed: Sparse Hessian   link_sparse_hessian",
 "double_sparse_jacobian.cpp  Double Speed: Sparse Jacobian   link_sparse_jacobian",
-"speed_adolc  Speed Test Derivatives Using Adolc  ",
+"speed_adolc  Speed Test of Derivatives Using Adolc  ",
 "adolc_det_minor.cpp  Adolc Speed: Gradient of Determinant by Minor Expansion   link_det_minor",
 "adolc_det_lu.cpp  Adolc Speed: Gradient of Determinant Using Lu Factorization   link_det_lu",
+"adolc_mat_mul.cpp  Adolc Speed: Matrix Multiplication  ",
 "adolc_ode.cpp  Adolc Speed: Ode  ",
 "adolc_poly.cpp  Adolc Speed: Second Derivative of a Polynomial   link_poly",
 "adolc_sparse_hessian.cpp  Adolc Speed: Sparse Hessian   link_sparse_hessian",
@@ -340,6 +385,7 @@ Keyword =
 "speed_cppad  Speed Test Derivatives Using CppAD  ",
 "cppad_det_minor.cpp  CppAD Speed: Gradient of Determinant by Minor Expansion   link_det_minor",
 "cppad_det_lu.cpp  CppAD Speed: Gradient of Determinant Using Lu Factorization   link_det_lu",
+"cppad_mat_mul.cpp  CppAD Speed: Matrix Multiplication   multiply link_mat_mul",
 "cppad_ode.cpp  CppAD Speed: Gradient of Ode Solution   jacobian link_ode",
 "cppad_poly.cpp  CppAD Speed: Second Derivative of a Polynomial   link_poly",
 "cppad_sparse_hessian.cpp  CppAD Speed: Sparse Hessian   link_sparse_hessian",
@@ -347,6 +393,7 @@ Keyword =
 "speed_fadbad  Speed Test Derivatives Using Fadbad  ",
 "fadbad_det_minor.cpp  Fadbad Speed: Gradient of Determinant by Minor Expansion   link_det_minor",
 "fadbad_det_lu.cpp  Fadbad Speed: Gradient of Determinant Using Lu Factorization   link_det_lu",
+"fadbad_mat_mul.cpp  Fadbad Speed: Matrix Multiplication  ",
 "fadbad_ode.cpp  Fadbad Speed: Ode  ",
 "fadbad_poly.cpp  Fadbad Speed: Second Derivative of a Polynomial   link_poly",
 "fadbad_sparse_hessian.cpp  Fadbad Speed: Sparse Hessian  ",
@@ -354,6 +401,7 @@ Keyword =
 "speed_sacado  Speed Test Derivatives Using Sacado  ",
 "sacado_det_minor.cpp  Sacado Speed: Gradient of Determinant by Minor Expansion   link_det_minor",
 "sacado_det_lu.cpp  Sacado Speed: Gradient of Determinant Using Lu Factorization   link_det_lu",
+"sacado_mat_mul.cpp  Sacado Speed: Matrix Multiplication  ",
 "sacado_ode.cpp  Sacado Speed: Gradient of Ode Solution   link_ode",
 "sacado_poly.cpp  Sacado Speed: Second Derivative of a Polynomial   link_poly",
 "sacado_sparse_hessian.cpp  Sacado Speed: Sparse Hessian  ",
@@ -367,6 +415,7 @@ Keyword =
 "AtanForward  Arctangent Function Forward Taylor Polynomial Theory  ",
 "AsinForward  Arcsine Function Forward Taylor Polynomial Theory  ",
 "AcosForward  Arccosine Function Forward Taylor Polynomial Theory  ",
+"tan_forward  Tangent and Hyperbolic Tangent Forward Taylor Polynomial Theory  ",
 "ReverseTheory  The Theory of Reverse Mode  ",
 "ExpReverse  Exponential Function Reverse Mode Theory  ",
 "LogReverse  Logarithm Function Reverse Mode Theory  ",
@@ -375,12 +424,14 @@ Keyword =
 "AtanReverse  Arctangent Function Reverse Mode Theory  ",
 "AsinReverse  Arcsine Function Reverse Mode Theory  ",
 "AcosReverse  Arccosine Function Reverse Mode Theory  ",
+"tan_reverse  Tangent and Hyperbolic Tangent Reverse Mode Theory  ",
 "reverse_identity  An Important Reverse Mode Identity  ",
 "glossary  Glossary   ad function of base levels above type elementary vector operation atomic sequence dependent independent parameter sparsity pattern efficient boolean sets tape active inactive variable variables taylor coefficient",
 "Bib  Bibliography  ",
 "Bugs  Know Bugs and Problems Using CppAD   gcc 3.4.4",
-"WishList  The CppAD Wish List   new features atan2 condexp sequence operation",
+"WishList  The CppAD Wish List   new features atan2 condexp cppad_ipopt_nlp compile speed ad<double> improve testing machine epsilon sequence operation optimize tape sparsity pattern parallel extend tests ms windows tracing vecad assignment",
 "whats_new  Changes and Additions to CppAD  ",
+"whats_new_11  Changes and Additions to CppAD During 2011  ",
 "whats_new_10  Changes and Additions to CppAD During 2010  ",
 "whats_new_09  Changes and Additions to CppAD During 2009  ",
 "whats_new_08  Changes and Additions to CppAD During 2008   erf ipopt_cppad_nlp",
@@ -389,7 +440,26 @@ Keyword =
 "whats_new_05  Changes and Additions to CppAD During 2005  ",
 "whats_new_04  Changes and Additions to CppAD During 2004  ",
 "whats_new_03  Changes and Additions to CppAD During 2003  ",
+"deprecated  CppAD Deprecated API Features  ",
 "include_deprecated  Deprecated Include Files  ",
+"FunDeprecated  ADFun Object Deprecated Member Functions   dependent order memory size taylor_size use_vecad",
+"omp_max_thread  OpenMP Parallel Setup   depreciated",
+"TrackNewDel  Routines That Track Use of New and Delete   memory deprecated tracknewvec ndebug cppad_track_new_vec cppadtracknewvec trackdelvec cppad_track_del_vec cppadtrackdelvec trackextend cppad_track_extend cppadtrackextend trackcount cppad_track_count multi-threading",
+"TrackNewDel.cpp  Tracking Use of New and Delete: Example and Test  ",
+"omp_alloc  A Quick OpenMP Memory Allocator Used by CppAD   multi-threading allocation",
+"omp_max_num_threads  Set and Get Maximum Number of Threads for omp_alloc Allocator   set_max_num_threads get_max_num_threads",
+"omp_in_parallel  Is The Current Execution in OpenMP Parallel Mode   omp_alloc",
+"omp_get_thread_num  Get the Current OpenMP Thread Number   omp_alloc",
+"omp_get_memory  Get At Least A Specified Amount of Memory   get_thread_num omp_alloc",
+"omp_return_memory  Return Memory to omp_alloc  ",
+"omp_free_available  Free Memory Currently Available for Quick Use by a Thread   omp_alloc",
+"omp_inuse  Amount of Memory a Thread is Currently Using   omp_alloc",
+"omp_available  Amount of Memory Available for Quick Use by a Thread   omp_alloc",
+"omp_create_array  Allocate Memory and Create A Raw Array   omp_alloc",
+"omp_delete_array  Return A Raw Array to The Available Memory for a Thread   omp_alloc",
+"omp_efficient  Check If A Memory Allocation is Efficient for Another Use   omp_alloc",
+"old_max_num_threads  Set Maximum Number of Threads for omp_alloc Allocator  ",
+"omp_alloc.cpp  OpenMP Memory Allocator: Example and Test   allocation multi-thread",
 "License  Your License for the CppAD Software  "
 ]
 
