@@ -16,10 +16,11 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down2 = [
@@ -31,9 +32,7 @@ var list_down2 = [
 'funeval.xml',
 'drivers.xml',
 'funcheck.xml',
-'omp_max_thread.xml',
-'optimize.xml',
-'fundeprecated.xml'
+'optimize.xml'
 ];
 var list_down1 = [
 'seq_property.cpp.xml'
