@@ -16,10 +16,11 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down2 = [
@@ -31,7 +32,7 @@ var list_down2 = [
 'bugs.xml',
 'wishlist.xml',
 'whats_new.xml',
-'include_deprecated.xml',
+'deprecated.xml',
 'license.xml'
 ];
 var list_down1 = [
@@ -46,6 +47,7 @@ var list_down1 = [
 var list_down0 = [
 'cppad_det_minor.cpp.xml',
 'cppad_det_lu.cpp.xml',
+'cppad_mat_mul.cpp.xml',
 'cppad_ode.cpp.xml',
 'cppad_poly.cpp.xml',
 'cppad_sparse_hessian.cpp.xml',
@@ -53,7 +55,7 @@ var list_down0 = [
 ];
 var list_current0 = [
 'speed_cppad.xml#Purpose',
-'speed_cppad.xml#Speed',
+'speed_cppad.xml#Running Tests',
 'speed_cppad.xml#C++ Compiler Flags',
 'speed_cppad.xml#Contents'
 ];
