@@ -16,10 +16,11 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down2 = [
@@ -33,6 +34,9 @@ var list_down1 = [
 'speed_example.cpp.xml',
 'luvecad.xml'
 ];
+var list_current0 = [
+'speed_example.cpp.xml#Running Tests'
+];
 function choose_across0(item)
 {	var index          = item.selectedIndex;
 	item.selectedIndex = 0;
