@@ -16,10 +16,11 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down2 = [
@@ -31,7 +32,7 @@ var list_down2 = [
 'bugs.xml',
 'wishlist.xml',
 'whats_new.xml',
-'include_deprecated.xml',
+'deprecated.xml',
 'license.xml'
 ];
 var list_down1 = [
@@ -46,6 +47,7 @@ var list_down1 = [
 var list_down0 = [
 'link_det_lu.xml',
 'link_det_minor.xml',
+'link_mat_mul.xml',
 'link_ode.xml',
 'link_poly.xml',
 'link_sparse_hessian.xml',
@@ -66,6 +68,7 @@ var list_current0 = [
 'speed_main.xml#option_list',
 'speed_main.xml#option_list.retape',
 'speed_main.xml#option_list.optimize',
+'speed_main.xml#option_list.atomic',
 'speed_main.xml#Correctness Results',
 'speed_main.xml#Speed Results',
 'speed_main.xml#Link Functions'
