@@ -16,10 +16,11 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down2 = [
@@ -31,7 +32,7 @@ var list_down2 = [
 'bugs.xml',
 'wishlist.xml',
 'whats_new.xml',
-'include_deprecated.xml',
+'deprecated.xml',
 'license.xml'
 ];
 var list_down1 = [
@@ -46,6 +47,7 @@ var list_down1 = [
 var list_down0 = [
 'sacado_det_minor.cpp.xml',
 'sacado_det_lu.cpp.xml',
+'sacado_mat_mul.cpp.xml',
 'sacado_ode.cpp.xml',
 'sacado_poly.cpp.xml',
 'sacado_sparse_hessian.cpp.xml',
@@ -54,6 +56,7 @@ var list_down0 = [
 var list_current0 = [
 'speed_sacado.xml#Purpose',
 'speed_sacado.xml#SacadoDir',
+'speed_sacado.xml#Running Tests',
 'speed_sacado.xml#C++ Compiler Flags',
 'speed_sacado.xml#Contents'
 ];
