@@ -16,10 +16,11 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
 var list_down2 = [
@@ -31,6 +32,7 @@ var list_down2 = [
 var list_down1 = [
 'ad_fun.cpp.xml',
 'ad_in_c.cpp.xml',
+'conj_grad.cpp.xml',
 'hesminordet.cpp.xml',
 'hesludet.cpp.xml',
 'interface2c.cpp.xml',
