@@ -7,47 +7,29 @@ var list_across0 = [
 ];
 var list_up0 = [
 'cppad.xml',
-'library.xml',
+'appendix.xml',
+'deprecated.xml',
 'tracknewdel.xml',
 'tracknewdel.cpp.xml'
 ];
 var list_down3 = [
-'install.xml',
-'introduction.xml',
-'ad.xml',
-'adfun.xml',
-'library.xml',
-'cppad_ipopt_nlp.xml',
-'example.xml',
-'configure.xml',
-'appendix.xml'
+'faq.xml',
+'speed.xml',
+'theory.xml',
+'glossary.xml',
+'bib.xml',
+'bugs.xml',
+'wishlist.xml',
+'whats_new.xml',
+'deprecated.xml',
+'license.xml'
 ];
 var list_down2 = [
-'errorhandler.xml',
-'nearequal.xml',
-'speed_test.xml',
-'speedtest.xml',
-'numerictype.xml',
-'checknumerictype.xml',
-'simplevector.xml',
-'checksimplevector.xml',
-'nan.xml',
-'pow_int.xml',
-'poly.xml',
-'ludetandsolve.xml',
-'rombergone.xml',
-'rombergmul.xml',
-'runge45.xml',
-'rosen34.xml',
-'odeerrcontrol.xml',
-'odegear.xml',
-'odegearcontrol.xml',
-'benderquad.xml',
-'opt_val_hes.xml',
-'luratio.xml',
-'std_math_unary.xml',
-'cppad_vector.xml',
-'tracknewdel.xml'
+'include_deprecated.xml',
+'fundeprecated.xml',
+'omp_max_thread.xml',
+'tracknewdel.xml',
+'omp_alloc.xml'
 ];
 var list_down1 = [
 'tracknewdel.cpp.xml'
