@@ -7,74 +7,68 @@ var list_across0 = [
 ];
 var list_up0 = [
 'cppad.xml',
-'library.xml',
+'appendix.xml',
+'deprecated.xml',
 'tracknewdel.xml'
 ];
-var list_down2 = [
+var list_down3 = [
 'install.xml',
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'multi_thread.xml',
 'library.xml',
 'cppad_ipopt_nlp.xml',
 'example.xml',
-'configure.xml',
+'preprocessor.xml',
 'appendix.xml'
 ];
+var list_down2 = [
+'faq.xml',
+'speed.xml',
+'theory.xml',
+'glossary.xml',
+'bib.xml',
+'bugs.xml',
+'wishlist.xml',
+'whats_new.xml',
+'deprecated.xml',
+'license.xml'
+];
 var list_down1 = [
-'errorhandler.xml',
-'nearequal.xml',
-'speed_test.xml',
-'speedtest.xml',
-'numerictype.xml',
-'checknumerictype.xml',
-'simplevector.xml',
-'checksimplevector.xml',
-'nan.xml',
-'pow_int.xml',
-'poly.xml',
-'ludetandsolve.xml',
-'rombergone.xml',
-'rombergmul.xml',
-'runge45.xml',
-'rosen34.xml',
-'odeerrcontrol.xml',
-'odegear.xml',
-'odegearcontrol.xml',
-'benderquad.xml',
-'opt_val_hes.xml',
-'luratio.xml',
-'std_math_unary.xml',
-'cppad_vector.xml',
-'tracknewdel.xml'
+'include_deprecated.xml',
+'fundeprecated.xml',
+'omp_max_thread.xml',
+'tracknewdel.xml',
+'omp_alloc.xml'
 ];
 var list_down0 = [
 'tracknewdel.cpp.xml'
 ];
 var list_current0 = [
+'tracknewdel.xml#Deprecated',
 'tracknewdel.xml#Syntax',
 'tracknewdel.xml#Purpose',
 'tracknewdel.xml#Include',
 'tracknewdel.xml#file',
 'tracknewdel.xml#line',
 'tracknewdel.xml#oldptr',
-'tracknewdel.xml#oldptr.OpenMP',
 'tracknewdel.xml#newlen',
 'tracknewdel.xml#head newptr',
 'tracknewdel.xml#ncopy',
 'tracknewdel.xml#TrackNewVec',
 'tracknewdel.xml#TrackNewVec.Macro',
-'tracknewdel.xml#TrackNewVec.Deprecated',
+'tracknewdel.xml#TrackNewVec.Previously Deprecated',
 'tracknewdel.xml#TrackDelVec',
 'tracknewdel.xml#TrackDelVec.Macro',
-'tracknewdel.xml#TrackDelVec.Deprecated',
+'tracknewdel.xml#TrackDelVec.Previously Deprecated',
 'tracknewdel.xml#TrackExtend',
 'tracknewdel.xml#TrackExtend.Macro',
-'tracknewdel.xml#TrackExtend.Deprecated',
+'tracknewdel.xml#TrackExtend.Previously Deprecated',
 'tracknewdel.xml#TrackCount',
 'tracknewdel.xml#TrackCount.Macro',
-'tracknewdel.xml#TrackCount.Deprecated',
-'tracknewdel.xml#TrackCount.OpenMP',
+'tracknewdel.xml#TrackCount.Previously Deprecated',
+'tracknewdel.xml#Multi-Threading',
 'tracknewdel.xml#Example'
 ];
 function choose_across0(item)
@@ -89,6 +83,12 @@ function choose_up0(item)
 	if(index > 0)
 		document.location = list_up0[index-1];
 }
+function choose_down3(item)
+{	var index          = item.selectedIndex;
+	item.selectedIndex = 0;
+	if(index > 0)
+		document.location = list_down3[index-1];
+}
 function choose_down2(item)
 {	var index          = item.selectedIndex;
 	item.selectedIndex = 0;
