@@ -1,4 +1,4 @@
-/* $Id: bender_quad.cpp 1771 2011-01-01 15:41:51Z bradbell $ */
+/* $Id: bender_quad.cpp 2057 2011-08-11 14:07:11Z bradbell $ */
 /* --------------------------------------------------------------------------
 CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
@@ -201,7 +201,7 @@ bool BenderQuad(void)
 	CppAD::ADFun<double> Gfun(a_x, a_g);
 
 	// accuracy for checks
-	double eps = 10. * std::numeric_limits<double>::epsilon();
+	double eps = 10. * CppAD::epsilon<double>();
 
 	// check Jacobian
 	BAvector check_gx = Gfun.Jacobian(x);
