@@ -1,6 +1,6 @@
-/* $Id: example.cpp 1662 2010-03-11 18:31:11Z bradbell $ */
+/* $Id: example.cpp 2240 2011-12-31 05:33:55Z bradbell $ */
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -11,13 +11,25 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
 /*
-$begin Example.cpp$$
+$begin example.cpp$$
 $spell
 	Cpp
 $$
 
-$section Program That Runs the CppAD Examples$$
-$index example, run all$$
+$section CppAD Examples and Tests$$
+$index example, CppAD$$
+$index test, CppAD$$
+
+$head Running Tests$$
+To build this program and run its correctness tests,
+execute the following commands starting in the
+$cref/work directory/InstallUnix/Download/Work Directory/$$:
+$codei%
+	cd example
+	make test
+%$$
+There are a lot of tests, so this may take a while to compile.
+
 
 $code
 $verbatim%example/example.cpp%0%// BEGIN PROGRAM%// END PROGRAM%1%$$
@@ -36,12 +48,12 @@ $end
 // standard string
 # include <string>
 
-// CppAD include file
-# include <cppad/cppad.hpp>
+// memory leak utility
+# include <cppad/memory_leak.hpp>
 
 // external complied tests
 extern bool abort_recording(void);
-extern bool Abs(void);
+extern bool abs(void);
 extern bool Acos(void);
 extern bool Add(void);
 extern bool AddEq(void);
@@ -60,6 +72,7 @@ extern bool Compare(void);
 extern bool CompareChange(void);
 extern bool complex_poly(void);
 extern bool CondExp(void);
+extern bool conj_grad(void);
 extern bool CopyAD(void);
 extern bool CopyBase(void);
 extern bool Cos(void);
@@ -68,6 +81,7 @@ extern bool CppAD_vector(void);
 extern bool Default(void);
 extern bool Div(void);
 extern bool DivEq(void);
+extern bool epsilon(void);
 extern bool Eq(void);
 extern bool EqualOpSeq(void);
 extern bool Erf(void);
@@ -99,6 +113,7 @@ extern bool LuInvert(void);
 extern bool LuRatio(void);
 extern bool LuSolve(void);
 extern bool LuVecADOk(void);
+extern bool mat_mul(void);
 extern bool Mul(void);
 extern bool MulEq(void);
 extern bool mul_level(void);
@@ -115,6 +130,7 @@ extern bool OdeGearControl(void);
 extern bool OdeStiff(void);
 extern bool ode_taylor(void);
 extern bool ode_taylor_adolc(void);
+extern bool omp_alloc(void);
 extern bool opt_val_hes(void);
 extern bool optimize(void);
 extern bool Output(void);
@@ -122,6 +138,7 @@ extern bool ParVar(void);
 extern bool Poly(void);
 extern bool Pow(void);
 extern bool pow_int(void);
+extern bool print_for(void);
 extern bool reverse_any(void);
 extern bool reverse_one(void);
 extern bool reverse_three(void);
@@ -136,6 +153,7 @@ extern bool Rosen34(void);
 extern bool runge_45_1(void);
 extern bool runge_45_2(void);
 extern bool seq_property(void);
+extern bool sign(void);
 extern bool SimpleVector(void);
 extern bool Sin(void);
 extern bool Sinh(void);
@@ -148,9 +166,10 @@ extern bool SubEq(void);
 extern bool Tan(void);
 extern bool Tanh(void);
 extern bool TapeIndex(void);
-extern bool TrackNewDel(void);
+extern bool thread_alloc(void);
 extern bool UnaryMinus(void);
 extern bool UnaryPlus(void);
+extern bool user_tan(void);
 extern bool Value(void);
 extern bool Var2Par(void);
 extern bool vec_ad(void);
@@ -188,7 +207,7 @@ int main(void)
 
 	// external compiled tests
 	ok &= Run( abort_recording,   "abort_recording"  );
-	ok &= Run( Abs,               "Abs"              );
+	ok &= Run( abs,               "abs"              );
 	ok &= Run( Acos,              "Acos"             );
 	ok &= Run( Add,               "Add"              );
 	ok &= Run( AddEq,             "AddEq"            );
@@ -207,6 +226,7 @@ int main(void)
 	ok &= Run( CompareChange,     "CompareChange"    );
 	ok &= Run( complex_poly,      "complex_poly"     );
 	ok &= Run( CondExp,           "CondExp"          );
+	ok &= Run( conj_grad,         "conj_grad"        );
 	ok &= Run( CopyAD,            "CopyAD"           );
 	ok &= Run( CopyBase,          "CopyBase"         );
 	ok &= Run( Cos,               "Cos"              );
@@ -215,6 +235,7 @@ int main(void)
 	ok &= Run( Default,           "Default"          );
 	ok &= Run( Div,               "Div"              );
 	ok &= Run( DivEq,             "DivEq"            );
+	ok &= Run( epsilon,           "epsilon"          );
 	ok &= Run( Eq,                "Eq"               );
 	ok &= Run( EqualOpSeq,        "EqualOpSeq"       );
 	ok &= Run( Erf,               "Erf"              );
@@ -246,6 +267,7 @@ int main(void)
 	ok &= Run( LuRatio,           "LuRatio"          );
 	ok &= Run( LuSolve,           "LuSolve"          );
 	ok &= Run( LuVecADOk,         "LuVecADOk"        );
+	ok &= Run( mat_mul,           "mat_mul"          );
 	ok &= Run( Mul,               "Mul"              );
 	ok &= Run( MulEq,             "MulEq"            );
 	ok &= Run( mul_level,         "mul_level"        );
@@ -260,6 +282,7 @@ int main(void)
 	ok &= Run( OdeGearControl,    "OdeGearControl"   );
 	ok &= Run( OdeStiff,          "OdeStiff"         );
 	ok &= Run( ode_taylor,        "ode_taylor"       );
+	ok &= Run( omp_alloc,         "omp_alloc"        );
 	ok &= Run( opt_val_hes,       "opt_val_hes"      );
 	ok &= Run( optimize,          "optimize"         );
 	ok &= Run( Output,            "Output"           );
@@ -281,6 +304,7 @@ int main(void)
 	ok &= Run( runge_45_1,        "runge_45_1"       );
 	ok &= Run( runge_45_2,        "runge_45_2"       );
 	ok &= Run( seq_property,      "seq_property"     );
+	ok &= Run( sign,              "sign"             );
 	ok &= Run( SimpleVector,      "SimpleVector"     );
 	ok &= Run( Sin,               "Sin"              );
 	ok &= Run( Sinh,              "Sinh"             );
@@ -293,32 +317,31 @@ int main(void)
 	ok &= Run( Tan,               "Tan"              );
 	ok &= Run( Tanh,              "Tanh"             );
 	ok &= Run( TapeIndex,         "TapeIndex"        );
-	ok &= Run( TrackNewDel,       "TrackNewDel"      );
+	ok &= Run( thread_alloc,      "thread_alloc"     );
 	ok &= Run( UnaryMinus,        "UnaryMinus"       );
 	ok &= Run( UnaryPlus,         "UnaryPlus"        );
+	ok &= Run( user_tan,           "user_tan"        );
 	ok &= Run( Value,             "Value"            );
 	ok &= Run( Var2Par,           "Var2Par"          );
 	ok &= Run( vec_ad,            "vec_ad"           );
-
 # ifdef CPPAD_ADOLC_EXAMPLES
 	ok &= Run( mul_level_adolc,   "mul_level_adolc"  );
 	ok &= Run( ode_taylor_adolc,  "ode_taylor_adolc" );
 # endif
-	
 
 	// check for errors
 	using std::cout;
 	using std::endl;
 	assert( ok || (Run_error_count > 0) );
-	if( CPPAD_TRACK_COUNT() == 0 )
-	{	Run_ok_count++;
-		cout << "Ok:    " << "No memory leak detected" << endl;
-	}
-	else
+	if( CppAD::memory_leak() )
 	{	ok = false;
 		Run_error_count++;
 		cout << "Error: " << "memory leak detected" << endl;
 	}
+	else
+	{	Run_ok_count++;
+		cout << "OK:    " << "No memory leak detected" << endl;
+	}
 	// convert int(size_t) to avoid warning on _MSC_VER systems
 	if( ok )
 		cout << "All " << int(Run_ok_count) << " tests passed." << endl;
