@@ -1,6 +1,6 @@
-/* $Id: reverse_any.cpp 1662 2010-03-11 18:31:11Z bradbell $ */
+/* $Id: reverse_any.cpp 2057 2011-08-11 14:07:11Z bradbell $ */
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -148,7 +148,7 @@ namespace {
 
 bool reverse_any(void)
 {	bool ok = true;
-     double eps = 10. * std::numeric_limits<double>::epsilon();
+     double eps = 10. * CppAD::epsilon<double>();
 
 	using CppAD::AD;
 	using CppAD::NearEqual;
