@@ -1,6 +1,6 @@
-/* $Id: example.cpp 1652 2010-02-09 12:26:20Z bradbell $ */
+/* $Id: example.cpp 2192 2011-11-18 00:15:16Z bradbell $ */
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -20,7 +20,17 @@ $index program, speed example$$
 $index example, speed program$$
 
 
-$section Program That Runs the Speed Examples$$
+$section Run the Speed Examples$$
+
+$head Running Tests$$
+To build this program and run its correctness tests,
+execute the following commands starting in the
+$cref/work directory/InstallUnix/Download/Work Directory/$$:
+$codei%
+	cd speed/example
+	make test
+%$$
+
 
 $code
 $verbatim%speed/example/example.cpp%0%// BEGIN PROGRAM%// END PROGRAM%1%$$
@@ -37,20 +47,31 @@ extern bool det_of_minor(void);
 extern bool det_by_lu(void);
 extern bool det_by_minor(void);
 extern bool elapsed_seconds(void);
+extern bool mat_sum_sq(void);
 extern bool ode_evaluate(void);
 extern bool sparse_evaluate(void);
 extern bool speed_test(void);
+extern bool time_test(void);
 
 namespace {
 	// function that runs one test
-	static size_t Run_ok_count    = 0;
-	static size_t Run_error_count = 0;
+	size_t Run_ok_count    = 0;
+	size_t Run_error_count = 0;
+	const char* exception_list[] = {
+		"elapsed_seconds",
+		"speed_test",
+		"time_test"
+	};
+	size_t n_exception = sizeof(exception_list) / sizeof(exception_list[0]);
 	bool Run(bool TestOk(void), std::string name)
 	{	bool ok               = true;
 		std::streamsize width =  20;         
 		std::cout.width( width );
 		std::cout.setf( std::ios_base::left );
 		std::cout << name;
+		bool exception = false;
+		for(size_t i = 0; i < n_exception; i++)
+			exception |= exception_list[i] == name;
 		//
 		ok &= name.size() < size_t(width);
 		ok &= TestOk();
@@ -58,6 +79,12 @@ namespace {
 		{	std::cout << "OK" << std::endl;
 			Run_ok_count++;
 		}
+		else if ( exception )
+		{	std::cout << "Error: perhaps too many other programs running";
+			std::cout << std::endl;
+			// no change to Run_ok_count
+			ok = true;
+		}
 		else
 		{	std::cout << "Error" << std::endl;
 			Run_error_count++;
@@ -75,27 +102,25 @@ int main(void)
 	ok &= Run(det_of_minor,          "det_of_minor"   );
 	ok &= Run(det_by_minor,         "det_by_minor"    );
 	ok &= Run(det_by_lu,               "det_by_lu"    );
-	ok &= Run(elapsed_seconds,   "eplased_seconds"    );
+	ok &= Run(elapsed_seconds,   "elapsed_seconds"    );
+	ok &= Run(mat_sum_sq,             "mat_sum_sq"    );
 	ok &= Run(ode_evaluate,         "ode_evaluate"    );
 	ok &= Run(sparse_evaluate,   "sparse_evaluate"    );
+	ok &= Run(speed_test,             "speed_test"    );
+	ok &= Run(time_test,               "time_test"    );
 
 	// check for memory leak in previous calculations
-	if( CPPAD_TRACK_COUNT() != 0 )
+	if( CppAD::memory_leak() )
 		cout << "Error: memroy leak detected" << endl;
 
 	assert( ok || (Run_error_count > 0) );
 	if( ok )
-		cout << "The " << int(Run_ok_count) << " tests above passed.";
-	else	cout << int(Run_error_count) << " tests above failed.";
+	{	cout << "All " << int(Run_ok_count) << " tests passed ";
+		cout << "(possibly excepting elapsed_seconds).";
+	}
+	else	cout << int(Run_error_count) << " tests failed.";
 	cout << endl;
 
-	bool speed_test_ok = speed_test();
-	if( speed_test_ok )
-		cout << "speed_test also passed correctness test" << endl;
-	else
-	{	cout << "speed_test failed its correctness test" << endl;
-		cout << "(expected if other processes are running)" << endl;
-	}
 
 	return static_cast<int>( ! ok );
 }
