@@ -1,6 +1,6 @@
-/* $Id: main.cpp 1655 2010-02-11 19:59:43Z bradbell $ */
+/* $Id: main.cpp 2233 2011-12-20 19:34:24Z bradbell $ */
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -21,6 +21,8 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <cppad/speed_test.hpp>
 # include <cppad/speed/uniform_01.hpp>
 # include <cppad/poly.hpp>
+# include <cppad/track_new_del.hpp>
+# include <cppad/memory_leak.hpp>
 
 # ifdef SPEED_ADOLC
 # define AD_PACKAGE "adolc"
@@ -44,6 +46,7 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 /*
 $begin speed_main$$
 $spell
+	mat_mul
 	retaped
 	retape
 	bool
@@ -65,8 +68,7 @@ $index test, cppad speed$$
 $section Speed Testing Main Program$$
 
 $head Syntax$$
-$codei%speed/%package%/%package% %test% %seed% %option_list% 
-%$$
+$codei%speed/%package%/%package% %test% %seed% %option_list%$$
 
 $head Purpose$$
 A version of this program runs the correctness tests
@@ -146,10 +148,10 @@ and the particular test has a fixed operation sequence,
 the AD package is allowed to use one taping of the operation
 sequence for all the repetitions of that speed test.
 The following tests have a fixed operation sequence:
-$code det_minor$$, $code ode$$, $code poly$$.
+$code det_minor$$, $code mat_mul$$, $code ode$$, $code poly$$.
 
 $subhead optimize$$
-If the option code optimize is present, the symbol
+If the option $code optimize$$ is present, the symbol
 $codep
 	extern bool global_optimize
 $$
@@ -161,6 +163,18 @@ this optimization should be done before doing computations.
 If it is false,
 this optimization should not be done.
 
+$subhead atomic$$
+If the option $code atomic$$ is present, the symbol
+$codep
+	extern bool global_atomic
+$$
+is true and otherwise it is false.
+If this external symbol is true,
+and the AD package has a way to speed up the processing
+by adding $cref user_atomic$$ operations,
+this should be included in computations.
+If it is false, user defined atomic operations should not be done.
+
 $head Correctness Results$$
 An output line is generated for each correctness test
 stating of the test passed or failed.
@@ -177,6 +191,7 @@ The rate is the number of times per second that the calculation was repeated.
 $children%
 	speed/src/link_det_lu.cpp%
 	speed/src/link_det_minor.cpp%
+	speed/src/link_mat_mul.cpp%
 	speed/src/link_ode.cpp%
 	speed/src/link_poly.cpp%
 	speed/src/link_sparse_hessian.cpp%
@@ -201,13 +216,14 @@ $end
 -----------------------------------------------------------------------------
 */
 
-# define CPPAD_DECLARE_SPEED(name)                          \
-	extern bool available_##name(void);                 \
-	extern bool correct_##name(bool is_package_double); \
-	extern void speed_##name(size_t size, size_t repeat)
+# define CPPAD_DECLARE_SPEED(name)                       \
+     extern bool available_##name(void);                 \
+     extern bool correct_##name(bool is_package_double); \
+     extern void speed_##name(size_t size, size_t repeat)
 
 CPPAD_DECLARE_SPEED(det_lu);
 CPPAD_DECLARE_SPEED(det_minor);
+CPPAD_DECLARE_SPEED(mat_mul);
 CPPAD_DECLARE_SPEED(ode);
 CPPAD_DECLARE_SPEED(poly);
 CPPAD_DECLARE_SPEED(sparse_hessian);
@@ -215,6 +231,7 @@ CPPAD_DECLARE_SPEED(sparse_jacobian);
 
 bool   global_retape;
 bool   global_optimize;
+bool   global_atomic;
 
 namespace {
 	using std::cout;
@@ -258,7 +275,7 @@ namespace {
 	}
 	// ----------------------------------------------------------------
 	// function that runs one speed case
-	void Run_speed(
+	void run_speed(
 		void speed_case(size_t size, size_t repeat) , 
 		const CppAD::vector<size_t>&       size_vec ,
 		const std::string&                case_name )
@@ -279,46 +296,56 @@ namespace {
 // main program that runs all the tests
 int main(int argc, char *argv[])
 {	bool ok = true;
-
-	const char *test[]= {
-		"correct",
-		"det_lu",
-		"det_minor",
-		"ode",
-		"poly",
-		"sparse_hessian",
-		"sparse_jacobian",
-		"speed"
+	enum test_enum {
+		test_correct,
+		test_speed,
+		test_det_lu,
+		test_det_minor,
+		test_mat_mul,
+		test_ode,
+		test_poly,
+		test_sparse_hessian,
+		test_sparse_jacobian,
+		test_error
 	};
-	const size_t n_test  = sizeof(test) / sizeof(test[0]);
-	const size_t test_correct        = 0;
-	const size_t test_det_lu         = 1;
-	const size_t test_det_minor      = 2;
-	const size_t test_ode            = 3;
-	const size_t test_poly           = 4;
-	const size_t test_sparse_hessian = 5;
-	const size_t test_sparse_jacobian= 6;
-	const size_t test_speed          = 7;
-	assert( n_test == test_speed+1 );
+	struct test_struct {
+		const char       *name;
+		const test_enum  index;
+	}; 
+	const test_struct test_list[]= {
+		{ "correct",            test_correct         }, 
+		{ "speed",              test_speed           },
+		{ "det_lu",             test_det_lu          },
+		{ "det_minor",          test_det_minor       },
+		{ "mat_mul",            test_mat_mul         },
+		{ "ode",                test_ode             },
+		{ "poly",               test_poly            },
+		{ "sparse_hessian",     test_sparse_hessian  },
+		{ "sparse_jacobian",    test_sparse_jacobian }
+	};
+	const size_t n_test  = sizeof(test_list) / sizeof(test_list[0]);
 
 	size_t i;
-	size_t match = n_test;
+	test_enum match = test_error;
 	int    iseed = 0;
 	bool   error = argc < 3;
 	if( ! error )
 	{	for(i = 0; i < n_test; i++)
-			if( strcmp(test[i], argv[1]) == 0 )
-				match = i;
-		error = match == n_test;
+			if( strcmp(test_list[i].name, argv[1]) == 0 )
+				match = test_list[i].index;
+		error = match == test_error;
 		iseed = std::atoi( argv[2] );
 		error |= iseed < 0;
 		global_retape   = false;
 		global_optimize = false;
+		global_atomic   = false;
 		for(i = 3; i < size_t(argc); i++)
 		{	if( strcmp(argv[i], "retape") == 0 )
 				global_retape = true;
 			else if( strcmp(argv[i], "optimize") == 0 )
 				global_optimize = true;
+			else if( strcmp(argv[i], "atomic") == 0 )
+				global_atomic = true;
 			else
 				error = true;
 		}
@@ -328,7 +355,7 @@ int main(int argc, char *argv[])
 		     << AD_PACKAGE << " test seed option_list" << endl;
 		cout << "test choices: " << endl;
 		for(i = 0; i < n_test; i++)
-			cout << "\t" << test[i] << endl;
+			cout << "\t" << test_list[i].name << endl;
 		cout << "seed choices: ";
 		cout << "a positive integer used as a random seed." << endl;
 		cout << "option choices: ";
@@ -343,6 +370,7 @@ int main(int argc, char *argv[])
 	size_t n_size   = 5;
 	CppAD::vector<size_t> size_det_lu(n_size);
 	CppAD::vector<size_t> size_det_minor(n_size);
+	CppAD::vector<size_t> size_mat_mul(n_size);
 	CppAD::vector<size_t> size_ode(n_size);
 	CppAD::vector<size_t> size_poly(n_size);
 	CppAD::vector<size_t> size_sparse_hessian(n_size);
@@ -350,33 +378,34 @@ int main(int argc, char *argv[])
 	for(i = 0; i < n_size; i++) 
 	{	size_det_lu[i]      = 3 * i + 1;
 		size_det_minor[i]   = i + 1;
+		size_mat_mul[i]     = 10 * (i + 1);
 		size_ode[i]         = i + 1;
 		size_poly[i]        = 8 * i + 1;
 		size_sparse_hessian[i]  = 30 * (i + 1);
 		size_sparse_jacobian[i] = 30 * (i + 1);
 	}
-# ifndef NDEBUG
-	size_t base_count = CPPAD_TRACK_COUNT();
-# endif
 
 	switch(match)
 	{
 		// run all the correctness tests
 		case test_correct:
 		if( available_det_lu() ) ok &= run_correct(
-			correct_det_lu,    "det_lu"       
+			correct_det_lu,           "det_lu"       
 		);
 		if( available_det_minor() ) ok &= run_correct(
-			correct_det_minor, "det_minor"    
+			correct_det_minor,        "det_minor"    
+		);
+		if( available_mat_mul() ) ok &= run_correct(
+			correct_mat_mul,          "mat_mul"    
 		);
 		if( available_ode() ) ok &= run_correct(
-			correct_ode,      "ode"         
+			correct_ode,             "ode"         
 		);
 		if( available_poly() ) ok &= run_correct(
-			correct_poly,      "poly"         
+			correct_poly,            "poly"         
 		);
 		if( available_sparse_hessian() ) ok &= run_correct(
-			correct_sparse_hessian, "sparse_hessian"         
+			correct_sparse_hessian,  "sparse_hessian"         
 		);
 		if( available_sparse_jacobian() ) ok &= run_correct(
 			correct_sparse_jacobian, "sparse_jacobian"         
@@ -395,22 +424,25 @@ int main(int argc, char *argv[])
 		// ---------------------------------------------------------
 		// run all the speed tests 
 		case test_speed:
-		if( available_det_lu() ) Run_speed(
-		speed_det_lu,    size_det_lu,    "det_lu"
+		if( available_det_lu() ) run_speed(
+		speed_det_lu,          size_det_lu,          "det_lu"
 		);
-		if( available_det_minor() ) Run_speed(
-		speed_det_minor, size_det_minor, "det_minor"
+		if( available_det_minor() ) run_speed(
+		speed_det_minor,       size_det_minor,       "det_minor"
 		);
-		if( available_ode() ) Run_speed(
-		speed_ode,       size_ode,       "ode"
+		if( available_mat_mul() ) run_speed(
+		speed_mat_mul,           size_mat_mul,       "det_minor"
 		);
-		if( available_poly() ) Run_speed(
-		speed_poly,      size_poly,      "poly"
+		if( available_ode() ) run_speed(
+		speed_ode,             size_ode,             "ode"
 		);
-		if( available_sparse_hessian() ) Run_speed(
+		if( available_poly() ) run_speed(
+		speed_poly,            size_poly,            "poly"
+		);
+		if( available_sparse_hessian() ) run_speed(
 		speed_sparse_hessian,  size_sparse_hessian,  "sparse_hessian"
 		);
-		if( available_sparse_jacobian() ) Run_speed(
+		if( available_sparse_jacobian() ) run_speed(
 		speed_sparse_jacobian, size_sparse_jacobian, "sparse_jacobian"
 		);
 		ok = true;
@@ -424,7 +456,7 @@ int main(int argc, char *argv[])
 			exit(1);
 		}
 		ok &= run_correct(correct_det_lu,           "det_lu");
-		Run_speed(speed_det_lu,    size_det_lu,     "det_lu");
+		run_speed(speed_det_lu,    size_det_lu,     "det_lu");
 		break;
 		// ---------------------------------------------------------
 
@@ -435,7 +467,18 @@ int main(int argc, char *argv[])
 			exit(1);
 		}
 		ok &= run_correct(correct_det_minor,       "det_minor");
-		Run_speed(speed_det_minor, size_det_minor, "det_minor");
+		run_speed(speed_det_minor, size_det_minor, "det_minor");
+		break;
+		// ---------------------------------------------------------
+
+		case test_mat_mul:
+		if( ! available_mat_mul() )
+		{	cout << AD_PACKAGE << ": test " << argv[1] 
+			     << " not available" << endl; 
+			exit(1);
+		}
+		ok &= run_correct(correct_mat_mul,     "mat_mul");
+		run_speed(speed_mat_mul, size_mat_mul, "mat_mul");
 		break;
 		// ---------------------------------------------------------
 
@@ -446,7 +489,7 @@ int main(int argc, char *argv[])
 			exit(1);
 		}
 		ok &= run_correct(correct_ode,           "ode");
-		Run_speed(speed_ode,      size_ode,      "ode");
+		run_speed(speed_ode,      size_ode,      "ode");
 		break;
 		// ---------------------------------------------------------
 
@@ -457,7 +500,7 @@ int main(int argc, char *argv[])
 			exit(1);
 		}
 		ok &= run_correct(correct_poly,            "poly");
-		Run_speed(speed_poly,      size_poly,      "poly");
+		run_speed(speed_poly,      size_poly,      "poly");
 		break;
 		// ---------------------------------------------------------
 
@@ -468,7 +511,7 @@ int main(int argc, char *argv[])
 			exit(1);
 		}
 		ok &= run_correct(correct_sparse_hessian, "sparse_hessian");
-		Run_speed(
+		run_speed(
 		speed_sparse_hessian, size_sparse_hessian,  "sparse_hessian");
 		break;
 		// ---------------------------------------------------------
@@ -480,7 +523,7 @@ int main(int argc, char *argv[])
 			exit(1);
 		}
 		ok &= run_correct(correct_sparse_jacobian, "sparse_jacobian");
-		Run_speed(
+		run_speed(
 		speed_sparse_jacobian, size_sparse_jacobian, "sparse_jacobian"
 		);
 		break;
@@ -490,15 +533,24 @@ int main(int argc, char *argv[])
 		assert(0);
 	}
 # ifndef NDEBUG
-	if( CPPAD_TRACK_COUNT() == base_count )
-	{	Run_ok_count++;
-		cout << "No memory leak detected" << endl;
-	}
-	else
+	// return memory for vectors that are still in scope
+	size_det_lu.resize(0);
+	size_det_minor.resize(0);
+	size_mat_mul.resize(0);
+	size_ode.resize(0);
+	size_poly.resize(0);
+	size_sparse_hessian.resize(0);
+	size_sparse_jacobian.resize(0);
+	// check for memory leak
+	if( CppAD::memory_leak() )
 	{	ok = false;
 		Run_error_count++;
 		cout << "Memory leak detected" << endl;
-        }
+	}
+	else
+	{	Run_ok_count++;
+		cout << "No memory leak detected" << endl;
+	}
 # endif
 	return static_cast<int>( ! ok );
 }
