@@ -1,6 +1,6 @@
-/* $Id: test_more.cpp 1717 2010-11-28 05:19:17Z bradbell $ */
+/* $Id: test_more.cpp 2240 2011-12-31 05:33:55Z bradbell $ */
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -13,11 +13,11 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 // system include files used for I/O
 # include <iostream>
 
-// AD<Type> template class definition
-# include <cppad/cppad.hpp>
+// memory leak checker
+# include <cppad/memory_leak.hpp>
 
 // various examples / tests
-extern bool Abs(void);
+extern bool abs(void);
 extern bool Acos(void);
 extern bool Add(void);
 extern bool AddEq(void);
@@ -57,9 +57,11 @@ extern bool NearEqualExt(void);
 extern bool Neg(void);
 extern bool ode_err_control(void);
 extern bool optimize(void);
+extern bool parameter(void);
 extern bool Poly(void);
 extern bool Pow(void);
 extern bool PowInt(void);
+extern bool print_for(void);
 extern bool reverse(void);
 extern bool rev_sparse_hes(void);
 extern bool rev_sparse_jac(void);
@@ -79,6 +81,8 @@ extern bool std_math(void);
 extern bool Sub(void);
 extern bool SubEq(void);
 extern bool SubZero(void);
+extern bool tan(void);
+extern bool track_new_del(void);
 extern bool Value(void);
 extern bool VecAD(void);
 extern bool VecADPar(void);
@@ -116,7 +120,7 @@ int main(void)
 
 	// This line is used by test_one.sh 
 
-	ok &= Run( Abs,             "Abs"            );
+	ok &= Run( abs,             "abs"            );
 	ok &= Run( Acos,            "Acos"           );
 	ok &= Run( Add,             "Add"            );
 	ok &= Run( AddEq,           "AddEq"          );
@@ -155,9 +159,11 @@ int main(void)
 	ok &= Run( Neg,             "Neg"            );
 	ok &= Run( ode_err_control, "ode_err_control");
 	ok &= Run( optimize,        "optimize"       );
+	ok &= Run( parameter,       "parameter"      );
 	ok &= Run( Poly,            "Poly"           );
 	ok &= Run( Pow,             "Pow"            );
 	ok &= Run( PowInt,          "PowInt"         );
+	ok &= Run( print_for,       "print_for"      );
 	ok &= Run( reverse,         "reverse"        );
 	ok &= Run( rev_sparse_hes,  "rev_sparse_hes" );
 	ok &= Run( rev_sparse_jac,  "rev_sparse_jac" );
@@ -177,6 +183,8 @@ int main(void)
 	ok &= Run( Sub,             "Sub"            );
 	ok &= Run( SubEq,           "SubEq"          );
 	ok &= Run( SubZero,         "SubZero"        );
+	ok &= Run( tan,             "tan"            );
+	ok &= Run( track_new_del,   "track_new_del"  );
 	ok &= Run( Value,           "Value"          );
 	ok &= Run( VecAD,           "VecAD"          );
 	ok &= Run( VecADPar,        "VecADPar"       );
@@ -190,15 +198,15 @@ int main(void)
 	using std::cout;
 	using std::endl;
 	assert( ok || (Run_error_count > 0) );
-	if( CPPAD_TRACK_COUNT() == 0 )
-	{	Run_ok_count++;
-		cout << "Ok:    " << "No memory leak detected" << endl;
-	}
-	else
+	if( CppAD::memory_leak() )
 	{	ok = false;
 		Run_error_count++;
 		cout << "Error: " << "memory leak detected" << endl;
 	}
+	else
+	{	Run_ok_count++;
+		cout << "OK:    " << "No memory leak detected" << endl;
+	}
 	// convert int(size_t) to avoid warning on _MSC_VER systems
 	if( ok )
 		cout << "All " << int(Run_ok_count) << " tests passed." << endl;
